#
# spec file for package pandoc
#
# Copyright (c) 2020 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name pandoc
%bcond_with tests
Name:           %{pkg_name}
Version:        2.9.2.1
Release:        lp152.1.1
Summary:        Conversion between markup formats
License:        GPL-2.0-or-later
URL:            https://hackage.haskell.org/package/%{name}
Source0:        https://hackage.haskell.org/package/%{name}-%{version}/%{name}-%{version}.tar.gz
BuildRequires:  chrpath
BuildRequires:  fdupes
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-Glob-devel
BuildRequires:  ghc-HTTP-devel
BuildRequires:  ghc-HsYAML-devel
BuildRequires:  ghc-JuicyPixels-devel
BuildRequires:  ghc-SHA-devel
BuildRequires:  ghc-aeson-devel
BuildRequires:  ghc-aeson-pretty-devel
BuildRequires:  ghc-attoparsec-devel
BuildRequires:  ghc-base-compat-devel
BuildRequires:  ghc-base-noprelude-devel
BuildRequires:  ghc-base64-bytestring-devel
BuildRequires:  ghc-binary-devel
BuildRequires:  ghc-blaze-html-devel
BuildRequires:  ghc-blaze-markup-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-case-insensitive-devel
BuildRequires:  ghc-cmark-gfm-devel
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-data-default-devel
BuildRequires:  ghc-deepseq-devel
BuildRequires:  ghc-directory-devel
BuildRequires:  ghc-doclayout-devel
BuildRequires:  ghc-doctemplates-devel
BuildRequires:  ghc-emojis-devel
BuildRequires:  ghc-exceptions-devel
BuildRequires:  ghc-filepath-devel
BuildRequires:  ghc-haddock-library-devel
BuildRequires:  ghc-hslua-devel
BuildRequires:  ghc-hslua-module-system-devel
BuildRequires:  ghc-hslua-module-text-devel
BuildRequires:  ghc-http-client-devel
BuildRequires:  ghc-http-client-tls-devel
BuildRequires:  ghc-http-types-devel
BuildRequires:  ghc-ipynb-devel
BuildRequires:  ghc-jira-wiki-markup-devel
BuildRequires:  ghc-mtl-devel
BuildRequires:  ghc-network-devel
BuildRequires:  ghc-network-uri-devel
BuildRequires:  ghc-pandoc-types-devel
BuildRequires:  ghc-parsec-devel
BuildRequires:  ghc-process-devel
BuildRequires:  ghc-random-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-safe-devel
BuildRequires:  ghc-scientific-devel
BuildRequires:  ghc-skylighting-core-devel
BuildRequires:  ghc-skylighting-devel
BuildRequires:  ghc-split-devel
BuildRequires:  ghc-syb-devel
BuildRequires:  ghc-tagsoup-devel
BuildRequires:  ghc-temporary-devel
BuildRequires:  ghc-texmath-devel
BuildRequires:  ghc-text-conversions-devel
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-time-devel
BuildRequires:  ghc-unicode-transforms-devel
BuildRequires:  ghc-unix-devel
BuildRequires:  ghc-unordered-containers-devel
BuildRequires:  ghc-vector-devel
BuildRequires:  ghc-xml-devel
BuildRequires:  ghc-zip-archive-devel
BuildRequires:  ghc-zlib-devel
%if %{with tests}
BuildRequires:  ghc-Diff-devel
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-executable-path-devel
BuildRequires:  ghc-tasty-devel
BuildRequires:  ghc-tasty-golden-devel
BuildRequires:  ghc-tasty-hunit-devel
BuildRequires:  ghc-tasty-lua-devel
BuildRequires:  ghc-tasty-quickcheck-devel
%endif

%description
Pandoc is a Haskell library for converting from one markup format to another,
and a command-line tool that uses this library. It can read several dialects of
Markdown and (subsets of) HTML, reStructuredText, LaTeX, DocBook, JATS,
MediaWiki markup, DokuWiki markup, TWiki markup, TikiWiki markup, Jira markup,
Creole 1.0, Haddock markup, OPML, Emacs Org-Mode, Emacs Muse, txt2tags, ipynb
(Jupyter notebooks), Vimwiki, Word Docx, ODT, EPUB, FictionBook2, roff man,
Textile, and CSV, and it can write Markdown, reStructuredText, XHTML, HTML 5,
LaTeX, ConTeXt, DocBook, JATS, OPML, TEI, OpenDocument, ODT, Word docx,
PowerPoint pptx, RTF, MediaWiki, DokuWiki, XWiki, ZimWiki, Textile, Jira, roff
man, roff ms, plain text, Emacs Org-Mode, AsciiDoc, Haddock markup, EPUB (v2
and v3), ipynb, FictionBook2, InDesign ICML, Muse, LaTeX beamer slides, and
several kinds of HTML/JavaScript slide shows (S5, Slidy, Slideous, DZSlides,
reveal.js).

In contrast to most existing tools for converting Markdown to HTML, pandoc has
a modular design: it consists of a set of readers, which parse text in a given
format and produce a native representation of the document, and a set of
writers, which convert this native representation into a target format.
Thus, adding an input or output format requires only adding a reader or writer.

%package -n ghc-%{name}
Summary:        Haskell %{name} library

%description -n ghc-%{name}
This package provides the Haskell %{name} shared library.

%package -n ghc-%{name}-devel
Summary:        Haskell %{name} library development files
Requires:       ghc-%{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description -n ghc-%{name}-devel
This package provides the Haskell %{name} library development files.

%prep
%setup -q
cabal-tweak-dep-ver haddock-library '< 1.9' '< 2'

%build
%ghc_lib_build

%install
%ghc_lib_install
%ghc_fix_rpath %{pkg_name}-%{version}
# Link duplicate template files
%fdupes %{buildroot}%{_datadir}/%{pkg_name}-%{version}/data/templates/

%check
%cabal_test

%post -n ghc-%{name}-devel
%ghc_pkg_recache

%postun -n ghc-%{name}-devel
%ghc_pkg_recache

%files
%license COPYING.md
%doc AUTHORS.md README.md changelog.md
%{_bindir}/%{name}
%dir %{_datadir}/%{name}-%{version}
%dir %{_datadir}/%{name}-%{version}/data
%dir %{_datadir}/%{name}-%{version}/data/docx
%dir %{_datadir}/%{name}-%{version}/data/docx/_rels
%dir %{_datadir}/%{name}-%{version}/data/docx/docProps
%dir %{_datadir}/%{name}-%{version}/data/docx/word
%dir %{_datadir}/%{name}-%{version}/data/docx/word/_rels
%dir %{_datadir}/%{name}-%{version}/data/docx/word/theme
%dir %{_datadir}/%{name}-%{version}/data/dzslides
%dir %{_datadir}/%{name}-%{version}/data/odt
%dir %{_datadir}/%{name}-%{version}/data/odt/Configurations2
%dir %{_datadir}/%{name}-%{version}/data/odt/Configurations2/accelerator
%dir %{_datadir}/%{name}-%{version}/data/odt/META-INF
%dir %{_datadir}/%{name}-%{version}/data/odt/Thumbnails
%dir %{_datadir}/%{name}-%{version}/data/pptx
%dir %{_datadir}/%{name}-%{version}/data/pptx/_rels
%dir %{_datadir}/%{name}-%{version}/data/pptx/docProps
%dir %{_datadir}/%{name}-%{version}/data/pptx/ppt
%dir %{_datadir}/%{name}-%{version}/data/pptx/ppt/_rels
%dir %{_datadir}/%{name}-%{version}/data/pptx/ppt/notesMasters
%dir %{_datadir}/%{name}-%{version}/data/pptx/ppt/notesMasters/_rels
%dir %{_datadir}/%{name}-%{version}/data/pptx/ppt/notesSlides
%dir %{_datadir}/%{name}-%{version}/data/pptx/ppt/notesSlides/_rels
%dir %{_datadir}/%{name}-%{version}/data/pptx/ppt/slideLayouts
%dir %{_datadir}/%{name}-%{version}/data/pptx/ppt/slideLayouts/_rels
%dir %{_datadir}/%{name}-%{version}/data/pptx/ppt/slideMasters
%dir %{_datadir}/%{name}-%{version}/data/pptx/ppt/slideMasters/_rels
%dir %{_datadir}/%{name}-%{version}/data/pptx/ppt/slides
%dir %{_datadir}/%{name}-%{version}/data/pptx/ppt/slides/_rels
%dir %{_datadir}/%{name}-%{version}/data/pptx/ppt/theme
%dir %{_datadir}/%{name}-%{version}/data/templates
%dir %{_datadir}/%{name}-%{version}/data/translations
%{_datadir}/%{name}-%{version}/COPYRIGHT
%{_datadir}/%{name}-%{version}/MANUAL.txt
%{_datadir}/%{name}-%{version}/data/abbreviations
%{_datadir}/%{name}-%{version}/data/bash_completion.tpl
%{_datadir}/%{name}-%{version}/data/docx/?Content_Types?.xml
%{_datadir}/%{name}-%{version}/data/docx/_rels/.rels
%{_datadir}/%{name}-%{version}/data/docx/docProps/app.xml
%{_datadir}/%{name}-%{version}/data/docx/docProps/core.xml
%{_datadir}/%{name}-%{version}/data/docx/docProps/custom.xml
%{_datadir}/%{name}-%{version}/data/docx/word/_rels/document.xml.rels
%{_datadir}/%{name}-%{version}/data/docx/word/_rels/footnotes.xml.rels
%{_datadir}/%{name}-%{version}/data/docx/word/comments.xml
%{_datadir}/%{name}-%{version}/data/docx/word/document.xml
%{_datadir}/%{name}-%{version}/data/docx/word/fontTable.xml
%{_datadir}/%{name}-%{version}/data/docx/word/footnotes.xml
%{_datadir}/%{name}-%{version}/data/docx/word/numbering.xml
%{_datadir}/%{name}-%{version}/data/docx/word/settings.xml
%{_datadir}/%{name}-%{version}/data/docx/word/styles.xml
%{_datadir}/%{name}-%{version}/data/docx/word/theme/theme1.xml
%{_datadir}/%{name}-%{version}/data/docx/word/webSettings.xml
%{_datadir}/%{name}-%{version}/data/dzslides/template.html
%{_datadir}/%{name}-%{version}/data/epub.css
%{_datadir}/%{name}-%{version}/data/init.lua
%{_datadir}/%{name}-%{version}/data/jats.csl
%{_datadir}/%{name}-%{version}/data/odt/Configurations2/accelerator/current.xml
%{_datadir}/%{name}-%{version}/data/odt/META-INF/manifest.xml
%{_datadir}/%{name}-%{version}/data/odt/Thumbnails/thumbnail.png
%{_datadir}/%{name}-%{version}/data/odt/content.xml
%{_datadir}/%{name}-%{version}/data/odt/manifest.rdf
%{_datadir}/%{name}-%{version}/data/odt/meta.xml
%{_datadir}/%{name}-%{version}/data/odt/mimetype
%{_datadir}/%{name}-%{version}/data/odt/settings.xml
%{_datadir}/%{name}-%{version}/data/odt/styles.xml
%{_datadir}/%{name}-%{version}/data/pandoc.List.lua
%{_datadir}/%{name}-%{version}/data/pandoc.lua
%{_datadir}/%{name}-%{version}/data/pptx/?Content_Types?.xml
%{_datadir}/%{name}-%{version}/data/pptx/_rels/.rels
%{_datadir}/%{name}-%{version}/data/pptx/docProps/app.xml
%{_datadir}/%{name}-%{version}/data/pptx/docProps/core.xml
%{_datadir}/%{name}-%{version}/data/pptx/ppt/_rels/presentation.xml.rels
%{_datadir}/%{name}-%{version}/data/pptx/ppt/notesMasters/_rels/notesMaster1.xml.rels
%{_datadir}/%{name}-%{version}/data/pptx/ppt/notesMasters/notesMaster1.xml
%{_datadir}/%{name}-%{version}/data/pptx/ppt/notesSlides/_rels/notesSlide1.xml.rels
%{_datadir}/%{name}-%{version}/data/pptx/ppt/notesSlides/_rels/notesSlide2.xml.rels
%{_datadir}/%{name}-%{version}/data/pptx/ppt/notesSlides/notesSlide1.xml
%{_datadir}/%{name}-%{version}/data/pptx/ppt/notesSlides/notesSlide2.xml
%{_datadir}/%{name}-%{version}/data/pptx/ppt/presProps.xml
%{_datadir}/%{name}-%{version}/data/pptx/ppt/presentation.xml
%{_datadir}/%{name}-%{version}/data/pptx/ppt/slideLayouts/_rels/slideLayout1.xml.rels
%{_datadir}/%{name}-%{version}/data/pptx/ppt/slideLayouts/_rels/slideLayout10.xml.rels
%{_datadir}/%{name}-%{version}/data/pptx/ppt/slideLayouts/_rels/slideLayout11.xml.rels
%{_datadir}/%{name}-%{version}/data/pptx/ppt/slideLayouts/_rels/slideLayout2.xml.rels
%{_datadir}/%{name}-%{version}/data/pptx/ppt/slideLayouts/_rels/slideLayout3.xml.rels
%{_datadir}/%{name}-%{version}/data/pptx/ppt/slideLayouts/_rels/slideLayout4.xml.rels
%{_datadir}/%{name}-%{version}/data/pptx/ppt/slideLayouts/_rels/slideLayout5.xml.rels
%{_datadir}/%{name}-%{version}/data/pptx/ppt/slideLayouts/_rels/slideLayout6.xml.rels
%{_datadir}/%{name}-%{version}/data/pptx/ppt/slideLayouts/_rels/slideLayout7.xml.rels
%{_datadir}/%{name}-%{version}/data/pptx/ppt/slideLayouts/_rels/slideLayout8.xml.rels
%{_datadir}/%{name}-%{version}/data/pptx/ppt/slideLayouts/_rels/slideLayout9.xml.rels
%{_datadir}/%{name}-%{version}/data/pptx/ppt/slideLayouts/slideLayout1.xml
%{_datadir}/%{name}-%{version}/data/pptx/ppt/slideLayouts/slideLayout10.xml
%{_datadir}/%{name}-%{version}/data/pptx/ppt/slideLayouts/slideLayout11.xml
%{_datadir}/%{name}-%{version}/data/pptx/ppt/slideLayouts/slideLayout2.xml
%{_datadir}/%{name}-%{version}/data/pptx/ppt/slideLayouts/slideLayout3.xml
%{_datadir}/%{name}-%{version}/data/pptx/ppt/slideLayouts/slideLayout4.xml
%{_datadir}/%{name}-%{version}/data/pptx/ppt/slideLayouts/slideLayout5.xml
%{_datadir}/%{name}-%{version}/data/pptx/ppt/slideLayouts/slideLayout6.xml
%{_datadir}/%{name}-%{version}/data/pptx/ppt/slideLayouts/slideLayout7.xml
%{_datadir}/%{name}-%{version}/data/pptx/ppt/slideLayouts/slideLayout8.xml
%{_datadir}/%{name}-%{version}/data/pptx/ppt/slideLayouts/slideLayout9.xml
%{_datadir}/%{name}-%{version}/data/pptx/ppt/slideMasters/_rels/slideMaster1.xml.rels
%{_datadir}/%{name}-%{version}/data/pptx/ppt/slideMasters/slideMaster1.xml
%{_datadir}/%{name}-%{version}/data/pptx/ppt/slides/_rels/slide1.xml.rels
%{_datadir}/%{name}-%{version}/data/pptx/ppt/slides/_rels/slide2.xml.rels
%{_datadir}/%{name}-%{version}/data/pptx/ppt/slides/_rels/slide3.xml.rels
%{_datadir}/%{name}-%{version}/data/pptx/ppt/slides/_rels/slide4.xml.rels
%{_datadir}/%{name}-%{version}/data/pptx/ppt/slides/slide1.xml
%{_datadir}/%{name}-%{version}/data/pptx/ppt/slides/slide2.xml
%{_datadir}/%{name}-%{version}/data/pptx/ppt/slides/slide3.xml
%{_datadir}/%{name}-%{version}/data/pptx/ppt/slides/slide4.xml
%{_datadir}/%{name}-%{version}/data/pptx/ppt/tableStyles.xml
%{_datadir}/%{name}-%{version}/data/pptx/ppt/theme/theme1.xml
%{_datadir}/%{name}-%{version}/data/pptx/ppt/theme/theme2.xml
%{_datadir}/%{name}-%{version}/data/pptx/ppt/viewProps.xml
%{_datadir}/%{name}-%{version}/data/sample.lua
%{_datadir}/%{name}-%{version}/data/templates/article.jats_publishing
%{_datadir}/%{name}-%{version}/data/templates/default.asciidoc
%{_datadir}/%{name}-%{version}/data/templates/default.asciidoctor
%{_datadir}/%{name}-%{version}/data/templates/default.commonmark
%{_datadir}/%{name}-%{version}/data/templates/default.context
%{_datadir}/%{name}-%{version}/data/templates/default.docbook4
%{_datadir}/%{name}-%{version}/data/templates/default.docbook5
%{_datadir}/%{name}-%{version}/data/templates/default.dokuwiki
%{_datadir}/%{name}-%{version}/data/templates/default.dzslides
%{_datadir}/%{name}-%{version}/data/templates/default.epub2
%{_datadir}/%{name}-%{version}/data/templates/default.epub3
%{_datadir}/%{name}-%{version}/data/templates/default.haddock
%{_datadir}/%{name}-%{version}/data/templates/default.html4
%{_datadir}/%{name}-%{version}/data/templates/default.html5
%{_datadir}/%{name}-%{version}/data/templates/default.icml
%{_datadir}/%{name}-%{version}/data/templates/default.jats_archiving
%{_datadir}/%{name}-%{version}/data/templates/default.jats_articleauthoring
%{_datadir}/%{name}-%{version}/data/templates/default.jats_publishing
%{_datadir}/%{name}-%{version}/data/templates/default.jira
%{_datadir}/%{name}-%{version}/data/templates/default.latex
%{_datadir}/%{name}-%{version}/data/templates/default.man
%{_datadir}/%{name}-%{version}/data/templates/default.markdown
%{_datadir}/%{name}-%{version}/data/templates/default.mediawiki
%{_datadir}/%{name}-%{version}/data/templates/default.ms
%{_datadir}/%{name}-%{version}/data/templates/default.muse
%{_datadir}/%{name}-%{version}/data/templates/default.opendocument
%{_datadir}/%{name}-%{version}/data/templates/default.opml
%{_datadir}/%{name}-%{version}/data/templates/default.org
%{_datadir}/%{name}-%{version}/data/templates/default.plain
%{_datadir}/%{name}-%{version}/data/templates/default.revealjs
%{_datadir}/%{name}-%{version}/data/templates/default.rst
%{_datadir}/%{name}-%{version}/data/templates/default.rtf
%{_datadir}/%{name}-%{version}/data/templates/default.s5
%{_datadir}/%{name}-%{version}/data/templates/default.slideous
%{_datadir}/%{name}-%{version}/data/templates/default.slidy
%{_datadir}/%{name}-%{version}/data/templates/default.tei
%{_datadir}/%{name}-%{version}/data/templates/default.texinfo
%{_datadir}/%{name}-%{version}/data/templates/default.textile
%{_datadir}/%{name}-%{version}/data/templates/default.xwiki
%{_datadir}/%{name}-%{version}/data/templates/default.zimwiki
%{_datadir}/%{name}-%{version}/data/templates/styles.html
%{_datadir}/%{name}-%{version}/data/translations/*.yaml

%files -n ghc-%{name} -f ghc-%{name}.files
%license COPYING.md

%files -n ghc-%{name}-devel -f ghc-%{name}-devel.files
%doc AUTHORS.md README.md changelog.md

%changelog
* Tue May 12 2020 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Add _constraints file to avoid OOM build failures
* Wed May  6 2020 psimons@suse.com
- Update pandoc to version 2.9.2.1.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/pandoc-2.9.2.1/src/changelog.md
* Thu Feb 27 2020 psimons@suse.com
- Update pandoc to version 2.9.2.
  [#]# pandoc 2.9.2 (2020-02-15)
  * Add `csv` as an input format (#6100).  The CSV table is converted into a
    pandoc simple table.  A new module Text.Pandoc.Readers.CSV
    exports `readCSV` [API change].
  * Introduce new format variants for JATS writer (#6014, Albert Krewinkel):
  - `jats_archiving` for the "Archiving and Interchange Tag Set",
  - `jats_publishing` for the "Journal Publishing Tag Set", and
  - `jats_articleauthoring` for the "Article Authoring Tag Set."
    The `jats` output format is now an alias for `jats_archiving`.
    The module Text.Pandoc.Writers.JATS now exports
    `writeJatsArchiving`, `writeJatsPublishing`, and
    `writeJatsArticleAuthoring`, as well as the legacy
    `writeJATS` [API change].
  * `--defaults`: Support `bibliography` and `csl` fields.
    Move `addMeta` from Text.Pandoc.App.CommandLineOptions to
    Text.Pandoc.App.Opt (internal change).
  * Add timing info for filters in `--verbose` mode (#6112).
    When verbose mode is specified (verbosity == INFO), print a
    notice when running a filter and when a filter completes (including
    timing).
  * LaTeX reader:
    + Allow `&` in LaTeX citation keys (#6110).
    + Improve caption and label parsing.
    + Don't emit empty Span elements for labels.
    + Put tables with labels in a surrounding Div.
    + Resolve `\ref` to table numbers (#6137).
    + Skip comments in more places where this is needed (#6114).
    + Allow beamer overlays for all commands in all raw tex (#6043).
    This affects parsing of raw tex in LaTeX and in Markdown and
    other formats.
    + Improve parsing of raw environments (#6034).  If parsing fails
    in a raw environment (e.g. due to special characters like unescaped
    `_`), try again as a verbatim environment, which is less sensitive to
    special characters.  This allows us to capture special environments
    that change catcodes as raw tex when `-f latex+raw_tex` is used.
  * RST reader:
    + Add highlight directive (#6140, Lucas Escot).
  * MediaWiki writer:
    + Prevent triple `[[[` which confuses MediaWiki (#6119).
  * HTML reader:
    + Don't parse `data-id` as `id` attribute.  And similarly don't
    parse any `data-X` as `X` when `X` is a valid HTML attribute.
  * Org reader:
    + Simplify parsing of sub- and superscripts (#6127, Albert Krewinkel).
    Speeds up parsing of single-word, markup-less sub- and superscripts.
  * LaTeX writer:
    + Group biblatex citations even with prefix and suffix (#5849, Ethan
    Riley).  Previously biblatex citations were only grouped if there
    was no prefix.  This patch allows them to be grouped in subgroups split
    by prefixes and suffixes, which allows better citation sorting.
    + Fix regression in handling of columns in beamer slides (#6033).
    Columns in title slides were causing problems with
    slide division.
    + Fix duplicate frame classes in LaTeX/Beamer output (#6107).
  * HTML writer:
    + Fix duplicate attributes on headings (#6062), regression from 2.7.x.
    + Fix `--number-offset` with HTML TOC.  Eventually it would be worth
    adding a parameter to `makeSections` so this could be done at that
    level; then it would also affect other writers that construct
    TOC manually.
    + reveal.js: restore old behavior for 2D nesting (#6032).
    The fix to #6030 actually changed behavior, so that the
    2D nesting occurred at slide level N-1 and N, instead of
    at the top-level section.  This commit restores the v2.7.3 behavior.
    If there are more than 2 levels, the top level is horizontal
    and the rest are collapsed to vertical.
    + reveal.js: ensure that pauses work even in title slides (#5819).
  * Markdown writer:
    + Fix regression: spurious dots in markdown_mmd metadata output (#6133).
  * Docx writer:
    + Fix regression with Compact style on tight lists (#6072).
    Starting in 2.8, the docx writer no longer distinguishes between tight
    and loose lists, since the Compact style is omitted.  This is a
    side-effect of the fix to #5670, as explained in the changelog.  This
    patch fixes the problem by extending the exception currently offered to
    Plain blocks inside tables to Plain blocks inside list items.
  * Jira writer:
    + Fix output of table headers (Albert Krewinkel, #6035).
  * Add Text.Pandoc.Image with unexported svgToPng.
  * Moved html5Attributes, html4Attributes, rdfaAttributes
    from T.P.Writers.HTML (where they were unexported) to
    T.P.XML (where they are now exported).
    [API change: new exported functions]
    This allows these sets to be used elsewhere, e.g.
    in the HTML reader.
  * Text.Pandoc.Shared: Export a new function `findM` (#6125,
    Joseph C. Sible).
  * Text.Pandoc.Logging: Add `RunningFilter`, `FilterCompleted`
    constructors to LogMessage [API change].
  * Text.Pandoc.CSV: fix bug in CSV parser; previously an extra blank record
    would sometimes be inserted at the end.
  * LaTeX template: add space option to xeCJK with PassOptionsToPackage
    (#6002).  Otherwise we can get a clash with documentclasses that
    already load the package.
  * Lua filters:
    + Allow filtering of element lists (#6038, Albert Krewinkel).  Lists of
    Inline and Block elements can now be filtered via `Inlines` and
    `Blocks` functions, respectively. This is helpful if a filter
    conversion depends on the order of elements rather than a single
    element.  For example, the following filter can be used to remove all
    spaces before a citation:
    function isSpaceBeforeCite (spc, cite)
    return spc and spc.t == 'Space'
    and cite and cite.t == 'Cite'
    end
    function Inlines (inlines)
    for i = #inlines-1,1,-1 do
    if isSpaceBeforeCite(inlines[i], inlines[i+1]) then
    inlines:remove(i)
    end
    end
    return inlines
    end
    + Add methods `insert`, `remove`, and `sort` to pandoc.List
    (Albert Krewinkel).  Example of use:
    local numbers = pandoc.List {2, 3, 1}
    numbers:sort()     -- numbers is now {1, 2, 3}
    + Make `pandoc.List` a callable constructor (Albert Krewinkel).
    It is now possible to construct a new List via
    `pandoc.List()` instead of `pandoc.List:new()`.
    + Add tests for pandoc.List module (Albert Krewinkel).
  * Text.Pandoc.App.CommandLineOptions: Change `setVariable` to use `Text`
    instead of `String`.  This avoids some unnecessary unpacking.
  * Use versioned directory for windows release zipfile.
    Also remove old `make-windows-installer.bat`, superseded by GitHub
    actions workflow, and modify `pandoc.wxs` for new paths.
  * Extensive code cleanup (#6141, #6128, #6129, #6130, #6123,
    [#6105], 6102, #6117, #6124, #6115, #6116, #6111, Joseph C. Sible).
  * Fix hlint warnings (Albert Krewinkel).
  * Use latest doclayout, doctemplates (#6031).  The new version of
    doclayout fixes a memory leak that affected `--include-in-header` with
    large files (and possibly other cases involving extremely long lines).
  * Use latest texmath.
  * Use latest skylighting and fix test suite (#6086).
  * sample.lua: Fix typo in descriptive comments (#6136, Caleb Maclennan).
    Fix typo in error message (#6135).
  * Add Docker and GH Actions instructions/links to INSTALL.md.
  * Update filter documentation (#6065). Improve cabal v2 instructions.
    Remove example using pandoc API directly (we have other
    docs for that and it was outdated).
  * Lua filter docs:
    + Cross-link constructors and types (Albert Krewinkel).
    Thanks to @bpj for the idea.
    + Sort pandoc.List methods alphabetically (Albert Krewinkel).
    + Unify, fix anchors and internal links (#6061, Albert Krewinkel).
    Links and anchors now follow consistent conventions, like
    lowercase-only anchor names.  This breaks some links to specific
    sections in the document, but will make it much easier to link
    documentation in the future.
    + Clarify filter function execution order (#6059, Albert Krewinkel).
  * In docs, update URLs and use `https:` wherever possible (#6090,
    Salim B).
* Tue Jan  7 2020 psimons@suse.com
- Update pandoc to version 2.9.1.1.
  [#]# pandoc 2.9.1.1 (2020-01-05)
  * Markdown reader:
    + Fix parsing bug affected indented code after raw HTML (#6009, #5360).
  * LaTeX writer:
    + Fix regression in beamer slide structure with certain slide levels
    (#6030).
    + Allow framebreaks for beamer's TOC (Heiko Schlittermann, #6012)
    + Properly handle unnumbered headings level 4+ (#6018).
    Previously the `\paragraph` command was used instead of
    `\paragraph*` for unnumbered level 4 headings.
  * HTML writer:
    + Fix revealjs slide structure regression with certain slide levels
    (#6030).
    + Add newlines to make slide show output more readable.
  * Org writer:
    + Remove extra spaces from table cells (Albert Krewinkel, #6024).
  * JATS template: Update JATS dtd (Arfon Smith, #6020).  Use the archiving
    and interchange DTD rather than the more restrictive journal publishing
    DTD (which doesn't permit ext-link as a valid child).
  * Text.Pandoc.PDF: Fix `runTeXProgram` so that the input source is always
    overwritten (#6027).  Previously it wasn't overridden if the file already
    existed, which led to bad results on subsequent runs when
    `pdf-engine-opt=-output-directory=` was used to specify an explicit temp
    dir.
  * Text.Pandoc.BCP47: Change `getLang` to handle block-level contents
    (#6008).  Some readers (e.g. RST) will populate the `lang` metadata field
    with block-level content.  `getLang` has been modified to handle this.
    Previously in these cases the LaTeX writer would not properly set the
    "main language" of the document.
  * Fix `test/tables.org` (Albert Krewinkel).
  * Use HTTPS in copyright message (Felix Yan, #6010)
* Sun Dec 29 2019 psimons@suse.com
- Update pandoc to version 2.9.1.
  * Add Jira reader (Albert Krewinkel, #5556).
  * Jira writer: use jira-wiki-markup renderer (Albert Krewinkel,
    [#5926]). The following improvements are included in this change:
    + non-jira raw blocks are fully discarded instead of showing
    as blank lines;
    + table cells can contain multiple blocks;
    + unnecessary blank lines are removed from the output;
    + markup chars within words are properly surrounded by
    braces;
    + preserving soft linebreaks via `--wrap=preserve` is
    supported.
    Note that backslashes are rendered as HTML entities, as there
    appears no alternative to produce a plain backslash if it is
    followed by markup. This may cause problems when used with
    confluence, where rendering seems to fail in this case.
  * Fix regression with `--number-sections`. Starting with 2.8,
    `--number-sections` also had the effect of `--section-divs`,
    even if `--section-divs` was not specified.
  * Improved table of contents generation in markdown, RTF,
    commonmark, better handling cases where section headings are
    enclosed in divs.
  * Ensure that later default file values for `variable` replace
    earlier ones (5988).
  * HTML reader: Add `nav` to list of block-level tags.
  * Org reader (Albert Krewinkel):
    + Wrap named table in Div, using name as id (#5984).
    Tables which are given a name via `#+NAME:` or `#+LABEL:`
    are wrapped in an additional Div, with the name set as the
    Div's ID.
    + Report parsing errors properly.
    + Fix parsing problem for colons in headline (#5993).
  * Text.Pandoc.PDF: Ensure UTF8 when printing source in
    `--verbose` mode, avoiding an error on platforms that
    default to something other than UTF-8 (#5997).
  * Text.Pandoc.Templates: Strip directory before trying to find
    partial in data files (#5987).
  * Text.Pandoc.Shared: Improve `makeSections` so we don't get
    doubled "number" attributes in EPUB output (or anywhere
    else) (#5986).
  * Added tests for `--toc` and `--section-divs`.
  * Text.Pandoc.MIME: Added glsl MIME type for WebGL maps (#6000,
    Jared Lander).
  * MANUAL: A bit clearer explanation for `--base-header-level`.
    We now say exactly how to translate between the deprecated
    `--base-header-level` and `--shift-heading-level-by`.
  * lua-filters.md:
    + Remove spurious dot in title (#5996, Mauro Bieg).
    + Replace metadata example with image centering (#6004,
    Albert Krewinkel). Thanks to @efx for proposing this filter.
* Fri Dec 13 2019 psimons@suse.com
- Update pandoc to version 2.9.
  [#]# pandoc 2.9 (PROVISIONAL)
  * Text.Pandoc.Templates [API change]
    + Add Monad wrappers `WithDefaultPartials` and `WithPartials`.
    Wrapping these around an instance of `PandocMonad` gives
    us different instances of `TemplateMonad`, with different
    search behavior in retrieving partials.
    To compile a template and limit partial search to pandoc's
    data files, use `runWithDefaultPartials (compileTemplate ...)`.
    To compile a template and allow partials to be found locally
    (either on the file system or via HTTP, in the event that
    the main template has an absolute URL), ue
    `runWithPartials (compileTemplate ...)`.
    + Export `getTemplate`, which seeks a template locally,
    or via HTTP if the template has an absolute URL, falling
    back to the data files if not found.
    + Export `compileDefaultTemplate` -- does `getDefaultTemplate`
    and compiles the result, raising an error on failure.
  * Text.Pandoc.Class [API change]
    + Remove `TemplateMonad` instances for `PandocIO` and `PandocPure`.
    These were too limiting and caused a bug whereby a local
    partial could be used even when the default template was requested.
    We now rely on instances provided in the Templates module.
  * Text.Pandoc.App.OutputSettings: Simplify template retrieval code.
  * ConTeXt template: Adjust to title formatting (#5949, Denis Maier).
    Add `\setupinterlinespace` to `title`, `subtitle`, `date` and `author`
    elements:  otherwise longer titles that run over multiple lines will look
    squashed as `\tfd` etc. won't adapt the line spacing to the font size.
  * reveal.js template: Add title-slide-attributes variable (#5981,
    Frederik Elwert).
  * More informative JSON parse error (#5973).
  * Use external emojis package (forked from pandoc).  Removed emoji data
    in Text.Pandoc.Emoji.
  * Fix regression in `makeSections` (#5965).
    Previously `hierarchicalize` (the ancestor of `makeSections`) would put
    header attributes on the containing Div.  In 2.8 this behavior changed,
    which broke some tools depending on pandoc.  Here we roll back this change,
    so that attributes again migrate from the header to the containing Div when
    `makeSections` is run.  Note that attributes are retained on the header as
    well (unlike before) -- with the exception of the `id` attribute, which of
    course cannot be duplicated.
  * Fix `--toc-depth` regression in 2.8 (#5967).
  * Use doctemplates 0.8.  Rename template 'filters' as 'pipes'
    to avoid confusion with the other notion of filter used by pandoc.
  * Fix README.md so that relative links from manual become absolute.
    Previously they'd be broken links when viewed on GitHub or Hackage.
    So we add the base URL for the pandoc manual.
  * Document display math syntax in manual.
* Sun Dec  8 2019 psimons@suse.com
- Update pandoc to version 2.8.1.
  [#]# pandoc 2.8.1 (2019-12-05)
  * Add `ascii_identifiers` as a supported extension for `markdown`.
    This fixes a regression in 2.8.
  * Fix regression with behavior of `--variable` (#5962).
    Previously `-Vfoo=1 -Vfoo=2` would produce a list value for foo;
    with 2.8 it produced just `2`.  This commit restores the earlier
    behavior.
  * Roll back part of of `--shift-heading-level-by` change (#5957).
    With positive heading shifts, starting in 2.8 this option
    caused metadata titles to be removed and changed to regular
    headings.  This behavior is incompatible with the old
    behavior of `--base-header-level` and breaks old workflows,
    so we have rolled back the change. Note that there is now an
    asymmetry in positive and negative heading level shifts:
    With positive shifts, the metadata title stays the same and
    does not get changed to a heading in the body, while with
    negative shifts, a heading can be converted into the
    metadata title.
  * Text.Pandoc.Shared: Fix `makeSections` so it doesn't turn
    column Divs into sections.
  * HTML writer: add task-list class to ul if all elements are
    task list items.  This will allow styling unordered task
    lists in a way that omits the bullet.
  * HTML-based templates: Add CSS to suppress bullet on unordered task lists.
  * ConTeXt template: Fix `\startcslreferences` and use ConTeXt syntax
    conventions (#5945, Denis Maier).  The old version had a too large
    a skip at the beginning of the reference list.
  * LaTeX template: keep the `\author{}` command even if author is not
    specified (#5961, Yihui Xie).  Avoids a LaTeX warning.
  * Generate Emoji module with TH.
    + Add Text.Pandoc.Emoji.TH.
    + Replace long literal list in Text.Pandoc.Emoji with one-liner
    generating it from `emoji.json` using TH.
    + Add Makefile target to download `emoji.json`.
    + Remove `tools/emoji.hs`.
  * Increase GC allocation space for compilation in cabal.project.
  * Clean up manual on PDF generation backend options (#5940).
  * Update release checklist to include code signing step and update
    Windows release-candidate builds (#5950).
* Sun Dec  1 2019 psimons@suse.com
- Update pandoc to version 2.8.0.1.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/pandoc-2.8.0.1/src/changelog.md
* Sat Nov 23 2019 psimons@suse.com
- Update pandoc to version 2.8.
  Upstream has renamed and modified the change log file(s) in this
  release. Unfortunately, the automatic updater cannot reliable
  determine relevant entries for this release.
* Fri Nov  8 2019 Peter Simons <psimons@suse.com>
- Drop obsolete group attributes.
* Fri Jun 14 2019 psimons@suse.com
- Update pandoc to version 2.7.3.
  pandoc (2.7.3)
  * Add `jira` (Atlassian's Jira wiki markup) as output format (#2497,
    Albert Krewinkel).
  * Add `tex_math_dollars` to `multimarkdownExtensions` (#5512).
    This form is now supported in multimarkdown,
    in addition to `tex_math_double_backslash`.
  * Fix `--self-contained` so it works when output format has extensions.
    Previously if you used `--self-contained` with `html-smart` or
    `html+smart`, it wouldn't work.
  * Add template variable `curdir` with working directory
    from which pandoc is run (#5464).
  * Markdown reader: don't create implicit reference for empty header
    (#5549).
  * Muse reader: allow images inside link descriptions (Alexander Krotov).
  * HTML reader: epub related fixes.
    + With epub extensions, check for `epub:type` in addition to `type`.
    + Fix problem with noteref parsing which caused block-level
    content to be eaten with the noteref.
    + Rename `pAnyTag` to `pAny`.
    + Refactor note resolution.
    + Trim definition list terms (Alexander Krotov).
  * LaTeX reader:
    + Add braces when resolving `\DeclareMathOperator`
    (#5441).  These seem to be needed for xelatex but not pdflatex.
    + Allow newlines in `\mintinline`.
    + Pass through unknown listings language as class (#5540).
    Previously if the language was not in the list of languages supported
    by listings, it would not be added as a class, so highlighting
    would not be triggered.
    + `rawLaTeXInline`: Include trailing `{}`s in raw latex commands (#5439).
    This change affects the markdown reader and other readers that allow raw
    LaTeX.  Previously, trailing `{}` would be included for unknown
    commands, but not for known commands.  However, they are sometimes used
    to avoid a trailing space after the command.  The chances that a `{}`
    after a LaTeX command is not part of the command are very small.
  * MediaWiki reader: handle multiple attributes in table row (#5471,
    chinapedia).
  * Docx reader: Add support for `w:rtl` (#5545).  Elements with this
    property are put into Span inlines with `dir="rtl"`.
  * DocBook reader: Issue `IgnoredElement` warnings.
  * Org reader (Albert Krewinkel):
    + Fix planning elements in headers level 3 and higher
    (#5494).  Planning info is now always placed before
    the subtree contents.  Previously, the planning info was placed after
    the content if the header's subtree was converted to a list, which
    happens with headers of level 3 and higher per default.
    + Omit, but warn about unknown export options.  Unknown export
    options are properly ignored and omitted from the output.
    + Prefer plain symbols over math symbols (#5483).
    Symbols like `\alpha` are output plain and unemphasized, not as math.
    + Recognize emphasis after TODO/DONE keyword (#5484).
  * FB2 reader:
    + Skip unknown elements rather than throwing errors (#5560).
    Sometimes custom elements are used (e.g. `id` element
    inside `author`); previously the reader would halt with an error.
    Now it skips the element and issues an `IgnoredElement` warning.
    + Parse notes (#5493, Alexander Krotov).
    + Internal improvements (Alexander Krotov).
  * OpenDocument writer:  Roll back automatic figure/table numbering
    (#5474).  This was added in pandoc 2.7.2, but it makes it impossible
    to use pandoc-crossref. So this has been rolled back for now,
    until we find a good solution to make this behavior optional
    (or a creative way to let pandoc-crossref and this feature
    to coexist).
  * New module Text.Pandoc.Writers.Jira, exporting `writeJira` [API
    change] (Albert Krewinkel).
  * EPUB writer:
    + Don't include 'landmarks' if there aren't any.
    Previously we could get an empty ol element, which caused
    validation errors with epubcheck.
    + Ensure unique ids for styleesheets in content.opf (#5463).
    + Make stylesheet link compatible with kindlegen (#5466,
    Eric Schrijver).  Pandoc omitted `type="text/css"` from both
    `<style>` and `<rel="stylesheet">` elements in all templates, which
    is valid according to the spec. However, Amazon’s kindlegen software
    relies on this attribute on `<link>` elements when detecting
    stylesheets to include.
  * HTML writer:
    + Output video and audio elements depending on file
    extension of the image path (Mauro Bieg).
    + Emit empty alt tag in figures (#5518, Mauro Bieg).
    The same text is already in the <figcaption> and
    screen-readers would read it twice, see #4737.
    + Don't add variation selector if it's already there.
    This fixes round-trip failures.
    + Prevent gratuitious emojification on iOS (#5469).
    iOS chooses to render a number of Unicode entities, including '↩', as
    big colorful emoji.  This can be defeated by appending Unicode VARIATION
    SELECTOR-15'/'VARIATION SELECTOR-16'.  So we now append this character
    when escaping strings, for both '↩' and '↔'.  If other characters prove
    problematic, they can simply be added to `needsVariationSelector`.
    + Add `class="heading"` to level 7+ Headers rendered as `<p>` elements
    (#5457).
  * RST writer: treat Span with no attributes as transparent (#5446).
    Previously an Emph inside a Span was being treated as
    nested markup and ignored.  With this patch, the Span
    is just ignored.
  * LaTeX writer:
    + Include inline code attributes with `--listings` (#5420).
    + Don't produce columns environment unless beamer (#5485).
    + Fix footnote in image caption.  Regression: the fix for #4683 broke
    this case.
    + Don't highlight code in headings (#5574).  This causes
    compilation errors.
    + Use `\mbox` to get proper behavior inside `\sout` (#5529).
  * EPUB writer: Fix document section assignments (#5546).
    For example, introduction should go in bodymatter, not frontmatter, and
    epigraph, conclusion, and afterward should go in bodymatter, not
    backmatter.  For the full list of assignments, see the manual.
  * Markdown writer:
    + Add backslashes to avoid unwanted interpretation of
    definition list terms as other kinds of block (#554).
    + Ensure the code fence is long enough (#5519).
    Previously too few backticks were used when the code block
    contained an indented line of backticks.  (Ditto tildes.)
    + Handle labels with integer names (Jesse Rosenthal, #5495).
    Previously if labels had integer names, it could produce a conflict
    with auto-labeled reference links. Now we test for a conflict and
    find the next available integer.  This involves adding a new state
    variable `stPrevRefs` to keep track of refs used in other document
    parts when using `--reference-location=block|section`
  * Textile writer: fix closing tag for math output (Albert Krewinkel).
    Opening and closing tag for math output match now.
  * Org writer: always indent src blocks content by 2 spaces (#5440, Albert
    Krewinkel).  Emacs always uses two spaces when indenting the content of
    src blocks, e.g., when exiting a `C-c '` edit-buffer. Pandoc used to
    indent contents by the space-equivalent of one tab, but now always uses
    two spaces, too.
  * Asciidoc writer:
    + Use `` `+...+` `` form for inline code.
    The old `` `a__b__c` `` yields emphasis inside code in asciidoc.
    To get a pure literal code span, use `` `+a__b__c+` ``.
    + Use proper smart quotes with asciidoctor (#5487).
    Asciidoctor has a different format for smart quotes.
    + Use doubled ## when necessary for spans (#5566).
    + Ensure correct nesting of strong/emph (#5565): strong
    must be the outer element.
  * JATS writer:
    + Wrap elements with p when needed (#5570).  The JATS spec restricts
    what elements can go inside `fn` and `list-item`.  So we wrap other
    elements inside `<p specific-use="wrapper">` when needed.
    + Properly handle footnotes (#5511) according to "best practice."
    (Group them at the end in `<fn-group>` and use `<xref>` elements
    to link them.)
    + Fix citations with PMID so they validate (#5481).  This includes
    an update to data/jats.csl.
    + Ensure validity of `<pub-date>` by parsing the date and
    extracting year, month, and day, as expected.  Also add an
    iso-8601-date attribute automatically.
    + Don't use `<break>` element for LineBreak. It is only
    allowed in a few special contexts, and not in `<p>` elements.
    + Don't make `<string-name>` a child of `<string>`, which is illegal.
  * FB2 writer:
    + Do not wrap note references into `<sup>` and brackets
    (Alexander Krotov).  Existing FB2 readers, such as FBReader, already
    display links with type="note" as a superscript.
    + Use genre metadata field (#5478).
  * Muse writer: do not escape empty line after `<br>` (Alexander Krotov).
  * Add unicode code point in "Missing character" warning (#5538).
    If the character isn't in the console font, the message is pretty useless,
    so we show the code point for anything non-ASCII.
  * Lua: add Version type to simplify comparisons (Albert Krewinkel).
    Version specifiers like `PANDOC_VERSION` and `PANDOC_API_VERSION` are
    turned into `Version` objects. The objects simplify version-appropriate
    comparisons while maintaining backward-compatibility.
    A function `pandoc.types.Version` is added as part of the newly
    introduced module `pandoc.types`, allowing users to create version
    objects in scripts.
  * pandoc lua module (Albert Krewinkel):
  - Fix deletion of nonexistent attributes (#5569).
  - Better tests for Attr and AttributeList.
  * pandoc.mediabag lua module (Albert Krewinkel):
    + Add function `delete` for deleting a single item.
    + Add function `empty` for removing all entries.
    + Add function `items` for iterating over mediabag.
  * Text.Pandoc.Class: Fix handling of `file:` URL scheme in
    `downloadOrRead` (#5517, Mauro Bieg).  Previously `file:/`
    URLs were handled wrongly and pandoc attempted to make HTTP
    requests, which failed.
  * Text.Pandoc.MIME: add `mediaCategory` [API change] (Mauro Bieg).
  * Text.Pandoc.Shared:
    + Add `onlySimpleTableCells` [API change]
    (Mauro Bieg) and use this to consolidate simple-table detection
    (#5524).  This fixes an inconsistency in the HTML reader, which did not
    treat tables with `<p>` inside cells as simple.
    + `metaToJSON`: treat digits starting with 0 as a string, not a number
    (#5479).  This fixes a regression in YAML metadata in pandoc 2.7.2.
  * Text.Pandoc.Logging: Add `IgnoredElement` constructor for
    `LogMessage`.  `SkippedConetnt` doesn't work for some XML-based
    readers which don't have access to parsec source positions.
  * Text.Pandoc.Asciify: Add Turkish undotted-i (#5433, Mauro Bieg).
  * Improve output of Lua tests (#5499, Albert Krewinkel).
    This makes use of tasty-lua, a package to write tests in Lua
    and integrate the results into Tasty output. Test output becomes
    more informative: individual tests and test groups become visible
    in test output. Failures are reported with helpful error messages.
  * Lua: add `pandoc.system` module (#5468, Albert Krewinkel).
    The `system` Lua module provides utility functions to interact with the
    operating- and file system. E.g.
    `print(pandoc.system.get_current_directory())`
    or
    ```lua
    pandoc.system.with_temporary_directory('tikz', function (dir)
  - - write and compile a TikZ file with pdflatex
    end)
    ```
  * LaTeX template: Add pdflang to hypersetup if lang is set (#5443).
  * beamer template: Fix using Beamer with geometry (#5505, Daniel Maslowski).
    Beamer already loads geometry, so we need to use the `\geometry`
    command to set geometry options.
  * EPUB2/3 templates: Move inline styles to default epub.css (#5466).
    NOTE: Those who use a custom CSS stylesheet with EPUB should
    add these lines:
    code{ white-space: pre-wrap; }
    span.smallcaps{ font-variant: small-caps; }
    span.underline{ text-decoration: underline; }
    q { quotes: "“" "”" "‘" "’"; }
    div.column{ display: inline-block; vertical-align: top; width: 50%%; }
  * reveal.js template:
    + Updates for revealjs 3.8.0 (#5435, ebiim).
    + Remove reference to head.min.js (#5448, Winnie Hellmann).
    NOTE: users will need to update reveal.js to at least 3.8.0
    for their presentations generated with this version of pandoc
    to work correctly.
  * Text.Pandoc.PDF:
    + Replace `</>` with literal `/` (#5451).
    We use forward-slash for a directory separator in tmpDir,
    even on Windows (because that's what tex likes).  So we
    should not put a backslash between the tmpDir and the
    filename on Windows.  This is harmless enough in normal
    Windows setups, but it breaks on Cygwin.
    Thanks to @cc2x for noticing and diagnosing the problem.
    + Allow use of `-output-directory` in `--pdf-engine-opt` (#5462).
    This is currently possible with `mklatex` and `-outdir`, but
    was not yet possible with xelatex and `-output-directory`.
    + For PDF via ms/pdfroff, make TOC appear at beginning and in
    PDF bookmarks (#5553).  Previously the TOC appeared at the end
    of the document, and was not bookmarked.  To keep it at the end,
    add `--pdf-engine-opt=--no-toc-relocation` to your command line.
  * Fix broken links in documents (#5473, Shim Myeongseob).
    Also, use absolute links to pandoc.org when possible, so that
    the links can be followed by people viewing these documents
    on GitHub.
  * Improved sample lua tikz filter in lua-filters docs (#5445,
    Matthew Doty).  There are three changes:
    + It only processes elements which begin with `\begin{tikzpicture}`
    + It uses pdf2svg instead of imagemagick to preserve fidelity
    + The images produced have transparent backgrounds
  * MANUAL.txt:
    + Add note about `title-meta`, `author-meta`, `date-meta` (#5486).
    + Fix typo (#5489, Christian Krause).
  * add test/tables.xwiki to git and pandoc.cabal (#5498, Mauro Bieg).
  * Disable missing-home-modules warning in `stack.yaml`.
    Otherwise `stack ghci` fails.
* Thu May 16 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update _constraints
* Sun Apr  7 2019 psimons@suse.com
- Update pandoc to version 2.7.2.
  pandoc (2.7.2)
  * Add XWiki writer (#1800, Derek Chen-Becker).
    Add `Text.Pandoc.Writers.XWiki`, exporting `writeXWiki` [API change].
  * Dokuwiki Reader: parse single curly brace (#5416, Mauro Bieg).
  * Vimwiki reader: improve handling of internal links (#5414).
    We no longer append `.html` to link targets, and we add a title
    `wikilink`.  This mirrors behavior of other wiki readers.  Generally
    the `.html` extension is not wanted.  It may be important for output
    to HTML in certain circumstances, but it can always be added using a
    filter that matches on links with title `wikilink`.
    If your workflow requires the current behavior, here is a lua filter
    that will add the `.html` extension:
    ```lua
    function Link(el)
    if el.title == 'wikilink' then
    el.target = el.target .. ".html"
    end
    return el
    end
    ```
  * ipynb reader:
    + Use format `ipynb` for raw cell where no format given.
    + Avoid introducing spurious `.0` on integers in metadata.
  * Markdown reader: fenced div takes priority over setext header.
  * HTML reader: read `data-foo` attribute into `foo` (#5392).
    The HTML writer adds the `data-` prefix for HTML5 for nonstandard
    attributes.  But the attributes are represented in the AST without
    the `data-` prefix, so we should strip this when reading HTML.
  * LaTeX reader: Improve autolink detection (#5340).
  * PowerPoint writer (Jesse Rosenthal):
    + Expand builtin reference doc to model all layouts.
    The previous built-in reference doc had only title and content
    layouts. Add in a section-header slide and a two-content slide, so
    users can more easily modify it to build their own templates.
    + Always open up in slide view.  When editing a
    template/reference-doc, the user might be in Master view, but when
    producing a slide show, it is assumed that slide view will be
    desired.
    + Remove `handoutsMasterList` from template presentation.xml
    + Fix numerous errors in templating (#5402). Previously, some templates
    produced by Office 365 (MacOS) would not render with `--reference-doc`
    correctly. We now apply correct shapes for content, and build
    shape trees correctly.
    + Make default placeholder type for template lookup.
    + Apply speaker notes to metadata slide if applicable.
    + Test for speaker notes after breaking header.
    + Correctly handle notes after section-title header.
    Previously, if notes came after a section-title header (ie, a level-1
    header in a slide-level=2 presentation), they would go on the next
    slide. This keeps them on the slide with the header.
    + Internal improvements.
  * ipynb writer:
    + Use format `ipynb` for raw cell where no format given.
    According to nbformat docs, this is supposed to render in every
    format.  We don't do that, but we at least preserve it as a raw
    block in markdown, so you can round-trip.
    + Consolidate adjacent raw blocks.  Sometimes pandoc creates two
    HTML blocks, e.g. one for the open tag and one for a close tag.
    If these aren't consolidated, only one will show up in output cell.
    + Fixed carry-over of nbformat from metadata.
    + Preserve `nbformat_minor` if it's given.  This helps with round-tripping.
  * LaTeX writer:
    + Avoid inadvertently creating ?` or !` ligatures (#5407).
    These are upside down ? and !, resp.
    + Fix footnotes in table caption and cells (#5367).  This fixes a
    bug wherein footnotes appeared in the wrong order, and with
    duplicate numbers, when in table captions and cells.
    We now use regular `\footnote` commands, even in the table
    caption and the minipages containing cells. Apparently
    longtable knows how to handle this.
  * HTML writer: Don't add data- prefix to RDFa attributes (#5403).
  * JATS writer: Ensure that plain strings go inside `<pub-id>` tag (#5397).
  * Markdown writer:
    + Better rendering of numbers (#5398).  If the number is integral,
    we render it as an integral not a float.
    + Proper rendering of empty map in YAML metadata (#5398).  Should
    be `{}`, not empty string.
    + Properly escape attributes in Markdown writer (#5369).
    + Be sure implicit figures work in list contexts (#5368).
    Previously they would sometimes not work: e.g., when they
    occured in final paragraphs in lists that were originally
    parsed as Plain and converted later using PlainToPara.
  * Docx writer: Use `w:br` without attributes for line breaks (#5377).
    We previously added the attribute `type="textWrapping"`, but
    this causes problems on Word Online.
  * LaTeX template (Andrew Dunning):
    + Ensure correct heading/table order (#5365).  Improve workaround
    (#1658) for tables following headings.  The new solution works whether
    or not the `indent` variable is enabled.
    + Remove `subparagraph` variable. The default is now to use run-in
    style for level 4 and 5 headings (`\paragraph` and `\subparagraph`).
    To get the previous default behavior (where these were formatted as
    blocks, like `\subsubsection`), set the `block-headings` variable.
    + Add pandoc to PDF metadata (#5388).
    + Group graphics-related code (#5389).
    + Move `\setstretch` after front matter (#5179).  Ensures that
    `\maketitle`, `\tableofcontents`, and so forth are not affected by
    changes to line spacing.
  * Update data/jats.csl to avoid commas between name-part elements
    (#5397).
  * Add support for golang (`go`) with `--listings` (#5427).
  * Text.Pandoc.Shared - improve `metaToJSON` behavior with numbers.
    We now do a better job marshalling numbers from MetaString
    or MetaInlines into JSON Number.
  * Text.Pandoc.Writers.Shared: `metaValueToJSON`: use Number Values for
    integers.  Pandoc's MetaValue doesn't have a distinguished number type,
    so numbers are put in MetaStrings.  If the MetaString consists
    entirely of digits, we convert it to a Number.  We should probably
    consider adding a MetaNumber constructor to MetaValue, for better
    round-tripping with JSON etc.  This change aids round-tripping in
    ipynb metadata fields, like `toc_depth`.
  * Text.Pandoc.Class: `fetchItem`: don't treat UNC paths as
    protocol-relative URLs (#5127).  These are paths beginning `//?/UNC/...`.
  * Text.Pandoc.ImageSize: Improve `pdfSize` so it handles
    a wider range of PDFs (#4322, with help from Richard Davis).
  * Text.Pandoc.Pretty: avoid stack overflow by using strict sum (#5401).
  * Fix harmless error in file-scope code (#5422).
  * MANUAL.txt:
    + Improve 'header' and 'heading' usage (#5423, Andrew
    Dunning).  The term 'header' was being used where 'heading'
    is more appropriate.
    + Add paragraph on options affecting markdown in ipynb.
  * stack.yaml - remove -Wmissing-home-modules
    This seems to cause problems with stack ghci.  Remove RTS options.
  * Add ghc-options to cabal.project.
  * appveyor.yml - use ghc 8.6.4.  Fixes segfault issues on Windows (#5037).
  * linux build process: Remove clone of pandoc-citeproc (#5366).
    It wasn't being used; cabal.project specifies the version to use.
* Fri Mar 15 2019 psimons@suse.com
- Update pandoc to version 2.7.1.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/pandoc-2.7.1/src/changelog
* Mon Mar  4 2019 psimons@suse.com
- Update pandoc to version 2.7.
  Upstream has edited the change log file since the last release in
  a non-trivial way, i.e. they did more than just add a new entry
  at the top. You can review the file at:
  http://hackage.haskell.org/package/pandoc-2.7/src/changelog
* Fri Feb  1 2019 psimons@suse.com
- Update pandoc to version 2.6.
  pandoc (2.6) PROVISIONAL
  * Support ipynb (Jupyter notebook) as input and output format.
    + Add `ipynb` as input and output format (extension `.ipynb`).
    + Added Text.Pandoc.Readers.Ipynb [API change].
    + Added Text.Pandoc.Writers.Ipynb [API change].
    + Add `PandocIpynbDecodingError` constructor to Text.Pandoc.Error.Error
    [API change].
    + Depend on ipynb library.
    + Note: there is no template for ipynb.
  * Add DokuWiki reader (#1792, Alexander Krotov).  This adds
    Text.Pandoc.Readers.DokuWiki [API change], and adds `dokuwiki`
    as an input format.
  * Implement task lists (#3051, Mauro Bieg). Added `task_lists`
    extension. Task lists are supported from markdown and gfm input.
    They should work, to some degree, in all output formats, though in
    most formats you'll get a bullet list with a unicode character for
    the box. In HTML, you get checkboxes and in LaTeX/PDF output, a
    box is used as the list marker. API changes:
    + Added constructor `Ext_task_lists` to `Extension`.
    + Added `taskListItemFromAscii` and `taskListItemToAscii` to
    Text.Pandoc.Shared.
  * Allow some command line options to take URL in addition to FILE.
    `--include-in-header`, `--include-before-body`, `--include-after-body`.
  * HTML reader:
    + Handle empty `start` attribute (see #5162).
    + Treat `textarea` as a verbatim environment (#5241) and preserve
    spacing.
  * RST reader:
    + Change treatment of `number-lines` directive (Brian Leung,
    [#5207]). Directives of this type without numeric inputs should
    not have a `startFrom` attribute; with a blank value, the
    writers can produce extra whitespace.
    + Removed superfluous `sourceCode` class on code blocks (#5047).
    + Handle `sourcecode` directive as synonynm for `code` (#5204).
  * Markdown reader:
    + Remove `sourceCode` class for literate Haskell code blocks
    (#5047). Reverse order of `literate` and `haskell` classes on
    code blocks when parsing literate Haskell, so `haskell` is
    first.
    + Treat `<textarea>` as a verbatim environment (#5241).
  * Org reader:
    + Handle `minlevel` option differently (#5190, Brian Leung).
    When `minlevel` exceeds the original minimum level observed in
    the file to be included, every heading should be shifted
    rightward.
    + Allow for case of `:minlevel == 0` (#5190).
    + Fix treatment of links to images (#5191, Albert Krewinkel).
    Links with descriptions which are pointing to images are no
    longer parsed as inline images, but as links.
    + Add support for #+SELECT_TAGS (Brian Leung).
    + Separate filtering logic from conversion function (Brian Leung).
  * TWiki reader: Fix performance issue with underscores (#3921).
  * MediaWiki reader: use `_` instead of `-` in auto-identifiers (#4731).
    We may not still be exactly matching mediawiki's algorithm.
  * LaTeX reader:
    + Remove `sourceCode` class for literate Haskell code blocks
    (#5047). Reverse order of `literate` and `haskell` classes on
    code blocks when parsing literate Haskell, so `haskell` is
    first.
    + Support `\DeclareMathOperator` (#5149).
    + Support `\inputminted` (#5103).
    + Support `\endinput` (#5233).
    + Allow includes with dots like `cc_by_4.0`.  Previously the `.0`
    was interpreted as a file extension, leading pandoc not to add
    `.tex` (and thus not to find the file).  The new behavior matches
    tex more closely.
  * Man reader:
    + Use `mapLeft` from Shared instead of defining own.
  * Docx reader (Jesse Rosenthal):
    + Handle level overrides (#5134).
  * Docx writer:
    + Support custom properties (#3024, #5252, Agustín Martín Barbero).
    Also supports additional core properties:  `subject`, `lang`,
    `category`, `description`.
    + Make Level into a real type, instead of an alias for a tuple
    (Jesse Rosenthal).
  * ICML writer (Mauro Bieg):
    + Support custom-styles (#5137, see #2106).
    + Support unnumbered headers (#5140).
  * Texinfo writer: Use header identifier for anchor if present (#4731).
    Previously we were overwriting an existing identifier with a new one.
  * Org writer: Preserve line-numbering for example and code blocks
    (Brian Leung).
  * Man/Ms writers: Don't escape `-` as `\-`. The `\-` gets rendered
    in HTML and PDF as a unicode minus sign.
  * Ms writer: Ensure we have a newline after .EN in disply math (#5251).
  * RST writer: Don't wrap simple table header lines (#5128).
  * Asciidoc writer: Shorter delimiters for tables, blockquotes
    (#4364). This matches asciidoctor reference docs.
  * Dokuwiki writer: Remove automatic `:` prefix before internal image
    links (#5183, Damien Clochard).  This prevented users from making
    relative image links.
  * Zimwiki writer: remove automatic colon prefix before internal
    images (#5183, Damien Clochard).
  * MediaWiki writer: fix caption, use 'thumb' instead of 'frame'
    (#5105). Captions used to have the word 'caption' prepended; this
    has been removed. Also, 'thumb' is used instead of 'frame' to
    allow images to be resized.
  * reveal.js writer:
    + Ensure that we don't get > 2 levels of section nesting,
    even with slide level > 2 (#5168).
    + If slide level == N but there is no N-level header, make
    sure the next header with level > N gets treated as a slide
    and put in a section, rather than remaining loose (#5168).
  * Markdown writer:
    + Make `plain` RawBlocks pass through in `plain` output.
    + Include needed whitespace after HTML figure (#5121).
    We use HTML for a figure in markdown dialects that can't
    represent it natively.
  * Commonmark writer:
    + Fix handling of SoftBreak with `hard_line_breaks` (#5195).
    + Implement `--toc` (`writerTableOfContents`)
    in commonmark/gfm writers (#5172).
  * EPUB writer:
    + Ensure that picture transforms are done on metadata too.
    + Small fixes to `nav.xhtml`:
    Add 'landmarks' id attribute to the landmarks nav.
    Replace old default CSS removing numbers from ol.toc li
    with new rules that match `nav#toc ol, nav#landmarks ol`.
    We keep the `toc` class on `ol` for backwards compatibility.
  * LaTeX writer:
    + Make raw content marked `beamer` pass through in `beamer`
    output (pandoc/lua-filters#40).
    + Beamer: avoid duplicated `fragile` property in some cases
    (#5208).
    + Add `#` special characters for listings (#4939).
    This character needs special handling in `\lstinline`.
  * RTF writer: use `toTableOfContents` from Shared to replace
    old duplicated code.
  * Pptx writer:
    + Support custom properties.  Also supports additional core
    properties: `subject`, `category`, `description` (#5252,
    Agustín Martín Barbero).
    + Use `toTableOfContents` from Shared to replace old duplicated code.
  * ODT writer (Augustín Martín Barbero):
    + Fix typo in custom properties (#2839).
    + Improve standard properties, including the following core
    properties: `generator` (Pandoc/VERSION), `description`, `subject`,
    `keywords`, `initial-creator` (from authors), `creation-date`
    (actual creation date) (#5252).
  * Custom writers:
    + Allow '-' in filenames for custom lua writers (#5187).
    + sample.lua: add `SingleQuoted`, `DoubleQuoted` (#5104).
    + sample.lua: Add a missing `>` (MichaWiedenmann).
  * reveal.js template:  Add `zoomKey` config (#4249).
  * HTML5 template: Remove unnecessary type="text/css" on style and
    link for HTML5 (#5146).
  * LaTeX template (Andrew Dunning, except where noted):
    + Prevent fontspec from scaling `mainfont` to match the default
    font, Latin Modern. A main font set to 12pt could
    previously appear between 11pt to 13pt depending on its design.
    To return to the earlier rendering, use `-V
    mainfontoptions="Scale=MatchLowercase"` (#5212, #5218).
    + Display monospaced fonts without TeX ligatures when using
    `--pdf-engine=lualatex`. It now matches the behaviour of other
    engines (#5212, #5218).
    + Remove the deprecated `romanfont` variable. The functionality of
    `mainfont` is identical (#5218).
    + Render `\subtitle` with the standard document classes.
    Previously, `subtitle` only appeared when using the KOMA-Script
    classes or Beamer (#5213, #5244).
    + Use Babel instead of Polyglossia for LuaLaTeX. This avoids
    several language selection problems, notably with retaining
    French spacing conventions when switching to a verbatim
    environment or another language; and in printing Greek text
    without hyphenation (#5193).
    + Use the [`xurl`](https://ctan.org/pkg/xurl) package if
    available, improving the appearance of URLs by allowing them to
    break at additional points (#5193).
    + Use [`bookmark`](https://ctan.org/pkg/bookmark) if available
    to correct heading levels in PDF bookmarks: see the [KOMA-Script
    3.26 release notes](https://komascript.de/release3.26) (#5193).
    + Require the [`xcolor`](https://ctan.org/pkg/xcolor) package to
    avoid a possible error when using additional packages alongside
    footnotes in tables (#5193, closes #4861).
    + Remove obsolete `fixltx2e` package, which has no functionality
    with TeX Live 2015 or later (#5193).
    + Allow multiple `fontfamilies.options` (#5193, closes #5194).
    + Restrict `institute` variable to Beamer (#5219).
    + Use [`footnotehyper`](https://ctan.org/pkg/footnotehyper)
    package if available to make footnotes in tables compatible
    with `hyperref` (#5234).
    + Number parts and chapters in book classes only if the
    `numbersections` variable is set, for consistency with other
    output formats. To return to the previous behaviour, use
    `-V numbersections -V secnumdepth=0` (#5235).
    + Reindent file (#5193).
    + Use built-in parskip handling with KOMA-Script classes (#5143, Enno).
    + Set default listings language for lua, assembler (#5227, John
    MacFarlane).  Otherwise we get an error when trying to compile code
    with lua or assembler code.  To change the default dialect
    (currenty 5.3 for lua and x86masm for assembler), you can use
    `--include-in-header` to inject something like
    `\lstset{defaultdialect=[5.2]Lua}`.
  * Text.Pandoc.Readers: Changed types of `readJSON`; it now runs
    in an instance of PandocMonad, like the other readers and
    writers.  [API change]
  * Text.Pandoc.Writers: Changed types of `writeJSON`; it now runs
    in an instance of PandocMonad, like the other readers and
    writers.  [API change]
  * Text.Pandoc.Error: Added `PandocUTF8DecodingError` constructor
    for `PandocError`. [API change]
  * Text.Pandoc.Writers.Shared - add `toTableOfContents`. [API change]
    This is refactored out from the Markdown writer.
    It can be used in other writers to create a table of contents.
  * Improve error messages for UTF-8 decoding errors. Now we give
    the filename and byte offset (#4765).
  * Text.Pandoc.XML: Strip out illegal XML characters in
    `escapeXMLString` (#5119).
  * Text.Pandoc.Process: update `pipeProcess` (Albert Krewinkel).
    The implementation of `pipeProcess` was rewritten to fix sporadic
    failures caused by prematurely closed pipes.
  * Use `safeRead` instead of `read` everywhere in the code
    (John MacFarlane, Mauro Bieg, #5162, #5180).
  * Text.Pandoc.SelfContained: Decompress `.svgz` when
    converting to `data:` URI (#5163, Alexander Krotov).
  * Text.Pandoc.Parsing: Remove unused `HasHeaderMap`
    (#5175, Alexander Krotov). [API change]
  * Normalize Windows paths to account for change in ghc 8.6 (#5127).
    When pandoc is compiled with ghc 8.6, Windows paths are treated
    differently, and paths beginning `\\server` no longer work.
    This commit rewrites such patsh to `\\?\UNC\server` which works.
    The change operates at the level of argument parsing, so it
    only affects the command line program.
  * Simplify/fix reading of `--metadata` values on command line
    to avoid problems relating to hvr/HsYAML#7 (#5177).
  * data/pandoc.lua: auto-fix nested constructor arguments (Albert
    Krewinkel).  Incorrect types to pandoc element constructors are
    automatically converted to the correct types when possible. This was
    already done for most constructors, but conversions are now also done
    for nested types (like lists of lists).
  * Removed custom Setup.hs, use build-type: simple. The only thing we
    gained from the custom build was automatic installation of the man
    page when using 'cabal install'. But custom builds cause problems,
    e.g., with cross-compilation. Installation of the man page is
    better handled by packagers. Note to packagers (e.g. Debian): it
    may be necessary to add a step installing the man page with the
    next release.
  * Allow latest http-client, tasty, zip-archive, Glob.
  * Require skylighting >= 0.7.5, adding support for sml, J,
    typescript.
  * Tests:  Cleaned up `findPandoc` in `Tests.Helpers`, so it
    works well with cabal v2.
  * INSTALL.md:
    + Use button for installer links (John MacFarlane, Mauro Bieg,
    [#5167]).
    + Fix links and bump required stack version (max).
    + Improve installation notes on associated software (Andrew
    Dunning). Includes explanation of how to install related tools
    with package managers (since the method of installing
    `rsvg-convert` is not obvious).
  * doc/org.md: improve documentation of org features (Albert
    Krewinkel).
  * doc/lua-filters.md:  use 3rd level headers for module fields.
  * MANUAL:
    + Clarify automatic identifiers (#5201). We remove
    non-alphanumerics. This includes, e.g., emojis.
    + Fix example for Div with id (Geoffrey Ely).
    + Update list of LaTeX packages used.
    + Make it clear that `hard_line_breaks` works in `gfm` (see #5195).
    + Mention `raw_attribute` in documentation for `raw_html` and
    `raw_tex` (#5240, thanks to @eiro).
    + Clarify that `$sep$` must come right before `$endfor$` in templates
    (#5243, Lev Givon).
    + Document metadata support for docx, odt, pptx writers (Agustín
    Martín Barbero).
    + Reorganize template variables (#5249, Andrew Dunning).
    Add additional headings to categorize variables, and
    alphabetize when there is large number; add more examples.
    + Document `date-meta` template variable (#5260, Tristan Stenner).
  * trypandoc: Fix CSS and viewport.
* Mon Jan 14 2019 Peter Simons <psimons@suse.com>
- Patch build to cope with with recent versions of 'http-client'.
* Fri Jan 11 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Increase required memory in _constraints to avoid OOM failures
* Wed Dec  5 2018 Peter Simons <psimons@suse.com>
- Update Cabal build instructions to support zip-archive 0.4.
* Tue Nov 27 2018 psimons@suse.com
- Update pandoc to version 2.5.
  * Text.Pandoc.App: split into several unexported submodules (Albert
    Krewinkel):  Text.Pandoc.App.FormatHeuristics,
    Text.Pandoc.App.Opt, Text.Pandoc.App.CommandLineOptions,
    Text.Pandoc.App.OutputSettings.  This is motivated partly by the
    desire to reduce recompilations when something is modified,
    since App previously depended on virtually every other module.
  * Text.Pandoc.Extensions
    + Semantically, `gfm_auto_identifiers` is now a modifier of
    `auto_identifiers`; for identifiers to be set, `auto_identifiers` must
    be turned on, and then the type of identifier produced depends on
    `gfm_auto_identifiers` and `ascii_identifiers` are set. Accordingly,
    `auto_identifiers` is now added to `githubMarkdownExtensions` (#5057).
    + Remove `ascii_identifiers` from `githubMarkdownExtensions`.
    GitHub doesn't seem to strip non-ascii characters any more.
  * Text.Pandoc.Lua.Module.Utils (Albert Krewinkel)
    + Test AST object equality via Haskell (#5092).  Equality of Lua
    objects representing pandoc AST elements is tested by unmarshalling
    the objects and comparing the result in Haskell.
    A new function `equals` which performs this test has been added to the
    `pandoc.utils` module.
    + Improve stringify.  Meta value strings (MetaString)
    and booleans (MetaBool) are now converted to the literal string and the
    lowercase boolean name, respectively. Previously, all values of these
    types were converted to the empty string.
  * Text.Pandoc.Parsing: Remove Functor and Applicative constraints where Monad
    already exists (Alexander Krotov).
  * Text.Pandoc.Pretty: Don't render BreakingSpace at end of line
    or beginning of line (#5050).
  * Text.Pandoc.Readers.Markdown
    + Fix parsing of citations, quotes, and underline emphasis
    after symbols.  Starting with pandoc 2.4, citations, quoted inlines,
    and underline emphasis were no longer recognized after certain
    symbols, like parentheses (#5099, #5053).
    + In pandoc 2.4, a soft break after an abbreviation would be
    relocated before it to allow for insertion of a nonbreaking
    space after the abbreviation. This behavior is here reverted.
    A soft break after an abbreviation will remain, and no nonbreaking
    space will be added. Those who care about this issue should take care not
    to end lines with an abbreviation, or to insert nonbreaking spaces
    manually.
  * Text.Pandoc.Readers.FB2: Do not throw error for unknown elements in
    `<body>` (Alexander Krotov).  Some libraries include custom elements
    in their FB2 files.
  * Text.Pandoc.Readers.HTML
    + Allow `tfoot` before body rows (#5079).
    + Parse `<small>` as a Span with class "small" (#5080).
    + Allow thead containing a row with `td` rather than `th` (#5014).
  * Text.Pandoc.Readers.LaTeX
    + Cleaned up handling of dimension arguments.  Allow decimal points,
    preceding space.
    + Don't allow arguments for verbatim, etc.
    + Allow space before bracketed options.
    + Allow optional arguments after `\\` in tables.
    + Improve parsing of `\tiny`, `\scriptsize`, etc.  Parse as raw,
    but know that these font changing commands take no arguments.
  * Text.Pandoc.Readers.Muse
    + Trim whitespace before parsing grid table cells (Alexander Krotov).
    + Add grid tables support (Alexander Krotov).
  * Text.Pandoc.Shared
    + For bibliography match Div with id `refs`, not class `references`.
    This was a mismatch between pandoc's docx, epub, latex, and markdown
    writers and the behavior of pandoc-citeproc, which actually looks for a
    div with id `refs` rather than one with class `references`.
    + Exactly match GitHub's identifier generating algorithm (#5057).
    + Add parameter for `Extensions` to `uniqueIdent` and
    `inlineListToIdentifier` (#5057).  [API change]
    This allows these functions to be sensitive to the settings of
    `Ext_gfm_auto_identifiers` and `Ext_ascii_identifiers`, and allows us to
    use `uniqueIdent` in the CommonMark reader, replacing custom code.  It
    also means that `gfm_auto_identifiers` can now be used in all formats.
  * Text.Pandoc.Writers.AsciiDoc
    + Use `.`+ as list markers to support nested ordered lists (#5087).
    + Support list number styles (#5089).
    + Render Spans using `[#id .class]#contents#` (#5080).
  * Text.Pandoc.Writers.CommonMark
    + Respect `--ascii` (#5043, quasicomputational).
    + Make sure `--ascii` affects quotes, super/subscript.
  * Text.Pandoc.Writers.Docx
    + Fix bookmarks to headers with long titles (#5091).
    Word has a 40 character limit for bookmark names.  In addition, bookmarks
    must begin with a letter.  Since pandoc's auto-generated identifiers may
    not respect these constraints, some internal links did not work.  With
    this change, pandoc uses a bookmark name based on the SHA1 hash of the
    identifier when the identifier isn't a legal bookmark name.
    + Add bookmarks to code blocks (Nikolay Yakimov).
    + Add bookmarks to images (Nikolay Yakimov).
    + Refactor common bookmark creation code into a function (Nikolay Yakimov).
  * Text.Pandoc.Writers.EPUB: Handle calibre metadata (#5098).
    Nodes of the form
    <meta name="calibre:series" content="Classics on War and Politics"/>
    are now included from an epub XML metadata file.  You can also include
    this information in your YAML metadata, like so:
    calibre:
    series: Classics on War and Policitics
    In addition, ibooks-specific metadata can now be included via an XML
    file. (Previously, it could only be included via YAML metadata, see
    [#2693].)
  * Text.Pandoc.Writers.HTML: Use plain `"` instead of `&quot;` outside of
    attributes.
  * Text.Pandoc.Writers.ICML: Consolidate adjacent strings, inc. spaces.
    This avoids splitting up the output unnecessarily into separate elements.
  * Text.Pandoc.Writers.LaTeX: Don't emit `[<+->]` unless beamer output, even
    if `writerIncremental` is True (#5072).
  * Text.Pandoc.Writers.Muse (Alexander Krotov).
    + Output tables as grid tables if they have multi-line cells.
    + Indent simple tables only on the top level.
    + Output tables with one column as grid tables.
    + Add support for `--reference-location`.
    + Internal improvements.
  * Text.Pandoc.Writers.OpenDocument: Fix list indentation (Nils Carlson,
    [#5095]).  This was a regression in pandoc 2.4.
  * Text.Pandoc.Writers.RTF: Fix warnings for skipped raw inlines.
  * Text.Pandoc.Writers.Texinfo: Add blank line before `@menu` section (#5055).
  * Text.Pandoc.XML: in `toHtml5Entities`, prefer shorter entities
    when there are several choices for a particular character.
  * data/abbreviations
    + Add additional abbreviations (Andrew Dunning)
    Many of these borrowed from the Chicago Manual of Style 10.42,
    'Scholarly abbreviations'.
  * Templates
    + Asciidoc template:  add :lang: to title header is lang is set in
    metadata (#5088).
  * pandoc.cabal: Add cabal flag `derive_json_via_th` (Albert Krewinkel)
    Disabling the flag will cause derivation of ToJSON and FromJSON
    instances via GHC Generics instead of Template Haskell. The flag is
    enabled by default, as deriving via Generics can be slow (see #4083).
  * trypandoc:
    + Tweaked drop-down lists.
    + Put link to site in footer.
    + Preselect output format.
    + Update on change of in or out format.
    + Add man input format.
  * MANUAL.txt:
    + Fix outdated description of latex_macros extension.
    + Clarified placement of bibliography.
    + Added "A note on security."
    + Fix note on curly brace syntx for locators.
    + Document new explicit syntax for citeproc locators.
    + Remove confusing cross-links for some extensions.
    + Don't put pandoc in code ticks in heading.
    + Document that `--ascii` works for gfm and commonmark too.
    + Add `man` to `--from` options.
  * doc/customizing-pandoc.md: various improvements (Mauro Bieg).
* Mon Nov  5 2018 psimons@suse.com
- Update pandoc to version 2.4.
  pandoc (2.4)
    [new features]
  * New input format `man` (Yan Pashkovsky, John MacFarlane).
    [behavior changes]
  * `--ascii` is now implemented in the writers, not in Text.Pandoc.App,
    via the new `writerPreferAscii` field in `WriterOptions`.
    Now the `write*` functions for Docbook, HTML, ICML, JATS, LaTeX,
    Ms, Markdown, and OPML are sensitive to `writerPreferAscii`.
    Previously the to-ascii translation was done in Text.Pandoc.App,
    and thus not available to those using the writer functions
    directly.
  * `--ascii` now works with Markdown output.  HTML5 character reference
    entities are used.
  * `--ascii` now works with LaTeX output. 100%% ASCII output can't be
    guaranteed, but the writer will use commands like `\"{a}` and `\l`
    whenever possible, to avoid emiting a non-ASCII character.
  * For HTML5 output, `--ascii` now uses HTML5 character reference
    entities rather than numerical entities.
  * Improved detection of format based on extension (in Text.Pandoc.App).
    We now ensure that if someone tries to convert a file for a
    format that has a pandoc writer but not a reader, it won't just
    default to markdown.
  * Add viz. to abbreviations file (#5007, Nick Fleisher).
  * AsciiDoc writer:  always use single-line section headers,
    instead of the old underline style (#5038).  Previously the single-line
    style would be used if `--atx-headers` was specified, but
    now it is always used.
  * RST writer: Use simple tables when possible (#4750).
  * CommonMark (and gfm) writer: Add plain text fallbacks. (#4528,
    quasicomputational). Previously, the writer would unconditionally
    emit HTML output for subscripts, superscripts, strikeouts (if the
    strikeout extension is disabled) and small caps, even with
    `raw_html` disabled. Now there are plain-text (and, where
    possible, fancy Unicode) fallbacks for all of these corresponding
    (mostly) to the Markdown fallbacks, and the HTML output is only
    used when `raw_html` is enabled.
  * Powerpoint writer: support raw openxml (Jesse Rosenthal, #4976).
    This allows raw openxml blocks and inlines to be used in the pptx
    writer. Caveats: (1) It's up to the user to write
    well-formed openxml. The chances for corruption, especially with
    such a brittle format as pptx, is high. (2) Because of
    the tricky way that blocks map onto shapes, if you are using
    a raw block, it should be the only block on a slide
    (otherwise other text might end up overlapping it). (3) The
    pptx ooxml namespace abbreviations are different from the
    docx ooxml namespaces. Again, it's up to the user to get it
    right. Unzipped document and ooxml specification should be
    consulted.
  * With `--katex` in HTML formats, do not use the autorenderer (#4946).
    We no longer surround formulas with `\(..\)` or `\[..\]`. Instead,
    we tell katex to convert the contents of span elements with
    class "math". Since math has already been identified, this
    avoids wasted time parsing for LaTeX delimiters. Note, however,
    that this may yield unexpected results if you have span elements
    with class "math" that don't contain LaTeX math.
    Also, use latest version of KaTeX by default (0.9.0).
  * The man writer now produces ASCII-only output, using groff escapes,
    for portability.
  * ODT writer:
    + Add title, author and date to metadata; any remaining
    metadata fields are added as `meta:user-defined` tags.
    + Implement table caption numbering (#4949, Nils Carlson).
    Captioned tables are numbered and labeled with format "Table 1:
    caption", where "Table" is replaced by a translation, depending
    on the value of `lang` in metadata. Uncaptioned tables are not
    enumerated.
    + OpenDocument writer: Implement figure numbering in captions (#4944,
    Nils Carlson). Figure captions are now numbered 1, 2, 3, ...
    The format in the caption is "Figure 1: caption" and so on
    (where "Figure" is replaced by a translation, depending on the
    value of `lang` in the metadata). Captioned figures are numbered
    consecutively and uncaptioned figures are not enumerated. This
    is necessary in order for LibreOffice to generate an
    Illustration Index (Table of Figures) for included figures.
  * RST reader: Pass through fields in unknown directives as div attributes
    (#4715). Support `class` and `name` attributes for all directives.
  * Org reader: Add partial support for `#+EXCLUDE_TAGS` option. (#4284,
    Brian Leung). Headers with the corresponding tags should not
    appear in the output.
  * Log warnings about missing title attributes now include a
    suggestion about how to fix the problem (#4909).
  * Lua filter changes (Albert Krewinkel):
    + Report traceback when an error occurs. A proper Lua traceback is
    added if either loading of a file or execution of a filter
    function fails. This should be of help to authors of Lua filters
    who need to debug their code.
    + Allow access to pandoc state (#5015). Lua filters and custom
    writers now have read-only access to most fields of pandoc's
    internal state via the global variable `PANDOC_STATE`.
    + Push ListAttributes via constructor (Albert Krewinkel).
    This ensures that ListAttributes, as present in OrderedList elements,
    have additional accessors (viz. `start`, `style`, and `delimiter`).
    + Rename ReaderOptions fields, use snake_case. Snake case is used
    in most variable names, using camelCase for these fields was an
    oversight. A metatable is added to ensure that the old field
    names remain functional.
    + Iterate over AST element fields when using `pairs`. This makes
    it possible to iterate over all ield names of an AST element by
    using a generic `for` loop with pairs`:
    for field_name, field_content in pairs(element) do
    ...
    end
    Raw table fields of AST elements should be considered an
    implementation detail and might change in the future. Accessing
    element properties should always happen through the fields
    listed in the Lua filter docs.
    Note that the iterator currently excludes the `t`/`tag` field.
    + Ensure that MetaList elements behave like Lists. Methods usable
    on Lists can also be used on MetaList objects.
    + Fix MetaList constructor (Albert Krewinkel). Passing a MetaList
    object to the constructor `pandoc.MetaList` now returns the
    passed list as a MetaList. This is consistent with the
    constructor behavior when passed an (untagged) list.
  * Custom writers: Custom writers have access to the global variable
    `PANDOC_DOCUMENT`(Albert Krewinkel, #4957). The variable contains
    a userdata wrapper around the full pandoc AST and exposes two
    fields, `meta` and `blocks`. The field content is only
    marshaled on-demand, performance of scripts not accessing the
    fields remains unaffected.
    [API changes]
  * Text.Pandoc.Options: add `writerPreferAscii` to `WriterOptions`.
  * Text.Pandoc.Shared:
    + Export `splitSentences`. This was previously duplicated in the Man and
    Ms writers.
    + Add `ToString` typeclass (Alexander Krotov).
  * New exported module Text.Pandoc.Filter (Albert Krewinkel).
  * Text.Pandoc.Parsing
    + Generalize `gridTableWith` to any `Char` Stream (Alexander Krotov).
    + Generalize `readWithM` from `[Char]` to any `Char` Stream
    that is a `ToString` instance (Alexander Krotov).
  * New exposed module Text.Pandoc.Filter (Albert Krewinkel).
  * Text.Pandoc.XML: add `toHtml5Entities`.
  * New exported module Text.Pandoc.Readers.Man (Yan Pashkovsky, John
    MacFarlane).
  * Text.Pandoc.Writers.Shared
    + Add exported functions `toSuperscript` and
    `toSubscript` (quasicomputational, #4528).
    + Remove exported functions `metaValueToInlines`,
    `metaValueToString`. Add new exported functions
    `lookupMetaBool`, `lookupMetaBlocks`, `lookupMetaInlines`,
    `lookupMetaString`. Use these whenever possible for uniformity
    in writers (Mauro Bieg, #4907). (Note that
    removed function `metaValueToInlines` was in previous
    released versions.)
    + Add `metaValueToString`.
  * Text.Pandoc.Lua
    + Expose more useful internals (Albert Krewinkel):
  - `runFilterFile` to run a Lua filter from file;
  - data type `Global` and its constructors; and
  - `setGlobals` to add globals to a Lua environment.
    This module also contains `Pushable` and `Peekable` instances
    required to get pandoc's data types to and from Lua. Low-level
    Lua operation remain hidden in Text.Pandoc.Lua.
    + Rename `runPandocLua` to `runLua` (Albert Krewinkel).
    + Remove `runLuaFilter`, merging this into Text.Pandoc.Filter.Lua's
    `apply` (Albert Krewinkel).
    [bug fixes and under-the-hood improvements]
  * Text.Pandoc.Parsing
    + Make `uri` accept any stream with Char tokens (Alexander Krotov).
    + Rewrite `uri` without `withRaw` (Alexander Krotov).
    + Generalize `parseFromString` and `parseFromString'` to any
    streams with Char token (Alexander Krotov)
    + Rewrite `nonspaceChar` using `noneOf` (Alexander Krotov)
  * Text.Pandoc.Shared: Reimplement `mapLeft` using `Bifunctor.first`
    (Alexander Krotov).
  * Text.Pandoc.Pretty: Simplify `Text.Pandoc.Pretty.offset`
    (Alexander Krotov).
  * Text.Pandoc.App
    + Work around HXT limitation for --syntax-definition with windows
    drive (#4836).
    + Always preserve tabs for man format. We need it for tables.
    + Split command line parsing code into a separate unexported
    module, Text.Pandoc.App.CommandLineOptions (Albert Krewinkel).
  * Text.Pandoc.Readers.Roff: new unexported module for tokenizing
    roff documents.
  * New unexported module Text.Pandoc.RoffChar, provided character
    escape tables for roff formats.
  * Text.Pandoc.Readers.HTML: Fix `htmlTag` and `isInlineTag` to
    accept processing instructions (#3123, regression since 2.0).
  * Text.Pandoc.Readers.JATS: Use `foldl'` instead of `maximum` to
    account for empty lists (Alexander Krotov).
  * Text.Pandoc.Readers.RST: Don't allow single-dash separator in
    headerless table (#4382).
  * Text.Pandoc.Readers.Org: Parse empty argument array in inline src
    blocks (Brian Leung).
  * Text.Pandoc.Readers.Vimwiki:
    + Get rid of `F`, `runF` and `stateMeta'` in favor of `stateMeta`
    (Alexander Krotov).
    + Parse `Text` without converting to `[Char]` (Alexander Krotov).
  * Text.Pandoc.Readers.Creole: Parse `Text` without converting to
    `[Char]` (Alexander Krotov).
  * Text.Pandoc.Readers.LaTeX
    + Allow space at end of math after `\` (#5010).
    + Add support for `nolinkurl` command (#4992, Brian Leung).
    + Simplified type on `doMacros'`.
    + Tokenize before pulling tokens, rather than after (#4408). This
    has some performance penalty but is more reliable.
    + Make macroDef polymorphic and allow in inline context.
    Otherwise we can't parse something like `\lowercase{\def\x{Foo}}`.
    I have actually seen tex like this in the wild.
    + Improved parsing of `\def`, `\let`. We now correctly parse:
    ```
    \def\bar{hello}
    \let\fooi\bar
    \def\fooii{\bar}
    \fooi +\fooii
    \def\bar{goodbye}
    \fooi +\fooii
    ```
    + Improve parsing of `\def` argspec.
    + Skip `\PackageError` commands (see #4408).
    + Fix bugs omitting raw tex (#4527). The default is `-raw_tex`,
    so no raw tex should result unless we explicitly say `+raw_tex`.
    Previously some raw commands did make it through.
    + Moved `isArgTok` to Text.Pandoc.Readers.LaTeX.Parsing.
    + Moved `babelLangToBCP`, `polyglossiaLangToBCP` to new module,
    Text.Pandoc.Readers.LaTeX.Lang (unexported).
    + Simplified accent code using unicode-transforms.
    New dependency on unicode-transforms package for normalization.
    + Allow verbatim blocks ending with blank lines (#4624).
    + Support `breq` math environments: `dmath`, `dgroup`, `darray`.
    This collects some of the general-purpose code from the LaTeX reader,
    with the aim of making the module smaller.
  * Text.Pandoc.Readers.Markdown
    + Fix awkward soft break movements before abbreviations (#4635).
    + Add updateStrPos in a couple places where needed.
  * Text.Pandoc.Readers.Docx: Trigger bold/italic with bCs, iCs
    (#4947). These are variants for "complex scripts" like Arabic
    and are now treated just like b, i (bold, italic).
  * Text.Pandoc.Readers.Muse (Alexander Krotov)
    + Try to parse lists before trying to parse table.
    This ensures that tables inside lists are parsed correctly.
    + Forbid whitespace after opening and before closing markup
    elements.
    + Parse page breaks.
    + Simplify `museToPandocTable` to get rid of partial functions.
    + Allow footnotes to start with empty line.
    + Make sure that the whole text is parsed.
    + Allow empty headers. Previously empty headers caused parser to
    terminate without parsing the rest of the document.
    + Allow examples to be indented with tabs.
    + Remove indentation from examples indicated by `{{{` and `}}}`.
    + Fix parsing of empty cells.
    + Various changes to internals.
    + Rewrite some parsers in applicative style.
    + Avoid tagsoup dependency.
    + Allow table caption to contain `+`.
  * Text.Pandoc.Writers.LaTeX
    + Add newline if math ends in a comment (#4880). This prevents the
    closing delimiter from being swalled up in the comment.
    + With `--listings`, don't pass through org-babel attributes (#4889).
    + With `--biblatex`, use `\autocite` when possible (#4960).
    `\autocites{a1}{a2}{a3}` will not collapse the entries. So, if
    we don't have prefixes and suffixes, we use instead
    `\autocite{a1;a2;a3}`.
    + Fix description lists contining highlighted code (#4662).
  * Text.Pandoc.Writers.Man
    + Don't wrap `.SH` and `.SS` lines (#5019).
    + Avoid unnecessary `.RS`/`.RE` pair in definition lists with
    one paragraph definitions.
    + Moved common groff functions to Text.Pandoc.Writers.Groff.
  * Fix strong/code combination on man (should be `\f[CB]` not
    `\f[BC]`, see #4973).
    + Man writer: use `\f[R]` instead of `\f[]` to reset font
    (Alexander Krotov, #4973).
    + Move `splitSentences` to Text.Pandoc.Shared.
  * Text.Pandoc.Writers.Docx
    + Add framework for custom properties (#3034). So far, we don't
    actually write any custom properties, but we have the
    infrastructure to add this.
    + Handle tables in table cells (#4953). Although this is not
    documented in the spec, some versions of Word require a `w:p`
    element inside every table cell. Thus, we add one when the
    contents of a cell do not already include one (e.g. when a table
    cell contains a table).
  * Text.Pandoc.Writers.AsciiDoc:  Prevent illegal nestings.
    Adjust header levels so that n+1 level headers are only
    found under n level headers, and the top level is 1.
  * Text.Pandoc.Writers.OpenDocument: Improve bullet/numbering
    alignment (#4385). This change eliminates the large gap we used
    to have between bullet and text, and also ensures that numbers
    in numbered lists will be right-aligned.
  * Text.Pandoc.Writers.ZimWiki
    + Number ordered list items sequentially, rather than always
    with 1 (#4962).
    + Remove extra indentation on lists (#4963).
  * Text.Pandoc.Writers.EPUB: Use metadata field `css` instead of
    `stylesheet` (Mauro Bieg, #4990).
  * Text.Pandoc.Writers.Markdown: Ensure blank between raw block and
    normal content (#4629). Otherwise a raw block can prevent a
    paragraph from being recognized as such.
  * Text.Pandoc.Writers.Ms
    + Removed old `escapeBar`. We don't need this now that we use
    `@` for math delim.
    + Moved common code to Text.Pandoc.Writers.Roff and to
    Text.Pandoc.RoffChar.
    + Move `splitSentences` to Text.Pandoc.Shared (to avoid duplication
    with the man writer).
  * Text.Pandoc.Writers.Muse (Alexander Krotov).
    + Add support for grid tables.
    + Fix Muse writer style.
    + Use `length` instead of `realLength` to calculate definition
    indentation. Muse parsers don't take character width into
    account when calculating indentation.
    + Do not insert newline before lists.
    + Use lightweight markup after `</em>` tag.
  * New unexported module Text.Pandoc.Writers.Roff, providing functions
    useful for all roff format writers (man, ms).
  * Text.Pandoc.Lua
    + Move globals handling to separate module Text.Pandoc.Lua.Global
    (Albert Krewinkel).
    + Lua filter internals: push Shared.Element as userdata (Albert
    Krewinkel). Hierarchical Elements were pushed to Lua as plain
    tables. This is simple, but has the disadvantage that marshaling
    is eager: all child elements will be marshaled as part of the
    object. Using a Lua userdata object instead allows lazy access
    to fields, causing content marshaling just (but also each time)
    when a field is accessed. Filters which do not traverse the full
    element contents tree become faster as a result.
    [default template changes]
  * LaTeX template:
    + Add variable `hyperrefoptions` (#4925, Mathias Walter).
    + Add variable `romanfont`, `romanfontoptions` (#4665, OvidiusCicero).
  * AsciiDoc template: use single-line style for title.
  * revealjs template: Fix typo in the socket.io javascript plugin (#5006,
    Yoan Blanc).
  * Text.Pandoc.Lua.Util: add missing docstring to `defineHowTo`
    (Albert Krewinkel).
  * data/pandoc.lua: add datatype ListAttributes (Albert Krewinkel)
  * data/sample.lua: replace custom pipe function with pandoc.utils.pipe
    (Albert Krewinkel).
    [documentation improvements]
  * INSTALL.md
    + Add chromeos install instructions (#4958) (Evan Pratten).
    + Add note about TinyTeX.
  * MANUAL.txt
    + Change `groff` -> `roff`.
    + Implement `--ascii` for Markdown writer.
    + Clarify LaTeX image dimensions output (Mauro Bieg).
  * doc/customizing-pandoc.md: added skeleton (Mauro Bieg, #3288).
  * doc/getting-started.md: Added title to test1.md to avoid warning.
  * doc/lua-filters.md: merge type references into main document,
    fix description of Code.text (Albert Krewinkel).
    [build infrastructure improvements]
  * Makefile
    + Makefile: added quick-cabal, full-cabal targets.
    + Make .msi download targets insensitive to order of appveyor builds.
  * Update benchmarks for ghc 8.6.1.
  * pandoc.cabal:
    + Enable more compiler warnings (Albert Krewinkel).
    + Make base lower bound 4.8.
    + Bump upper bound for QuickCheck.
    + Bump upper bound for binary.
    + Updated version bounds for containers and haddock-library (#4974).
    + Added docx/docPropos/custom.xml to cabal data-files.
    + Require skylighting 0.7.4 (#4920).
    + New dependency on unicode-transforms package for normalization.
  * Improved .travis.yml testing and test with GHC 8.6.1 (Albert Krewinkel).
  * Added `tools/changelog-helper.sh`.
  * Added test/grofftest.sh for testing the man reader on real man pages.
* Wed Oct 10 2018 psimons@suse.com
- Update pandoc to version 2.3.1.
  * RST reader:
    + Parse RST inlines containing newlines (#4912, Francesco Occhipinti).
    This eliminates a regression introduced after pandoc 2.1.1, which
    caused inline constructions containing newlines not to be recognized.
    + Fix bug with internal link targets (#4919).  They were gobbling up
    indented content underneath.
  * Markdown reader: distinguish autolinks in the AST.  With this change,
    autolinks are parsed as Links with the `uri` class. (The same is true
    for bare links, if the `autolink_bare_uris` extension is enabled.)
    Email autolinks are parsed as Links with the `email` class.  This
    allows the distinction to be represented in the AST.
  * Org reader:
    + Force inline code blocks to honor export options (Brian Leung).
    + Parse empty argument array in inline src blocks (Brian Leung).
  * Muse reader (Alexander Krotov):
    + Added additional tests.
    + Do not allow code markup to be followed by digit.
    + Remove heading level limit.
    + Simplify `<literal>` tag parsers
    + Parse Text instead of String. Benchmark shows 7%% improvement.
    + Get rid of HTML parser dependency.
    + Various code improvements.
  * ConTeXt writer: change `\` to `/` in Windows image paths (#4918).
    We do this in the LaTeX writer, and it avoids problems.
    Note that `/` works as a LaTeX path separator on Windows.
  * LaTeX writer:
    + Add support for multiprenote and multipostnote arguments
    with `--biblatex` (Brian Leung, #4930).  The multiprenotes occur before
    the first prefix of a multicite, and the multipostnotes follow the
    last suffix.
    + Fix a use of `last` that might take empty list.  If you ran with
    `--biblatex` and have an empty document (metadata but no blocks),
    pandoc would previously raise an error because of the use of
    `last` on an empty list.
  * RTF writer: Fix build failure with ghc-8.6.1 caused by missing
    MonadFail instance (Jonas Scholl).
  * ODT Writer: Improve table header row style handling (Nils Carlson).
    This changes the way styles for cells in the header row
    and normal rows are handled in ODT tables.
    Previously a new (but identical) style was generated for
    every table, specifying the style of the cells within the table.
    After this change there are two style definitions for table cells,
    one for the cells in the header row, one for all other cells.
    This doesn't change the actual styles, but makes post-processing
    changes to the table styles much simpler as it is no longer
    necessary to introduce new styles for header rows and there are
    now only two styles where there was previously one per table.
  * HTML writer:
    + Don't add `uri` class to presumed autolinks.  Formerly the `uri`
    class was added to autolinks by the HTML writer, but it had to
    guess what was an autolink and could not distinguish
    `[http://example.com](http://example.com)` from
    `<http://example.com>`.  It also incorrectly recognized
    `[pandoc](pandoc)` as an autolink.  Now the HTML writer
    simply passes through the `uri` attribute if it is present,
    but does not add anything.
    + Avoid adding extra section nestings for revealjs.
    Previously revealjs title slides at level (slidelevel - 1)
    were nested under an extra section element, even when
    the section contained no additional (vertical) content.
    That caused problems for some transition effects.
    + Omit unknown attributes in EPUB2 output.  For example,
    `epub:type` attributes should not be passed through,
    or the epub produced will not validate.
  * JATS writer: remove 'role' attribute on 'bold' and 'sc' elements (#4937).
    The JATS spec does not allow these.
  * Textile writer: don't represent `uri` class explicitly
    for autolinks (#4913).
  * Lua filters (Albert Krewinkel):
    + Cleanup filter execution code.
    + Better error on test failure.
  * HTML, Muse reader tests: reduce time taken by round-trip test.
  * Added cabal.project.
  * MANUAL: `epub:type` is only useful for epub3 (Maura Bieg).
  * Use hslua v1.0.0 (Albert Krewinkel).
  * Fix `translations/ru` to use modern Russian orthography
    (Ivan Trubach).
  * Build Windows binary using ghc 8.6.1 and cabal new-build. This
    fixes issues with segfaults in the 32-bit Windows binaries (#4283).
  * Add `--metadata-file` option (Mauro Bieg, #1960), which allows
    users to specify metadata in a YAML file, regardless of the
    input format (#1960).
  * Text.Pandoc.Writers.Shared: export `isDisplayMath` (API change).
  * Text.Pandoc.Readers.Markdown: export `yamlToMeta` (API change,
    Mauro Bieg).
  * Text.Pandoc.Readers.LaTeX.Types:
    + New type `ArgSpec` (API change).
    + Second parameter of `Macro` constructor is now `[ArgSpec]` instead of
    `Int` (API change).
  * Markdown reader:
    + Use `tex` instead of `latex` for raw tex-ish content. We can't
    always tell if it's LaTeX, ConTeXt, or plain TeX. Better just to
    use `tex` always. Note that if `context` or `latex` specifically
    is desired, you can still force that in a markdown document by
    using the raw attribute. Note that this change may affect some
    filters, if they assume that raw tex parsed by the Markdown reader
    will be RawBlock (Format `latex`). In most cases it should be
    trivial to modify the filters to accept `tex` as well.
    + Refactor and reorganize YAML code (Mauro Bieg).
    + Make `example_lists` work for interrupted lists
    without `startnum` (#4908).
  * HTML reader:
    + Parse `<script type="math/tex` tags as math (#4877).
    These are used by MathJax in some configurations.
    + Extract spaces inside links instead of trimming them
    (Alexander Krotov, #4845).
    + Added round-trip tests (Alexander Krotov).
    + Make parsing sensitive to the `raw_tex` extension (#1126). This now
    allows raw LaTeX environments, `\ref`, and `\eqref` to be parsed
    (which is helpful for translation HTML documents using MathJaX).
  * Org reader (Albert Krewinkel):
    + Respect export option `p` for planning info.  Inclusion of planning info
    (`*DEADLINE*`, `*SCHEDULED*`, and `*CLOSED*`) can be controlled via the
    `p` export option: setting the option to `t` will add all planning
    information in a *Plain* block below the respective headline.
    + Org reader internals: don't rely on RecordWildCards and ViewPatterns
    ghc extensions.
    + Strip planning info from output.  Planning info is parsed, but not
    included in the output (as is the default with Emacs Org-mode, #4867).
  * LaTeX reader:
    + Split some general-purpose definitions into a separate, unexported
    module, Text.Pandoc.Readers.LaTeX.Parsing.  This is to avoid
    out-of-memory errors compiling the LaTeX reader.
    + Handle parameter patterns for `\def` (#4768, #4771).
    For example:  `\def\foo#1[#2]{#1 and #2}`.
    + Allow `%%` characters in URLs. This affects `\href` and `\url` (#4832).
    + Fixed parsing of `\texorpdfstring`. We were returning the wrong
    argument as the content.
    + Support `blockcquote`, `foreignblockquote`, `foreigncblockquote`,
    `hyphenblockquote`, `hyphencblockquote`, `enquote*`, `foreignquote`,
    `hyphenquote` from `csquotes` (#4848). Note that `foreignquote`
    will be parsed as a regular Quoted inline (not using the quotes
    appropriate to the foreign language).
    + Support more text-mode accents (#4652). Add support for `\|`, `\b`, `\G`,
    `\h`, `\d`, `\f`, `\r`, `\t`, `\U`, `\i`, `\j`, `\newtie`,
    `\textcircled`. Also fall back to combining characters when composed
    characters are not available.
    + Resolve `\ref` for figure numbers.
    + Support `mintinline` (#4365, Marc Schreiber).
    + Fix siunitx unit commands so they are only recognized in
    siunitx contexts (#4842). For example, `\l` outside of an
    siunitx context should be l-slash, not l (for liter).
    + Fix double `unnumbered` class (#4838). The `unnumbered` class
    was being included twice for starred sections.
  * RST reader: Don't skip link definitions after comments (#4860).
  * Muse reader (Alexander Krotov):
    + Close the `</quote>` in indented tag test.
    There is already a separate test for unclosed `</quote>`.
    + Autonumber sections in the correct order.  Parsing now stops
    at each section header to ensure the header is registered before
    parsing of the next section starts.
    + Move duplicate code into `headingStart` function.
    + Allow newline after opening `*` or `**`.
    + Don't allow digits after closing marker in lightweight markup
    This change makes reader more compatible with Emacs Muse.
    + Parse `<verse>` tag in one pass instead of using
    `parseFromString`. This change makes it possible to have
    verbatim `</verse>` tag inside verse.
  * ODT reader:  deal gracefully with missing `<office:font-face-decls/>`
    (#4336). This allows pandoc to parse ODT document produced by KDE's
    Calligra.
  * Muse writer (Alexander Krotov):
    + Output headers without asterisks if not on the top level.
    + Never wrap definition list terms.
    + Set `envInsideBlock = True` when rendering notes.
    + Use `""` instead of `[]` for empty String.
    + Check for whitespace in the beginning and end of Str's.
    + Escape `-`, `;` and `>` in the beginning of strings.
    + Escape list markers in the beginning of notes.
    + Normalize inline list before testing if tags should be used.
    + Use tags instead of lightweight markup for empty strings.
    + Use lightweight markup when possible.
    + Escape empty strings.  This guarantees that `conditionalEscapeString`
    never returns empty string.
    + Wrap conditionalEscapeString result into `Muse` type.
    This removes the need to pass `envInsideLinkDescription` to it.
    + Separate `shouldEscapeString` function.
    + Simplify inline list rendering.
    + Replace newlines in strings with spaces.
  * Docx writer:
    + Add MetaString case for abstract, subtitle (#4900, Mauro Bieg).
    + Properly handle display math in spans (#4826). This isn't a
    complete solution, since other nestings of display math may still
    cause problems, but it should work for what is by far the most
    common case.
  * HTML writer:
    + Always output `<dt>` element, even if it is empty (#4883,
    Alexander Krotov).
    + Don't prefix `epub:` attributes with `data-`.
  * Org writer: Don't escape literal `_`, `^` (#4882). Org doesn't
    recognize these escapes.
  * ODT writer: Fix percentage image scaling (#4881, Nils Carlson).
    Image scaling was broken when a width was set to a percentage.
  * EPUB writer: set `epub:type` on body element in each chapter,
    depending on the `epub:type` of the first section (#4823). This
    only affects epub3. See
    http://www.idpf.org/epub/profiles/edu/structure/#h.l0bzsloklt10
  * FB2 writer: put `coverpage` element between title and date rather than in
    `document-info` element (#4854).
  * Markdown writer: Escape `~` if strikeout extension enabled (#4840).
  * Haddock writer: Use proper format for latex math in haddock (#4571, Joe
    Hermaszewski). Inline math in `\(..\)`, display math in `\[..\]`,
    tex is now used. Previously we'd "fake it with unicode" and fall
    back to tex when that didn't work. But newer haddock versions
    support latex math.
  * TEI writer:
    + Ensure that title element is always present, even if empty (#4839).
    + Put author tags in the template, rather than adding them in
    the writer (#4839).
  * LaTeX writer/template: be sensitive to `filecolor` variable (#4822).
    `linkcolor` only affects internal links, and `urlcolor` only
    affects linked URLs.  For external links, the option to use is
    `filecolor`.
  * ConTeXt writer: output raw `tex` blocks as well as `context` (#969).
  * RST writer:
    + Use `.. raw:: latex` for `tex` content.
    + Use `.. container` for generic Divs, instead of raw HTML.
    + Render Divs with admonition classes as admonitions (#4833).
    Also omit Div with class `admonition-title`. These are generated
    by the RST reader and should be omitted on round-trip.
  * Text.Pandoc.PDF: fix message printed when rsvg-convert is not available
    (#4855, Antonio Terceiro).
  * HTML5 template: add the `title-block-header` identifier to the
    `header` element, to make it easier to style precisely (#4767,
    J. B. Rainsberger).
  * OpenDocument template: Remove unnecessary indenting of TOC title (#4798,
    José de Mattos Neto).
  * latex template: Add support for $toc-title$ to LaTeX (and PDF)
    (#4853, Wandmalfarbe).
  * TEI template: improve `publicationStmt`. Add support for
    `publisher`, `address`, `pubPlace`, and `date` variables.
  * beamer template: Support "toc-title" (#4835, Cyril Roelandt).
  * Text.Pandoc.Extensions: Fix haddock on `Ext_footnotes` (Chris Martin).
  * Lua: cleanup Lua utils, remove unused functions (Albert Krewinkel).
  * MANUAL.txt:
    + Clarify that `--biblatex/--natbib` don't work directly for PDF
    (#4904).
    + Document `epub:type` attribute (Mauro Bieg, #4901)
    + Clarify when `--resource-path` has an effect.
    + More detail on customization in syntax highlighting section.
    + Document encoding issue with `--listings` (#4871, Damien Clochard).
    + Remove docs on removed `--katex-stylesheet` (Mauro Bieg, #4862).
    + Use https for context wiki links (#4910).
  * CONTRIBUTING.md:
    + Link to lua-filters repository (#4874).
    + Fix mistake in REPL instructions for stack. (#4849, Brian Leung).
  * lua-filters.md: add links to filters, and to lua-filters repository
    (#4874).
  * INSTALL.md:
    + Indicate that cabal >= 2.0 is needed.
    + Added chocolatey installation method (#4844, Miodrag Milić).
  * Travis: exclude round-trip tests, except for nightly test which can fail.
  * Use latest texmath, pandoc-citeproc.
  * Use a patched version of foundation until
    https://github.com/haskell-foundation/foundation/pull/503
    is fixed.
  * Clean up appveyor build and Windows package creation.
    We now use 64-bit stack and ghc 8.4.3, lts-12 for the 64-bit build. The
    WiX-based msi is now 64-bit for 64-bit builds (fixing #4795).
  * Remove obsolete RELEASE-CHECKLIST.md.
  * Added additional compiler warnings in Makefile and CI builds.
* Wed Oct 10 2018 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Add _constraints to avoid OOM errors
* Fri Aug 17 2018 psimons@suse.com
- Update pandoc to version 2.2.3.2.
  * Markdown reader: Properly handle boolean values in YAML metadata (#4819).
    This fixes a regression in 2.2.3, which cause boolean values to
    be parsed as MetaInlines instead of MetaBool.
    We here record another undocumented (but desirable) change in 2.2.3:
    numerical metadata fields are now parsed as MetaInlines rather than
    MetaString.
  * Markdown reader: Fix parsing of embedded mappings in YAML metadata
    (#4817).  This fixes a regression in 2.2.3 which caused embedded
    mappings (e.g. mappings in sequences) not to work in YAML metadata.
  * RST reader: improve parsing of inline interpreted text roles (#4811).
    + Use a Span with class "title-reference" for the default
  title-reference role.
    + Use `B.text` to split up contents into `Space`s, `SoftBreak`s,
  and `Str`s for `title-reference`.
    + Use Code with class "interpreted-text" instead of Span and Str for
  unknown roles.  (The RST writer has also been modified to round-trip
  this properly.)
    + Disallow blank lines in interpreted text.
    + Backslash-escape now works in interpreted text.
    + Backticks followed by alphanumerics no longer end interpreted text.
    + Remove support for nested inlines (Francesco Occhipinti).
  RST does not allow nested emphasis, links, or other inline
  constructs.  This fixes several bugs (#4581, #4561, #4792).
  * Org reader: fix parsers relying on `parseFromString` (#4784, Albert
    Krewinkel).  Emphasis was not parsed when it followed directly after
    some block types (e.g., lists).
  * Markdown reader: Allow unquoted numbers and booleans as YAML mapping
    keys.  Previously in 2.2.2 you could not do
    ```
  - --
    0: bar
    ...
    ```
    but only
    ```
  - --
    '0': bar
    ...
    ```
    With this change, both forms work.
  * DocBook reader: metadata handling improvements.
    Now we properly parse title and subtitle elements that are direct
    children of book and article (as well as children of bookinfo,
    articleinfo, or info).  We also now use the `subtitle` metadata
    field for subtitles, rather than tacking the subtitle on to the
    title.
  * RST writer:
    + Allow images to be directly nested within links (#4810, Francesco
  Occhipinti).
    + Use `titleblock` instead of `title` variable for title block (#4803,
  Francesco Occhipinti).  `titleblock` contains a properly formatted
  title and subtitle (using top-level headers).  `title` and
  `subtitle` variables are still available and just contain the
  title and subtitle text.  Note that this change will require an
  update to custom rst templates.
    + Render Code with class "interpreted-text" as interpreted text role.
  * MediaWiki writer: Avoid extra blank line in tables with empty cells
    (#4794).  Note that the old output is semantically identical, but the
    new output looks better.
  * Lua Utils module: add function `blocks_to_inlines` (#4799, Albert
    Krewinkel).  Exposes a function converting which flattenes a list of
    blocks into a list of inlines. An example use case would be the
    conversion of Note elements into other inlines.
  * RST template:  use `titleblock` instead of `title`.  Users of
    custom RST templates will want to update this.
  * LaTeX template: Moved some beamer code in default.latex template.
    This change allows beamer themes to change the template and font (as
    Metropolis does) (#4450).
  * Better error message on `-t pdf -o out.pdf` (#1155, Mauro Bieg).
  * Added test case for #4669 to repository.
  * INSTALL.md: Fix broken link for cabal-install (#4806, ChanHoHo).
  * MANUAL.txt:
    + Add beamer info for slide backgrounds (#4802, John Muccigrosso).
    + Clarify when `csquotes` is used in LaTeX writer (#4514).
    + Add `commonmark` to list of output formats where `raw_tex` has an
  effect (see #4527).
* Fri Jul 20 2018 psimons@suse.com
- Update pandoc to version 2.2.2.1.
  pandoc (2.2.2.1)
  * Fix regression finding templates in user data directory (#4777).
    Under version 2.2.1 and prior pandoc found latex templates in the
    templates directory under the data directory, but this broke in 2.2.2.
  * Fix for bug in parsing `\input` in `rawLaTeXBlock` and
    `rawLaTeXInline` (#4781). (This primarily affects the markdown
    reader, and other readers that accept raw tex.)
    Starting in 2.2.2, everything after an `\input` (or `\include`)
    in a markdown file would be parsed as raw LaTeX.
  * MANUAL:
    + Clarify `gfm` vs `markdown_github` (#4783, Mauro Bieg).
  * Use `keywords` instead of `tags` in YAML metadata example (#4779).
    Unlike `tags`, `keywords` is used in some of the writers
    and default templates.
  * Add missing `rollingLinks` option to revealjs template (#4778,
    Igor Khorlo).
* Wed Jul 18 2018 psimons@suse.com
- Cosmetic: replace tabs with blanks, strip trailing white space,
  and update copyright headers with spec-cleaner.
* Tue Jul 17 2018 psimons@suse.com
- Update pandoc to version 2.2.2.
  * Use HsYAML instead of yaml for translations and YAML metadata (#4747).
    yaml wraps a C library; HsYAML is pure Haskell.  Advances #4535.
    Note: HsYAML implements YAML 1.2, in which the valid true
    values are `true`, `True`, `TRUE`.  This means a change in
    the semantics of YAML metadata that could affect users:
    `y`, `yes`, and `on` no longer count as true values.
  * Fix regression: make `--pdf-engine` work with full paths (#4681, Mauro
    Bieg).
  * CommonMark reader: Handle `ascii_identifiers` extension (#4742,
    Anders Waldenborg).  Non-ascii characters were not stripped from
    identifiers even if the `ascii_identifiers` extension was
    enabled (which is is by default for gfm).
  * TikiWiki reader: Improve list parsing (#4722, Mauro Bieg).
    Remove trailing Space from list items.  Parse lists that have no space
    after marker.
  * LaTeX reader:
    + Treat `lilypond` as a verbatim environment (#4725).
    + Parse figure label into Image id (#4700, Mauro Bieg).
    + Beamer: Allow "noframenumbering" option (#4696, Raymond Ehlers).
    + Allow spaces around `\graphicspath` arguments (#4698).
    + Handle includes without surrounding blanklines (#4553).
    In addition, `\input` can now be used in an inline context,
    e.g. to provide part of a paragraph, as it can in LaTeX.
    + In `rawLaTeXBlock`, handle macros that resolve to a
    `\begin` or `\end` (#4667).
    + In `rawLaTeXBlock`, don't expand macros in macro definitions (#4653).
    Note that this only affected LaTeX in markdown.
    + Tighten up reading of beamer overlay specifications (#4669).
    Ideally we'd turn these on only when reading beamer, but currently
    beamer is not distinguished from latex as an input format.
    This commit also activates parsing of overlay specifications
    after commands in general (e.g. `\item`), since they can occur
    in many contexts in beamer.
    + Parse more siunitx unit commands (#4296, #4773).
    + Be more forgiving in key/value option parsing (#4761).
  * Markdown reader:
    + Allow empty code spans, e.g. `` ` ` ``.
    + Emojis are now wrapped in Spans with class `emoji` and
    attribute `data-emoji` (Anders Waldenborg, #4743).
    This allows the writer to handle them in a special way
    (e.g. using a special font, or just rendering the
    emoji name).
  * Muse reader (Alexander Krotov, except where indicated):
    + Get rid of non-exhaustive pattern match warning (Mauro Bieg).
    + Add support for floating images.
    + Add support for images with specified width.
    + Parse image URLs without "guard" and "takeExtension".
    + Split link and image parsing into separate functions.
    + Parse links starting with "URL:" explicitly instead of trying to strip
    "URL:" prefix after parsing.
  * Texinfo writer: Use `@sup` and `@sub` instead of custom macros (#4728,
    Alexander Krotov).
  * Markdown writer: Preserve `implicit_figures` with attributes, even if
    `implicit_attributes` is not set, by rendering in raw HTML (#4677).
  * Markdown and commonmark/github writers now respect the `emoji`
    extension.  So, `-f markdown+emoji -t markdown+emoji` now leaves
    `:smile:` as `:smile:` rather than converting it to a smile
    character.
  * Docx writer: Be sensitive to `toc` in YAML metadata (#4645).
  * ODT/OpenDocument writer: Make internal links work (#4358).
    This adds proper bookmarks to the headers with non-null IDs.
  * EPUB writer: Properly escape pagetitle.  Previously we weren't
    escaping `&` and other XML characters in the pagetitle, so a title
    containing a `&` would be invalid.
  * AsciiDoc Writer: Eescape square brackets at start of line (#4545,
    Mauro Bieg).
  * RST writer:
    + Don't treat 'example' as a syntax name (#4748).
    This fixes conversions from org with example blocks.
    + Support `--number-sections` via the `section-numbering`
    directive in standalone output.
  * reveal.js writer and template: reuse mathjax URL
    provided by the argument to `--mathjax` or the normal pandoc default,
    rather than a hard-coded one in the template (#4701).
  * LaTeX writer:
    + Properly handle footnotes in table captions (#4683).
    Refactored code from figure captions to use in both places.
    + In beamer output, fix single digit column percentage (#4690, Mauro
    Bieg).
  * FB2 writer (Alexander Krotov):
    + Convert Plain to Para in annotation (#2424).
    + Fix order of items in title-info (#2424).
  * Custom writer: fix error message on script failure (Albert Krewinkel).
    Error messages produced by Lua were not displayed by Pandoc.
  * Text.Pandoc.Emoji now exports `emojiToInline`, which returns a Span
    inline containing the emoji character and some attributes with metadata
    (class `emoji`, attribute `data-emoji` with emoji name).  (API change,
    Anders Waldenborg, #4743).
  * Text.Pandoc.PDF:
    + Revert fix for #4484 (only compress images on last run, #4755).
    This will mean some increase in the time it takes to
    produce an image-heavy PDF with xelatex, but it will
    make tables of contents correct, which is more important.
    + Fix logic error in `runTeXProgram`.  We were running the tex program
    one more time than requested.  This should speed up PDF production.
  * Allow `--template` to take a URL as argument.
  * Text.Pandoc.Highlighting: Add missing re-export of `breezeDark`
    highlighting style (#4687, Adrian Sieber, API change).
  * Clarify macOS install in INSTALL.md (#4661).  Make the binary package
    installer the recommended method, and note that on some older versions of
    macOS, homebrew installs from source and takes a lot of disk space
    (#4664, Ian).
  * MANUAL:
    + Clarify EPUB linked media (#4756, Mauro Bieg)
    + Update manual for "true" YAML values.  Now that we're using HsYAML and
    YAML 1.2, the valid true values are `true`, `True`, `TRUE`.  NOTE!
    `y`, `yes`, `on` no longer count as true values.
    + Document `-F` as alias for `--filter` (thanks to Gandalf Saxe).
    + Update manual on how math is rendered in LaTeX.
    + Add proxy description (#4131, Mauro Bieg).
    + Clarify that `--toc` requires `--standalone` (#4703).
    + Update citation styles link (#4699, wiefling).
  * In API docs, clarify how `Ext_east_asian_line_breaks` extension works
    (kaizshang91).  Note that it will not take effect when readers/writers
    are called as libraries (#4674).
  * Improved translations/fr (#4766, lux-lth).
  * Removed inadvertently added `.orig` files from repository (#4648).
  * Remove `network-uri` flag and use 'Network.Socket'.
    This removes a compiler warning.  There is no need for the old
    `network-uri` flag, since network 2.6 was released in 2014.
  * Add stack.lts10.yaml, stack.lts11.yaml.  use lts-12 in stack.yaml.
  * Bump upper bounds for dependent packages.
  * Exclude foundation 0.0.21 for ghc 7.10.  Otherwise cabal gets
    confused because of the way ghc 7.10 is excluded in foundation's
    cabal file.  This can be removed when haskell-foundation/foundation#500
    is fixed.
  * Require cabal-version >= 2.0.  This is needed for haddock-library.
* Tue May 22 2018 hpj@urpla.net
- Avoid use of '[' and ']' characters in %%files section entries.
  This allows building for older distributions.
* Mon May 14 2018 psimons@suse.com
- Update pandoc to version 2.2.1.
  * Restored and undeprecated gladtex for HTML math (#4607).
    + Added `GladTeX` constructor to `Text.Pandoc.Options.HTMLMathMethod`
    [API change, reverts removal in v2.2]
    + Restored and undeprecated `--gladtex` option, removed in v2.2.
  * LaTeX reader:  Handle `$` in `/text{..}` inside math (#4576).
  * Org reader: Fix image filename recognition (Albert Krewinkel).
    Use a function from the filepath library to check whether a string is a
    valid file name.  The custom validity checker that was used before gave
    wrong results (e.g. for absolute file paths on Windows,
    kawabata/ox-pandoc#52).
  * FB2 reader: Replace some errors with warnings (Alexander Krotov).
  * HTML writer:
    + Strip links from headers when creating TOC (#4340).
    Otherwise the TOC entries will not link to the sections.
    + Fix regression with tex math environments in HTML + MathJax (#4639).
  * Muse writer (Alexander Krotov): Add support for left-align and
    right-align classes (#4542).
  * Docx writer: Support underline (#4633).
  * Text.Pandoc.Parsing: Lookahead for non-whitespace after
    `singleQuoteStart` and `doubleQuoteStart` (#4637).
  * `test-pandoc-utils.lua`:  more robust testing on both windows
    and \*nix. Previously the pipe tests were only run if
    `\bin/false` and `/bin/sed` were present, which they aren't
    in default MacOS and Windows systems.  Fixed by using `tr`
    and `false`, which should always be in the path on a \*nix
    system, and `find` and `echo` for Windows.
  * Text.Pandoc.Shared: add `uriPathToPath`.
    This adjusts the path from a file: URI in a way that is sensitive
    to Windows/Linux differences.  Thus, on Windows,
    `/c:/foo` gets interpreted as `c:/foo`, but on Linux,
    `/c:/foo` gets interpreted as `/c:/foo`.  See #4613.
  * Use `uriPathToPath` with file: URIs (#4613).
  * Revert piping HTML to pdf-engine (Mauro Bieg, #4413).  Use a temp
    file as before.
  * Text.Pandoc.Class: Catch IO errors when writing media files
    and issue a warning, rather than an error (Francesco Occhipinti, #4559).
  * Don't lowercase custom writer filename (Alexander Krotov, #4610).
  * MANUAL (Mauro Bieg):
    + Clarify truthiness in template variables (#2281).
    + Clarify pipe table width calculation (#4520).
  * ConTeXt template: New Greek fallback typeface (Pablo Rodríguez, #4405).
    CMU Serif gives better typographic results than the previous
    Greek fallback DejaVu Serif.
  * Make HTML template polyglot (#4606, OvidiusCicero), by making
    `<link rel="stylesheet" href="$css$">` self-closing.
  * Use texmath 0.11, allowing better translation of non-ASCII
    characters in math (#4642).
  * New input format: `fb2` (FictionBook2) (Alexander Krotov).
  * Make `--ascii` work for all XML formats (ICML, OPML, JATS,...),
    and for `ms` and `man`.
  * Remove deprecated `--latexmathml`, `--gladtex`, `--mimetex`, `--jsmath`, `-m`,
    `--asciimathml` options.
  * New module Text.Pandoc.Readers.FB2, exporting readFB2 (Alexander
    Krotov, API change).
  * Markdown reader:
    + Allow empty key-value attributes, like `title=""` (#2944).
    + Handle table w/o following blank line in fenced div (#4560).
    + Remove "fallback" for `doubleQuote` parser.  Previously the
    parser tried to be efficient -- if no end double quote was found,
    it would just return the contents.  But this could backfire in a
    case `**this should "be bold**`, since the fallback would return
    the content `"be bold**` and the closing boldface delimiter
    would never be encountered.
    + Improve computation of the relative width of the last column in a
    multiline table, so we can round-trip tables without constantly
    shrinking the last column.
  * EPUB reader:
    + Fix images with space in file path (#4344).
  * LaTeX reader:
    + Properly resolve section numbers with `\ref` and chapters (#4529).
    + Parse sloppypar environment (#4517, Marc Schreiber).
    + Improve handling of raw LaTeX (for markdown etc.) (#4589, #4594).
    Previously there were some bugs in how macros were handled.
    + Support `\MakeUppercase`, `\MakeLowercase', `\uppercase`, `\lowercase`,
    and also `\MakeTextUppercase` and `\MakeTextLowercase` from textcase
    (#4959).
  * Textile reader:
    + Fixed tables with no body rows (#4513).
    Previously these raised an exception.
  * Mediawiki reader:
    + Improve table parsing (#4508).  This fixes detection of table
    attributes and also handles `!` characters in cells.
  * DocBook reader:
    + Properly handle title in `section` element (#4526).
    Previously we just got `section_title` for `section` (though `sect1`,
    `sect2`, etc. were handled properly).
    + Read tex math as output by asciidoctor (#4569, Joe Hermaszewski).
  * Docx reader:
    + Combine adjacent CodeBlocks with the same attributes into
    a single CodeBlock.  This prevents a multiline codeblock in
    Word from being read as different paragraphs.
  * RST reader:
    + Allow < 3 spaces indent under directives (#4579).
    + Fix anonymous redirects with backticks (#4598).
  * Muse reader (Alexander Krotov):
    + Add support for Text::Amuse multiline headings.
    + Add `<math>` tag support.
    + Add support for `<biblio>` and `<play>` tags.
    + Allow links to have empty descriptions.
    + Require block `<literal>` tags to be on separate lines.
    + Allow `-` in anchors.
    + Allow verse to be indented.
    + Allow nested footnotes.
    + Internal improvements.
  * Muse writer (Alexander Krotov):
    + Escape `>` only at the beginning of a line.
    + Escape `]` in image title.
    + Escape `]` brackets in URLs as `%%5D`.
    + Only escape brackets when necessary.
    + Escape ordered list markers.
    + Do not escape list markers unless preceded by space.
    + Escape strings starting with space.
    + Escape semicolons and markers after line break.
    + Escape `;` to avoid accidental comments.
    + Don't break headers, line blocks and tables with line breaks.
    + Correctly output empty headings.
    + Escape horizontal rule only if at the beginning of the line.
    + Escape definition list terms starting with list markers.
    + Place header IDs before header.
    + Improve span writing.
    + Do not join Spans in normalization.
    + Don't align ordered list items.
    + Remove key-value pairs from attributes before normalization.
    + Enable `--wrap=preserve` for all tests by default.
    + Reduced `<verbatim>` tags in output.
    + Internal changes.
  * RST writer:
    + Use more consistent indentation (#4563).  Previously we
    used an odd mix of 3- and 4-space indentation.  Now we use 3-space
    indentation, except for ordered lists, where indentation must
    depend on the width of the list marker.
    + Flatten nested inlines (#4368, Francesco Occhipinti).
    Nested inlines are not valid RST syntax, so we flatten them following
    some readability criteria discussed in #4368.
  * EPUB writer:
    + Ensure that `pagetitle` is always set, even when structured titles
    are used.  This prevents spurious warnings about empty title
    elements (#4486).
  * FB2 writer (Alexander Krotov):
    + Output links inline instead of producing notes.  Previously all links
    were turned into footnotes with unclickable URLs inside.
    + Allow emphasis and notes in titles.
    + Don't intersperse paragraph with empty lines.
    + Convert metadata value `abstract` to book annotation.
    + Use `<empty-line />` for `HorizontalRule` rather than `LineBreak`.
    FB2 does not have a way to represent line breaks inside paragraphs;
    previously we used `<empty-line />` elements, but these are not allowed
    inside paragraphs.
  * Powerpoint writer (Jesse Rosenthal):
    + Handle Quoted Inlines (#4532).
    + Simplify code with `ParseXml`.
    + Allow fallback options when looking for placeholder type.
    + Check reference-doc for all layouts.
    + Simplify speaker notes logic.
    + Change notes state to a simpler per-slide value.
    + Remove `Maybe` from `SpeakerNotes` in `Slide`. `mempty`
    means no speaker notes.
    + Add tests for improved speaker notes.
    + Handle speaker notes earlier in the conversion process.
    + Keep notes with related blocks (#4477).  Some blocks automatically
    split slides (imgs, tables, `column` divs). We assume that any
    speaker notes immediately following these are connected to these
    elements, and keep them with the related blocks, splitting after them.
    + Remove `docProps/thumbnail.jpeg` in data dir (Jesse Rosenthal, #4588).
    It contained a nonfree ICC color calibration profile and is not needed
    for production of a powerpoint document.
  * Markdown writer:
    + Include a blank line at the end of the row in a single-row multiline
    table, to prevent it from being interpreted as a simple table (#4578).
  * CommonMark writer:
    + Correctly ignore LaTeX raw blocks when `raw_tex` is not
    enabled (#4527, quasicomputational).
  * EPUB writer:
    + Add `epub:type="footnotes"` to notes section in EPUB3 (#4489).
  * LaTeX writer:
    + In beamer, don't use format specifier for default ordered lists
    (#4556).  This gives better results for styles that put ordered list
    markers in boxes or circles.
    + Update `\lstinline` delimiters (#4369, Tim Parenti).
  * Ms writer:
    + Use `\f[R]` rather than `\f[]` to reset font (#4552).
    + Use `\f[BI]` and `\f[CB]` in headers, instead of `\f[I]` and `\f[C]`,
    since the header font is automatically bold (#4552).
    + Use `\f[CB]` rather than `\f[BC]` for monospace bold (#4552).
    + Create pdf anchor for a Div with an identifier (#4515).
    + Escape `/` character in anchor ids (#4515).
    + Improve escaping for anchor ids: we now use _uNNN_ instead of uNNN
    to avoid ambiguity.
  * Man writer:
    + Don't escape U+2019 as `'` (#4550).
  * Text.Pandoc.Options:
    + Removed `JsMath`, `LaTeXMathML`, and `GladTeX` constructors from
    `Text.Pandoc.Options.HTMLMathMethod` [API change].
  * Text.Pandoc.Class:
    + `writeMedia`: unescape URI-escaping in file path.  This avoids
    writing things like `file%%20one.png` to the file system.
  * Text.Pandoc.Parsing:
    + Fix `romanNumeral` parser (#4480).  We previously accepted 'DDC'
    as 1100.
    + `uri`: don't treat `*` characters at end as part of URI (#4561).
  * Text.Pandoc.MIME:
    + Use the alias `application/eps` for EPS (#2067).
    This will ensure that we retain the eps extension after reading the
    image into a mediabag and writing it again.
  * Text.Pandoc.PDF:
    + Use `withTempDir` in `html2pdf`.
    + With `xelatex`, don't compress images til the last run (#4484).
    This saves time for image-heavy documents.
    + Don't try to convert EPS files (#2067).  `pdflatex` converts them
    itself, and JuicyPixels can't do it.
    + For `pdflatex`, use a temp directory in the working directory.
    Otherwise we can have problems with the EPS conversion pdflatex
    tries to do, which can't operate on a file above the working
    directory without `--shell-escape`.
  * Changes to tests to accommodate changes in pandoc-types.
    In <https://github.com/jgm/pandoc-types/pull/36> we changed
    the table builder to pad cells.  This commit changes tests
    (and two readers) to accord with this behavior.
  * Set default extensions for `beamer` same as `latex`.
  * LaTeX template:
    + Add `beameroption` variable (#4359, Étienne Bersac).
    + Use `pgfpages` package; this is needed for notes on second
    screen in beamer (Étienne Bersac).
    + Add `background-image` variable (#4601, John Muccigrosso).
  * reveal.js template: Add `background-image` variable (#4600,
    John Muccigrosso).
  * ms template: Fix date.  Previously `.ND` was used, but this only
    works if you have a title page, which we don't.  Thanks to @teoric.
  * Removed pragmas for unused extensions (#4506, Anabra).
  * Fix bash completion for `--print-default-data-file` (#4549).
    Previously this looked in the filesystem, even if pandoc
    was compiled with `embed_data_files` (and sometimes it looked
    in a nonexistent build directory).  Now the bash completion
    script just includes a hard-coded list of data file names.
  * MANUAL:
    + Clarify template vs metadata variables (#4501, Mauro Bieg).
    + Fix raw content example (#4479, Mauro Bieg).
    + Specify that you use html for raw output in epub.
    + Add examples for raw docx blocks (#4472, Tristan Stenner).
    The documentation states that the target format name should match
    the output format, which isn't the case for `docx`/`openxml` and
    some others.
    + Don't say that `empty_paragraphs` affects markdown output (#4540).
    + Consolidate input/output format documentation (#4577, Mauro Bieg).
  * New README template. Take in/out formats from manual.
  * Fix example in lua-filters docs (#4459, HeirOfNorton).
  * Use the `-threaded` GHC flag when building benchmarks (#4587,
    Francesco Occhipinti).
  * Bump temporary upper bound to 1.4.
  * Use pandoc-citeproc 0.14.3.1.
  * Use texmath-0.10.1.2 (fixes escapes in math in ms, #4597).
  * Removed old lib directory.  This was used for something long ago,
    but plays no role now.
  * Removed unneeded data file `LaTeXMathML.js`.
  * Create 64- and 32-bit versions of Windows binary packages.
  * Docx reader (Jesse Rosenthal):
    + Add tests for nested smart tags.
    + Parse nested smart tags.
    + Make unwrapSDT into a general `unwrap` function that can unwrap both
    nested SDT tags and smartTags. This makes the SmartTags constructor in
    the Docx type unnecessary, so we remove it (#4446).
    + Remove unused `docxWarnings` (Alexander Krotov).
  * RST reader: Allow unicode bullet characters (#4454).
  * Haddock reader:  Better table handling, using haddock-library's
    new table support, if compiled against a version that
    includes it.  Note that tables with col/rowspans will not
    translate well into Pandoc.
  * Muse reader (Alexander Krotov):
    + Require closing tag to have the same indentation as opening.
    + Do not reparse blocks inside unclosed block tag (#4425).
    + Parse `<class>` tag (supported by Emacs Muse).
    + Do not produce empty Str element for unindented verse lines.
    + Don't allow footnote references inside links.
    + Allow URL to be empty.
    + Require that comment semicolons are in the first column (#4551).
    + Various internal improvements.
  * LaTeX reader:
    + Add support to parse unit string of `\SI` command (closes #4296,
    Marc Schreiber).
  * Haddock writer:  In the writer, we now render tables always as
    grid tables, since Haddock supports these.
  * DokuWiki writer: rewrite backSlashLineBreaks (#4445, Mauro Bieg).
  * Docx writer: Fixed formatting of `DefaultStyle` ordered lists in
    docx writer.  We want decimal for the top level, not lower roman.
  * RST writer:
    + Strip whitespace at beginning and ending of inline containers
    (#4327, Francesco Occhipinti).
    + Filter out empty inline containers (#4434).  There is nothing in
    RST that corresponds to e.g. `Emph []`, so we just ignore elements
    like this (Francesco Occhipinti).
  * Muse writer (Alexander Krotov):
    + Support spans with anchors.
    + Replace smallcaps with emphasis before normalization.
    + Output smallcaps as emphasis.
    + Expand Cite before list normalization.
    + Write empty inline lists as `<verbatim></verbatim>`.
    + Remove empty Str from the beginning of inline lists during normalization.
    + Escape "-" to avoid creating bullet lists.
    + Fix math expansion for more than one expression per paragraph.
    + Expand math before inline list normalization.
  * Dokuwiki writer: fix LineBreaks in Tables (#4313, Mauro Bieg).
  * Ms writer:
    + Asciify pdf anchors, since unicode anchors don't work (#4436).
    Internal links should be converted automatically, so this shouldn't
    affect users directly.
    + Don't escape hyphens as `\-`; that's for a minus sign (#4467).
  * Beamer writer: put hyperlink after `\begin{frame}` and not in the title
    (#4307).  If it's in the title, then we get a titlebar on slides with
    the `plain` attribute, when the id is non-null.  This fixes a regression
    in 2.0.
  * EPUB writer: Remove notes from TOC in nav.xhtml (#4453, Mauro Bieg).
  * JATS writer: Remove extraneous, significant whitespace (#4335,
    Nokome Bentley).
  * html2pdf: inject base tag wih current working directory (#4413, Mauro
    Bieg).  This helps ensure that linked resources are included.
  * Add Semigroup instances for everything for which we defined a
    Monoid instance previously (API change):
    + Text.Pandoc.Class.FileTree.
    + Text.Pandoc.Translations.Translations.
    + Text.Pandoc.Extensions.Extensions.
    + Text.Pandoc.Readers.Odt.StyleReader.Styles.
    + Text.Pandoc.Pretty.Doc.
    + Text.Pandoc.MediaBag.MediaBag.
  * Add custom Prelude to give clean code for Monoid and Semigroup
    that works with ghc 7.10-8.4.  The custom Prelude (`prelude/Prelude`)
    is used for ghc versions < 8.4.  `NoImplicitPrelude` is used
    in all source files, and Prelude is explicitly imported
    (this is necessary for ghci to work properly with the custom prelude).
  * Text.Pandoc.Writers.Shared (Francesco Occhipinti):
    + Export `stripLeadingTrailingSpace`.
    + Don't wrap lines in grid tables when `--wrap=none` (#4320).
    + `gridTable`: Don't wrap lines in tables when `--wrap=none`.  Instead,
    expand cells, even if it results in cells that don't respect relative
    widths or surpass page column width.  This change affects RST,
    Markdown, and Haddock writers.
  * Raise error if someone tries to print docx, odt, etc. template (#4441).
  * LaTeX template: Provide `bidi` package's option using
    `\PassOptionsToPackage`  (#4357, Václav Haisman).  This avoid a
    clash when   `polyglossia` loads it first and then it is loaded again
    for XeLaTeX.
  * ConTeXt template: Added `pdfa` variable to generate PDF/A (#4294, Henri
    Menke).  Instructions on how to install the ICC profiles on ConTeXt
    standalone can be found in the wiki:
    <http://wiki.contextgarden.net/PDFX#ICC_profiles>.
    If the ICC profiles are not available the log will contain error
    messages.
  * Use latest pandoc-types, skylighting
  * Use latest pandoc-citeproc in binary package.
  * Bump upper bound for time, criterion, haddock-library, exceptions,
    http-types, aeson, haddock-library.
  * Bump upper bound tasty-quickcheck 0.10 (#4429, Felix Yan).
  * pandoc.cabal:  fix up other-extensions and language fields.
    Language is now consistently `Haskell2010`, and other-extensions
    is consistently `NoImplicitPrelude`. Everything else to be specified
    in the module header as needed.
  * Removed `old-locale` flag and Text.Pandoc.Compat.Time.
    This is no longer necessary since we no longer support ghc 7.8.
  * Make `weigh-pandoc` into a benchmark program.
    Remove `weigh-pandoc` flag.  `weigh-pandoc` is now built (and run)
    automatically when you build (and run) benchmarks.
  * MANUAL: add instructions for background images reveal.js (#4325, John
    Muccigrosso).
  * appveyor: use VS 2013 environment instead of VS 2015 for Windows builds.
  * Markdown reader:
    + Fix parsing bug with nested fenced divs (#4281).  Previously we allowed
    "nonindent spaces" before the opening and closing `:::`, but this
    interfered with list parsing, so now we require the fences to be flush with
    the margin of the containing block.
  * Commonmark reader:
    + `raw_html` is now on by default.  It can be disabled explicitly
    using `-f commonmark-raw_html`.
  * Org reader (Albert Krewinkel):
    + Move citation tests to separate module.
    + Allow changing emphasis syntax (#4378).  The characters allowed before
    and after emphasis can be configured via `#+pandoc-emphasis-pre` and
    `#+pandoc-emphasis-post`, respectively. This allows to change which
    strings are recognized as emphasized text on a per-document or even
    per-paragraph basis.  Example:
    [#]+pandoc-emphasis-pre: "-\t ('\"{"
    [#]+pandoc-emphasis-post: "-\t\n .,:!?;'\")}["
  * LaTeX reader:
    + Fixed comments inside citations (#4374).
    + Fix regression in package options including underscore (#4424).
    + Make `--trace` work.
    + Fixed parsing of `tabular*` environment (#4279).
  * RST reader:
    + Fix regression in parsing of headers with trailing space (#4280).
  * Muse reader (Alexander Krotov):
    + Enable `<literal>` tags even if amuse extension is enabled.
    Amusewiki disables <literal> tags for security reasons.
    If user wants similar behavior in pandoc, RawBlocks and RawInlines
    can be removed or replaced with filters.
    + Remove space prefix from `<literal>` tag contents.
    + Do not consume whitespace while looking for closing end tag.
    + Convert alphabetical list markers to decimal in round-trip test.
    Alphabetical lists are an addition of Text::Amuse.
    They are not present in Emacs Muse and can be ambiguous
    when list starts with "i.", "c." etc.
    + Allow `<quote>` and other tags to be indented.
    + Allow single colon in definition list term.
    + Fix parsing of verse in lists.
    + Improved parsing efficiency.  Avoid `parseFromString`.
    Lists are parsed in linear instead of exponential time now.
    + Replace ParserState with MuseState.
    + Prioritize lists with roman numerals over alphabetical lists.
    This is to make sure "i." starts a roman numbered list,
    instead of a list with letter "i" (followed by "j", "k", ...").
    + Fix directive parsing.
    + Parse definition lists with multiple descriptions.
    + Parse next list item before parsing more item contents.
    + Fixed a bug: headers did not terminate lists.
    + Move indentation parsing from `definitionListItem` to `definitionList`.
    + Paragraph indentation does not indicate nested quote.
    Muse allows indentation to indicate quotation or alignment,
    but only on the top level, not within a <quote> or list.
    + Require that block tags are on separate lines.
    Text::Amuse already explicitly requires it anyway.
    + Fix matching of closing inline tags.
    + Various internal changes.
    + Fix parsing of nested definition lists.
    + Require only one space for nested definition list indentation.
    + Do not remove trailing whitespace from `<code>`.
    + Fix parsing of trailing whitespace.  Newline after whitespace now
    results in softbreak instead of space.
  * Docx reader (Jesse Rosenthal, except where noted):
    + Handle nested sdt tags (#4415).
    + Don't look up dependant run styles if `+styles` is enabled.
    + Move pandoc inline styling inside custom-style span.
    + Read custom styles (#1843).  This will read all paragraph and
    character classes as divs and spans, respectively. Dependent styles
    will still be resolved, but will be wrapped with appropriate style
    tags. It is controlled by the `+styles` extension (`-f docx+styles`).
    This can be used in conjunction with the `custom-style` feature in the
    docx writer for a pandoc-docx editing workflow. Users can convert from
    an input docx, reading the custom-styles, and then use that same input
    docx file as a reference-doc for producing an output docx file. Styles
    will be maintained across the conversion, even if pandoc doesn't
    understand them.
    + Small change to Fields hyperlink parser.  Previously, unquoted string
    required a space at the end of the line (and consumed it). Now we
    either take a space (and don't consume it), or end of input.
    + Pick table width from the longest row or header (Francesco Occhipinti,
    [#4360]).
  * Muse writer (Alexander Krotov):
    + Change verse markup: `> ` instead of `<verse>` tag.
    + Remove empty strings during inline normalization.
    + Don't indent nested definition lists.
    + Use unicode quotes for quoted text.
    + Write image width specified in percent in Text::Amuse mode.
    + Don't wrap displayMath into `<verse>`.
    + Escape nonbreaking space (`~~`).
    + Join code with different attributes during normalization.
    + Indent lists inside Div.
    + Support definitions with multiple descriptions.
  * Powerpoint writer (Jesse Rosenthal):
    + Use table styles This will use the default table style in the
    reference-doc file. As a result they will be easier when using
    in a template, and match the color scheme.
    + Remove empty slides.  Because of the way that slides were split, these
    could be accidentally produced by comments after images.  When animations
    are added, there will be a way to add an empty slide with either
    incremental lists or pauses.
    + Implement syntax highlighting.  Note that background colors can't
    be implemented in PowerPoint, so highlighting styles that require
    these will be incomplete.
    + New test framework for pptx.  We now compare the output of the
    Powerpoint writer with files that we know to (a) not be corrupt,
    and (b) to show the desired output behavior (details below).
    + Add `notesMaster` to `presentation.xml` if necessary.
    + Ignore links and (end)notes in speaker notes.
    + Output speaker notes.
    + Read speaker note templates conditionally.  If there are speaker
    notes in the presentation, we read in the notesMasters templates
    from the reference pptx file.
    + Fix deletion track changes (#4303, Jesse Rosenthal).
  * Markdown writer: properly escape @ to avoid capture as citation
    (#4366).
  * LaTeX writer:
    + Put hypertarget inside figure environment (#4388).
    This works around a problem with the endfloat package and
    makes pandoc's output compatible with it.
    + Fix image height with percentage (#4389).  This previously caused
    the image to be resized to a percentage of textwidth, rather than
    textheight.
  * ConTeXt writer (Henri Menke):
    + New section syntax and support `--section-divs` (#2609).
    `\section[my-header]{My Header}` ->
    `\section[title={My Header},reference={my-header}]`.
    The ConTeXt writer now supports the `--section-divs` option to
    write sections in the fenced style, with `\startsection` and
    `\stopsection`.
    + xtables: correct wrong usage of caption (Henri Menke).
  * Docx writer:
    + Fix image resizing with multiple images (#3930, Andrew Pritchard).
    + Use new golden framework (Jesse Rosenthal).
    + Make more deterministic to facilitate testing (Jesse Rosenthal).
  - `getUniqueId` now calls to the state to get an incremented digit,
    instead of calling to P.uniqueHash.
  - we always start the PRNG in mkNumbering/mkAbstractNum with the same
    seed (1848), so our randoms should be the same each time.
    + Fix ids in comment writing (Jesse Rosenthal).  Comments from
    `--track-changes=all` were producing corrupt docx, because the
    writer was trying to get id from the `(ID,_,_)` field of
    the attributes, and ignoring the "id" entry in the key-value pairs. We
    now check both.
  * Ms writer: Added papersize variable.
  * TEI writer:
    + Use `height` instead of `depth` for images (#4331).
    + Ensure that id prefix is always used.
    + Don't emit `role` attribute; that was a leftover from the
    Docbook writer.
    + Use 'xml:id', not 'id' attribute (#4371).
  * AsciiDoc writer:
    + Do not output implicit heading IDs (#4363, Alexander
    Krotov).  Convert to `asciidoc-auto_identifiers` for old behaviour.
  * RST writer:
    + Remove `blockToRST'` moving its logic into `fixBlocks`
    (Francesco Occhipinti).
    + Insert comment between lists and quotes (#4248, Francesco Occchipinti).
  * RST template: remove definition of 'math' role as raw.
    This used to be needed prior to v 0.8 of docutils, but
    now math support is built-in.
  * Slides: Use divs to set incremental/non-incremental (#4381,
    Jesse Rosenthal).  The old method (list inside blockquote) still
    works, but we are encouraging the use of divs with class
    `incremental` or `nonincremental`.
  * Text.Pandoc.ImageSize:
    + Make image size detection for PDFs more robust (#4322).
    + Determine image size for PDFs (#4322).
    + EMF Image size support (#4375, Andrew Pritchard).
  * Text.Pandoc.Extensions:
    + Add `Ext_styles` (Jesse Rosenthal, API change).  This will be used in
    the docx reader (defaulting to off) to read pargraph and character
    styles not understood by pandoc (as divs and spans, respectively).
    + Made `Ext_raw_html` default for `commonmark` format.
  * Text.Pandoc.Parsing:
    + Export `manyUntil` (Alexander Krotov, API change).
    + Export improved `sepBy1` (Alexander Krotov).
    + Export list marker parsers: `upperRoman`, `lowerRoman`,
    `decimal`, `lowerAlpha`, `upperAlpha` (Alexander Krotov, API change).
  * Tests/Lua: fix tests on windows (Albert Krewinkel).
  * Lua: register script name in global variable (#4393).  The name of the Lua
    script which is executed is made available in the global Lua variable
    `PANDOC_SCRIPT_FILE`, both for Lua filters and custom writers.
  * Tests: Abstract powerpoint tests out to OOXML tests (Jesse Rosenthal).
    There is very little pptx-specific in these tests, so we abstract out
    the basic testing function so it can be used for docx as well. This
    should allow us to catch some errors in the docx writer that slipped
    by the roundtrip testing.
  * Lua filters: store constructors in registry (Albert Krewinkel).  Lua
    functions used to construct AST element values are stored in the Lua
    registry for quicker access. Getting a value from the registry is much
    faster than getting a global value (partly to idiosyncrasies of hslua);
    this change results in a considerable performance boost.
  * Documentation:
    + `doc/org.md` Add draft of Org-mode documentation (Albert Krewinkel).
    + `doc/lua-filters.md`: document global vars set for filters
    (Albert Krewinkel).
    + INSTALL.md: mention Stack version. (#4343, Adam Brandizzi).
    + MANUAL: add documentation on custom styles (Jesse Rosenthal).
    + MANUAL.txt: Document incremental and nonincremental divs (Jesse
    Rosenthal).  Blockquoted lists are still described, but fenced divs are
    presented in preference.
    + MANUAL.txt: document header and footer variables (newmana).
    + MANUAL.txt: self-contained implies standalone (#4304, Daniel Lublin).
    + CONTRIBUTING.md: label was renamed. (#4310, Alexander Brandizzi).
  * Require tagsoup 0.14.3 (#4282), fixing HTML tokenization bug.
  * Use latest texmath.
  * Use latest pandoc-citeproc.
  * Allow exceptions 0.9.
  * Require aeson-pretty 0.8.5 (#4394).
  * Bump blaze-markup, blaze-html lower bounds to 0.8, 0.9 (#4334).
  * Update tagsoup to 0.14.6 (Alexander Krotov, #4282).
  * Removed ghc-prof-options.  As of cabal 1.24, sensible defaults are used.
  * Update default.nix to current nixpkgs-unstable for hslua-0.9.5 (#4348,
    jarlg).
  * Markdown reader:
    + Don't coalesce adjacent raw LaTeX blocks if they are separated by a
    blank line.  See lierdakil/pandoc-crossref#160.
    + Improved `inlinesInBalancedBrackets` (#4272, jgm/pandoc-citeproc#315).
    The change both improves performance and fixes a regression whereby
    normal citations inside inline notes and figure captions were not
    parsed correctly.
  * RST reader:
    + Better handling for headers with an anchor (#4240).  Instead of creating a
    Div containing the header, we put the id directly on the header.
    This way header promotion will work properly.
    + Add aligned environment when needed in math (#4254).  `rst2latex.py`
    uses an `align*` environment for math in `.. math::` blocks, so this
    math may contain line breaks.  If it does, we put the math in an
    `aligned` environment to simulate `rst2latex.py`'s behavior.
  * HTML reader:
    + Fix col width parsing for percentages < 10%% (#4262, n3fariox).
  * LaTeX reader:
    + Advance source position at end of stream.
    + Pass through macro defs in `rawLaTeXBlock` even if the `latex_macros`
    extension is set (#4246).  This reverts to earlier behavior and is
    probably safer on the whole, since some macros only modify things in
    included packages, which pandoc's macro expansion can't modify.
    + Fixed pos calculation in tokenizing escaped space.
    + Allow macro definitions inside macros (#4253).  Previously we went into
    an infinite loop with
    ```
    \newcommand{\noop}[1]{#1}
    \noop{\newcommand{\foo}[1]{#1}}
    \foo{hi}
    ```
    + Fix inconsistent column widths (#4238).  This fixes a bug whereby column
    widths for the body were different from widths for the header in some
    tables.
  * Docx reader (Jesse Rosenthal):
    + Parse hyperlinks in `instrText` tags (#3389, #4266).  This was a form of
    hyperlink found in older versions of word. The changes introduced for
    this, though, create a framework for parsing further fields in MS Word
    (see the spec, ECMA-376-1:2016, §17.16.5, for more on these fields).
    We introduce a new module, `Text.Pandoc.Readers.Docx.Fields` which
    contains a simple parsec parser. At the moment, only simple hyperlink
    fields are accepted, but that can be extended in the future.
  * Muse reader (Alexander Krotov):
    + Parse `~~` as non-breaking space in Text::Amuse mode.
    + Refactor list parsing.
  * Powerpoint writer (Jesse Rosenthal):
    + Change reference to `notesSlide` to `endNotesSlide`.
    + Move image sizing into `picProps`.
    + Improve table placement.
    + Make our own `_rels/.rels` file.
    + Import reference-doc images properly.
    + Move `Presentation.hs` out of `PandocMonad`.
    + Refactor into separate modules.  T.P.W.Powerpoint.Presentation
    defines the Presentation datatype and goes Pandoc->Presentation;
    T.P.W.Pandoc.Output goes Presentation->Archive.
    Text.Pandoc.Writers.Powerpoint a thin wrapper around the two modules.
    + Avoid overlapping blocks in column output.
    + Position images correctly in two-column layout.
    + Make content shape retrieval environment-aware.
    + Improve image handling.  We now determine image and caption placement
    by getting the dimensions of the content box in a given layout.
    This allows for images to be correctly sized and positioned in a
    different template.  Note that images without captions and headers are
    no longer full-screened. We can't do this dependably in different
    layouts, because we don't know where the header is (it could be to
    the side of the content, for example).
    + Read presentation size from reference file.  Our presentation size is
    now dependent on the reference/template file we use.
    + Handle (sub)headers above slidelevel correctly.  Above the slidelevel,
    subheaders will be printed in bold and given a bit of extra space
    before them. Note that at the moment, no distinction is made between
    levels of headers above the slide header, though that can be changed.
    + Check for required files.  Since we now import from reference/dist
    file by glob, we need to make sure that we're getting the files we
    need to make a non-corrupt Powerpoint. This performs that check.
    + Improve templating using `--reference-doc`.  Templating should work
    much more reliably now.
    + Include Notes slide in TOC.
    + Set notes slide header to slide-level.
    + Add table of contents.  This is triggered by the `--toc` flag. Note
    that in a long slide deck this risks overrunning the text box. The user
    can address this by setting `--toc-depth=1`.
    + Set notes slide number correctly.
    + Clean up adding metadata slide.  We want to count the slide numbers
    correctly if it's in there.
    + Add anchor links.  For anchor-type links (`[foo](#bar)`) we produce
    an anchor link. In powerpoint these are links to slides, so we keep
    track of a map relating anchors to the slides they occur on.
    + Make the slide number available to the blocks.  For anchors,
    block-processing functions need to know what slide number
    they're in. We make the `envCurSlideId` available to blocks.
    + Move `curSlideId` to environment.
    + Allow setting `toc-title` in metadata.
    + Link notes to endnotes slide.
  * Markdown writer:
    + Fix cell width calculation (#4265).  Previously we could get
    ever-lengthening cell widths when a table was run repeatedly through
    `pandoc -f markdown -t markdown`.
  * LaTeX writer:
    + Escape `&` in lstinline (Robert Schütz).
  * ConTeXt writer:
    + Use xtables instead of Tables (#4223, Henri Menke).
    Default to xtables for context output.  Natural Tables are used
    if the new `ntb` extension is set.
  * HTML writer:
    + Fixed footnote backlinks with `--id-prefix` (#4235).
  * `Text.Pandoc.Extensions`:  Added `Ext_ntb` constructor (API change,
    Henri Menke).
  * `Text.Pandoc.ImageSize`: add derived `Eq` instance to `Dimension`
    (Jesse Rosenthal, API change).
  * Lua filters (Albert Krewinkel):
    + Make `PANDOC_READER_OPTIONS` available.
    The options which were used to read the document are made available to
    Lua filters via the `PANDOC_READER_OPTIONS` global.
    + Add lua module `pandoc.utils.run_json_filter`, which runs a JSON filter
    on a Pandoc document.
    + Refactor filter-handling code into `Text.Pandoc.Filter.JSON`,
    `Text.Pandoc.Filter.Lua`, and `Text.Pandoc.Filter.Path`.
    + Improve error messages.  Provide more context about the task
    which caused an error.
  * data/pandoc.lua (Albert Krewinkel):
    + Accept singleton inline as a list.  Every constructor which accepts a
    list of inlines now also accepts a single inline element for
    convenience.
    + Accept single block as singleton list. Every constructor which accepts
    a list of blocks now also accepts a single block element for
    convenience.  Furthermore, strings are accepted as shorthand for
    `{pandoc.Str "text"}` in constructors.
    + Add attr, listAttributes accessors.  Elements with
    attributes got an additional `attr` accessor. Attributes were
    accessible only via the `identifier`, `classes`, and `attributes`,
    which was in conflict with the documentation, which indirectly states
    that such elements have the an `attr` property.
    + Drop `_VERSION`.  Having a `_VERSION` became superfluous, as this
    module is closely tied to the pandoc version, which is available via
    `PANDOC_VERSION`.
    + Fix access to Attr components.  Accessing an Attr value (e.g.,
    ` Attr().classes`) was broken; the more common case of accessing it via
    an Inline or Block element was unaffected by this.
  * Move `metaValueToInlines` to from Docx writer to
    `Text.Pandoc.Writers.Shared`, so it can be used by other writers
    (Jesse Rosenthal).
  * MANUAL.txt:
    + Clarify otherlangs in LaTeX (#4072).
    + Clarify `latex_macros` extension.
    + Recommend use of `raw_attribute` extension in header includes (#4253).
  * Allow latest QuickCheck, tasty, criterion.
  * Remove custom prelude and ghc 7.8 support.
  * Reduce compiler noise (exact paths for compiled modules).
  * Allow filters and lua filters to be interspersed (#4196).  Previously
    we ran all lua filters before JSON filters.  Now we run filters in
    the order they are presented on the command line, whether lua or JSON.
    There are two incompatible API changes: The type of `applyFilters`
    has changed, and `applyLuaFilters` has been removed.  `Filter` is
    also now exported.
  * Use latest skylighting and omit the `missingIncludes` check, fixing
    a major performance regression in earlier releases of the 2.x series
    (#4226).  Behavior change: If you use a custom syntax definition that
    refers to a syntax you haven't loaded, pandoc will now complain when
    it is highlighting the text, rather than doing a check at the start.
    This change dramatically speeds up invocations of pandoc on short
    inputs.
  * Text.Pandoc.Class: make `FileTree` opaque (don't export
    `FileTree` constructor).  This forces users to interact with it using
    `insertInFileTree` and `getFileInfo`, which normalize file names.
  * Markdown reader:
    + Rewrite `inlinesInBalancedBrackets`.  The rewrite is much more
    direct, avoiding `parseFromString`.  And it performs significantly
    better; unfortunately, parsing time still increases exponentially
    (see #1735).
    + Avoid parsing raw tex unless `\` + letter seen.  This seems to
    help with the performance problem, #4216.
  * LaTeX reader: Simplified a check for raw tex command.
  * Muse reader (Alexander Krotov):
    + Enable round trip test (#4107).
    + Automatically translate `#cover` into `#cover-image`.
    Amusewiki uses #cover directive to specify cover image.
  * Docx reader (Jesse Rosenthal):
    + Allow for insertion/deletion of paragraphs (#3927).
    If the paragraph has a deleted or inserted paragraph break (depending
    on the track-changes setting) we hold onto it until the next
    paragraph. This takes care of accept and reject. For this we introduce
    a new state which holds the ils from the previous para if necessary.
    For `--track-changes=all`, we add an empty span with class
    `paragraph-insertion`/`paragraph-deletion` at the end of the paragraph
    prior to the break to be inserted or deleted.
    + Remove unused anchors (#3679).  Docx produces a lot of anchors with
    nothing pointing to them---we now remove these to produce cleaner
    output. Note that this has to occur at the end of the process
    because it has to follow link/anchor rewriting.
    + Read multiple children of `w:sdtContents`.
    + Combine adjacent anchors.  There isn't any reason to have numerous
    anchors in the same place, since we can't maintain docx's
    non-nesting overlapping. So we reduce to a single anchor.
    + Improved tests.
  * Muse writer (Alexander Krotov): don't escape URIs from AST
  * Docx writer:
    + Removed redundant subtitle in title (Sebastian Talmon).
    + `firstRow` table definition compatibility for Word 2016 (Sebastian
    Talmon).  Word 2016 seems to use a default value of "1" for table
    headers, if there is no firstRow definition (although a default
    value of 0 is documented), so all tables get the first Row formatted
    as header.  Setting the parameter to 0 if the table has no header
    row fixes this for Word 2016
    + Fix custom styles with spaces in the name (#3290).
  * Powerpoint writer (Jesse Rosenthal):
    + Ignore Notes div for parity with other slide outputs.
    + Set default slidelevel correctly.  We had previously defaulted to
    slideLevel 2. Now we use the correct behavior of defaulting to the
    highest level header followed by content. We change an expected test
    result to match this behavior.
    + Split blocks correctly for linked images.
    + Combine adjacent runs.
    + Make inline code inherit code size.  Previously (a) the code size
    wasn't set when we force size, and (b) the properties was set from
    the default, instead of inheriting.
    + Simplify `replaceNamedChildren` function.
    + Allow linked images.  The following markdown:
    `[![Image Title](image.jpg)](http://www.example.com)`
    will now produce a linked image in the resulting PowerPoint file.
    + Fix error with empty table cell.  We require an empty `<a:p>` tag,
    even if the cell contains no paragraphs---otherwise PowerPoint
    complains of corruption.
    + Implement two-column slides.  This uses the columns/column div
    format described in the pandoc manual. At the moment, only two
    columns (half the screen each) are allowed. Custom widths are not
    supported.
    + Added more tests.
  * OpenDocument/ODT writers: improved rendering of formulas (#4170, oltolm).
  * Lua filters (Albert Krewinkel):
    + `data/pandoc.lua`: drop 'pandoc-api-version' from Pandoc objects
    + The current pandoc-types version is made available to Lua programs in
    the global `PANDOC_API_VERSION`. It contains the version as a list of
    numbers.
    + The pandoc version available as a global `PANDOC_VERSION` (a list
    of numbers).
    + `data/pandoc.lua`: make `Attr` an `AstElement`.
    + `data/pandoc.lua`: make all types subtypes of `AstElement`.
    `Pandoc`, `Meta`, and `Citation` were just plain functions and did
    not set a metatable on the returned value, which made it difficult
    to amend objects of these types with new behavior. They are now
    subtypes of AstElement, meaning that all their objects can gain
    new features when a method is added to the behavior object
    (e.g., `pandoc.Pandoc.behavior`).
    + `data/pandoc.lua`: split type and behavior tables.  Clearly distinguish
    between a type and the behavioral properties of an instance of that
    type. The behavior of a type (and all its subtypes) can now be
    amended by adding methods to that types `behavior` object, without
    exposing the type objects internals.  E.g.:
    ```lua
    pandoc.Inline.behavior.frob = function () print'42' end
    local str = pandoc.Str'hello'
    str.frob() -- outputs '42'
    ```
    + `data/pandoc.lua`: fix Element inheritance.  Extending all elements
    of a given type (e.g., all inline elements) was difficult, as the
    table used to lookup unknown methods would be reset every time a
    new element of that type was created, preventing recursive property
    lookup. This is was changed in that all methods and attributes of
    supertypes are now available to their subtypes.
    + `data/pandoc.lua`: fix attribute names of Citation (#4222).  The
    fields were named like the Haskell fields, not like the documented,
    shorter version.  The names are changed to match the documentation
    and Citations are given a shared metatable to enable simple
    extensibility.
    + `data/pandoc.lua`: drop function `pandoc.global_filter`.
    + Bump `hslua` version to 0.9.5.  This version fixes a bug that made it
    difficult to handle failures while getting lists or a Map from Lua.
    A bug in pandoc, which made it necessary to always pass a tag when
    using MetaList or MetaBlock, is fixed as a result. Using the pandoc
    module's constructor functions for these values is now optional
    (if still recommended).
    + Stop exporting `pushPandocModule` (API change).  The introduction
    of `runPandocLua` renders direct use of this function obsolete.
    + Update generation of module docs for lua filters.
    + `Lua.Module.Utils`: make stringify work on `MetaValues` (John
    MacFarlane).  I'm sure this was intended in the first place,
    but currently only `Meta` is supported.
  * Improve benchmarks.
    + Set the default extensions properly.
    + Improve benchmark argument parsing.  You can now say
    `make bench BENCHARGS="markdown latex reader"` and both the
    markdown and latex readers will be benchmarked.
  * MANUAL.txt simplify and add more structure (Mauro Bieg).
  * Generate README.md from template and MANUAL.txt.
    `make README.md` will generate the README.md after changes
    to MANUAL.txt have been made.
  * Update copyright notices to include 2018 (Albert Krewinkel).
  * Added `jats` as an input format.
    + Add Text.Pandoc.Readers.JATS, exporting `readJATS` (API
    change) (Hamish Mackenzie).
    + Improved citation handling in JATS reader.  JATS citations
    are now converted to pandoc citations, and JATS ref-lists
    are converted into a `references` field in metadata, suitable
    for use with pandoc-citeproc. Thus a JATS article with embedded
    bibliographic information can be processed with pandoc and
    pandoc-citeproc to produce a formatted bibliography.
  * Allow `--list-extensions` to take an optional FORMAT argument.
    This lists the extensions set by default for the selected FORMAT.
    The extensions are now alphabetized, and the `+` or `-`
    indicating the default setting comes before, rather than after,
    the extension.
  * Markdown reader:
    + Preserve original whitespace between blocks.
    + Recognize `\placeformula` as context.
    + Be pickier about table captions.  A caption starts with a `:` which
    can't be followed by punctuation.  Otherwise we can falsely interpret
    the start of a fenced div, or even a table header line like
    `:--:|:--:`, as a caption.
    + Always use four space rule for example lists.  It would be awkward
    to indent example list contents to the first non-space character after
    the label, since example list labels are often long.  Thanks to
    Bernhard Fisseni for the suggestion.
    + Improve raw tex parsing.  Note that the Markdown reader is also
    affected by the `latex_macros` extension changes described below
    under the LaTeX reader.
  * LaTeX reader:
    + `latex_macros` extension changes (#4179).  Don't pass through macro
    definitions themselves when `latex_macros` is set.  The macros
    have already been applied.  If `latex_macros` is enabled, then
    `rawLaTeXBlock` in Text.Pandoc.Readers.LaTeX will succeed in parsing
    a macro definition, and will update pandoc's internal macro map
    accordingly, but the empty string will be returned.
    + Export `tokenize`, `untokenize` (API change).
    + Use `applyMacros` in `rawLaTeXBlock`, `rawLaTeXInline`.
    + Refactored `inlineCommand`.
    + Fix bug in tokenizer.  Material following `^^` was
    dropped if it wasn't a character escape.  This only affected
    invalid LaTeX, so we didn't see it in the wild, but it appeared
    in a QuickCheck test failure.
    + Fix regression in LateX tokenization (#4159).  This mainly affects the
    Markdown reader when parsing raw LaTeX with escaped spaces.
    + Add tests of LaTeX tokenizer.
    + Support `\foreignlanguage` from babel.
    + Be more tolerant of `&` character (#4208).  This allows us to parse
    unknown tabular environments as raw LaTeX.
  * Muse reader (Alexander Krotov):
    + Parse anchors immediately after headings as IDs.
    + Require that note references does not start with 0.
    + Parse empty comments correctly.
  * Org reader (Albert Krewinkel):
    + Fix asterisks-related parsing error (#4180).
    + Support minlevel option for includes (#4154).  The level of headers
    in included files can be shifted to a higher level by specifying a
    minimum header level via the `:minlevel` parameter. E.g.
    `#+include: "tour.org" :minlevel 1` will shift the headers in
    tour.org such that the topmost headers become level 1 headers.
    + Break-up org reader test file into multiple modules.
  * OPML reader:
    + Enable raw HTML and other extensions by default for notes
    (#4164).  This fixes a regression in 2.0.  Note that extensions can
    now be individually disabled, e.g.  `-f opml-smart-raw_html`.
  * RST reader:
    + Allow empty list items (#4193).
    + More accurate parsing of references (#4156).  Previously we erroneously
    included the enclosing backticks in a reference ID (#4156).  This
    change also disables interpretation of syntax inside references, as
    in docutils.  So, there is no emphasis in `` `my *link*`_ ``.
  * Docx reader:
    + Continue lists after interruption (#4025, Jesse Rosenthal).
    Docx expects that lists will continue where they left off after an
    interruption and introduces a new id if a list is starting again. So
    we keep track of the state of lists and use them to define a "start"
    attribute, if necessary.
    + Add tests for structured document tags unwrapping (Jesse Rosenthal).
    + Preprocess Document body to unwrap `w:sdt` elements (Jesse Rosenthal,
    [#4190]).
  * Plain writer:
    + Don't linkify table of contents.
  * RST writer:
    + Fix anchors for headers (#4188).  We were missing an `_`.
  * PowerPoint writer (Jesse Rosenthal):
    + Treat lists inside BlockQuotes as lists.  We don't yet produce
    incremental lists in PowerPoint, but we should at least treat lists
    inside BlockQuotes as lists, for compatibility with other slide formats.
    + Add ability to force size.  This replaces the more specific
    `blockQuote runProp`, which only affected the size of blockquotes. We
    can use this for notes, etc.
    + Implement notes.  This currently prints all notes on a final slide.
    Note that at the moment, there is a danger of text overflowing the
    note slide, since there is no logic for adding further slides.
    + Implement basic definition list functionality to PowerPoint writer.
    + Don't look for default template file for Powerpoint (#4181).
    + Add pptx to isTextFormat list.  This is used to check standalone
    and not writing to the terminal.
    + Obey slide level option (Jesse Rosenthal).
    + Introduce tests.
  * Docx writer:
    + Ensure that `distArchive` is the one that comes with pandoc
    (#4182).  Previously a `reference.docx` in `~/.pandoc` (or the user data
    dir) would be used instead, and this could cause problems because a
    user-modified docx sometimes lacks vital sections that we count
    on the `distArchive` to supply.
  * Org writer:
    + Do not wrap "-" to avoid accidental bullet lists (Alexander Krotov).
    + Don't allow fn refs to wrap to beginning of line (#4171, with help from
    Alexander Krotov).  Otherwise they can be interpreted as footnote
    definitions.
  * Muse writer (Alexander Krotov):
    + Don't wrap note references to the next line (#4172).
  * HTML writer:
    + Use br elements in line blocks instead of relying on CSS
    (#4162).  HTML-based templates have had the custom CSS for
    `div.line-block` removed.  Those maintaining custom templates will want
    to remove this too.  We still enclose line blocks in a div with class
    `line-block`.
  * LaTeX writer:
    + Use `\renewcommand` for `\textlatin` with babel (#4161).
    This avoids a clash with a deprecated `\textlatin` command defined
    in Babel.
    + Allow fragile=singleslide attribute in beamer slides (#4169).
    + Use `\endhead` after `\toprule` in headerless tables (#4207).
  * FB2 writer:
    + Add cover image specified by `cover-image` meta (Alexander Krotov,
    [#4195]).
  * JATS writer (Hamish Mackenzie):
    + Support writing `<fig>` and `<table-wrap>` elements
    with `<title>` and `<caption>` inside them by using Divs with class set
    to one of `fig`, `table-wrap` or `caption` (Hamish Mackenzie).  The
    title is included as a Heading so the constraint on where Heading can
    occur is also relaxed.
    + Leave out empty alt attributes on links.
    + Deduplicate image mime type code.
    + Make `<p>` optional in `<td>` and `<th>` (#4178).
    + Self closing tags for empty xref (#4187).
    + Improve support for code language.
  * Custom writer:
    + Use init file to setup Lua interpreter (Albert Krewinkel).
    The same init file (`data/init`) that is used to setup the Lua
    interpreter for Lua filters is also used to setup the interpreter of
    custom writers.lua.
    + Define instances for newtype wrapper (Albert Krewinkel).  The custom
    writer used its own `ToLuaStack` instance definitions, which made
    it difficult to share code with Lua filters, as this could result
    in conflicting instances.  A `Stringify` wrapper is introduced to
    avoid this problem.
    + Added tests for custom writer.
    + Fixed definition lists and tables in `data/sample.lua`.
  * Fixed regression: when target is PDF, writer extensions were being
    ignored.  So, for example, `pandoc -t latex-smart -o file.pdf`
    did not work properly.
  * Lua modules (Albert Krewinkel):
    + Add `pandoc.utils` module, to hold utility functions.
    + Create a Haskell module Text.Pandoc.Lua.Module.Pandoc to
    define the `pandoc` lua module.
    + Make a Haskell module for each Lua module. Move definitions for the
    `pandoc.mediabag` modules to a separate Haskell module.
    + Move `sha1` from the main `pandoc` module to `pandoc.utils`.
    + Add function `pandoc.utils.hierarchicalize` (convert list of
    Pandoc blocks into (hierarchical) list of Elements).
    + Add function `pandoc.utils.normalize_date` (parses a date and
    converts it (if possible) to "YYYY-MM-DD" format).
    + Add function `pandoc.utils.to_roman_numeral` (allows conversion
    of numbers below 4000 into roman numerals).
    + Add function `pandoc.utils.stringify` (converts any AST element
    to a string with formatting removed).
    + `data/init.lua`: load `pandoc.utils` by default
    + Turn pipe, read into full Haskell functions.  The `pipe` and `read`
    utility functions are converted from hybrid lua/haskell functions
    into full Haskell functions. This avoids the need for intermediate
    `_pipe`/`_read` helper functions, which have dropped.
    + pandoc.lua: re-add missing MetaMap function.  This was a bug
    introduced in version 2.0.4.
  * Text.Pandoc.Class: Add `insertInFileTree` [API change].  This gives
    a pure way to insert an ersatz file into a `FileTree`.  In addition, we
    normalize paths both on insertion and on lookup.
  * Text.Pandoc.Shared: export `blocksToInlines'` (API change, Maura Bieg).
  * Text.Pandoc.MIME: Add opus to MIME type table as audio/ogg (#4198).
  * Text.Pandoc.Extensions:   Alphabetical order constructors for
    `Extension`.  This makes them appear in order in `--list-extensions`.
  * Allow lenient decoding of latex error logs, which are not always
    properly UTF8-encoded (#4200).
  * Update latex template to work with recent versions of beamer.
    The old template produced numbered sections with some recent
    versions of beamer.  Thanks to Thomas Hodgson.
  * Updated reference.docx (#4175).  Instead of just "Hello, world", the
    document now contains exemplars of most of the styles that have an
    effect on pandoc documents.  This makes it easier to see the effect
    of style changes.
  * Removed `default.theme` data file (#4096).  It is no longer needed now
    that we have `--print-highlight-style`.
  * Added `stack.lts9.yaml` for building with lts 9 and ghc 8.0.2.
    We still need this for the alpine static linux build, since
    we don't have ghc 8.2.2 for that yet.
  * Removed `stack.pkg.yaml`.  We only really need `stack.yaml`; we
    can put flag settings for pandoc-citeproc there.
  * Makefile: Add 'trypandoc' and 'pandoc-templates' targets to
    make releases easier.
  * MANUAL.txt:
    + Add note on what formats have `+smart` by default.
    + Use native syntax for custom-style (#4174, Mauro Bieg).
    + Introduce dedicated Extensions section, since some extensions
    affect formats other than markdown (Mauro Bieg, #4204).
    + Clarify default html output for `--section-divs` (Richard Edwards).
  * filters.md: say that Text.Pandoc.JSON comes form pandoc-types.
    Closes jgm/pandoc-website#16.
  * epub.md: Delete removed `-S` option from command (#4151, Georger Araújo).
  * Fix a bug in 2.0.4, whereby pandoc could not read the theme files
    generated with `--print-highlight-style` (#4133).  Improve JSON
    serialization of styles.
  * Fix CSS issues involving line numbers (#4128).
    Highlighted code blocks are now enclosed in a div with class `sourceCode`.
    Highlighting CSS no longer sets a generic color for pre and code; we only
    set these for class `sourceCode`.
  * `--pdf-engine-opt`: fix bug where option order was reversed (#4137).
  * Add PowerPoint (pptx) writer (Jesse Rosenthal).
    It works following the standard Pandoc conventions for making other
    sorts of slides. Caveats:
    + Syntax highlighting is not yet implemented. (This is difficult
    because there are no character classes in Powerpoint.)
    + Footnotes and Definition lists are not yet implemented. (Notes will
    usually take the form of a final slide.
    + Image placement and auto-resizing has a few glitches.
    + Reference powerpoint files don't work dependably from the command
    line. This will be implemented, but at the moment users are advised
    to change themes from within Powerpoint.
  * Create shared Text.Pandoc.Writers.OOXML module (Jesse Rosenthal).
    This is for functions used by both Powerpoint and Docx writers.
  * Add default pptx data for Powerpoint writer (Jesse Rosenthal).
  * Add `empty_paragraphs` extension.
    + Deprecate `--strip-empty-paragraphs` option.  Instead we now
    use an `empty_paragraphs` extension that can be enabled on
    the reader or writer.  By default, disabled.
    + Add `Ext_empty_paragraphs` constructor to `Extension`.
    + Revert "Docx reader: don't strip out empty paragraphs."
    This reverts commit d6c58eb836f033a48955796de4d9ffb3b30e297b.
    + Implement `empty_paragraphs` extension in docx reader and writer,
    opendocument writer, HTML reader and writer.
    + Add tests for `empty_paragraphs` extension.
  * Markdown reader:
    + Don't parse native div as table caption (#4119).
    + Improved computation of column widths in pipe tables.
    Pipe tables with lines longer than the text width (as set
    by `--columns`) are now scaled to text width, with the relative
    widths of columns determined by the ratios between the
    header lines.  Previously we computed column widths using
    the ratio of header line lengths to column width, so that
    tables with narrow header lines were extremely thin, which
    was very rarely the desired result.
  * LaTeX reader: fix `\` before newline (#4134).  This should be a space,
    as long as it's not followed by a blank line. This has been fixed at the
    tokenizer level.
  * Muse reader (Alexander Krotov):
    + Add test for `#disable-tables` directive in Emacs mode.
    + Don't allow emphasis to be preceded by letter.
    + Add underline support in Emacs Muse mode..
    + Support multiline directives in Amusewiki mode
  * Man writer: omit internal links (#4136).  That is, just print the link
    text without the URL.
  * Markdown reader: accept processing instructions as raw HTML (#4125).
  * Lua filters (Albert Krewinkel):
    + Use script to initialize the interpreter.  The file `init.lua` is
    used to initialize the Lua interpreter which is used in Lua filters.
    This gives users the option to require libraries which they want to
    use in all of their filters, and to extend default modules.
    + Fix package loading for Lua 5.1.  The list of package searchers is
    named `package.loaders` in Lua 5.1 and LuaJIT, and `package.searchers`
    in Lua 5.2 and later.
    + Refactor lua module handling.  The integration with Lua's package/module
    system is improved: A pandoc-specific package searcher is prepended to
    the searchers in `package.searchers`. The modules `pandoc` and
    `pandoc.mediabag` can now be loaded via `require`.
    + Bump lower bound of hslua.  The release hslua 0.9.3 contains a new
    function which makes using Haskell functions as package loaders much
    easier.
  * reveal.js template:  add title-slide identifier to title slide (#4120).
    This allows it to be styled more easily.
  * LaTeX template: Added support for `pagestyle` variable (#4135,
    Thomas Hodgson)
  * Add `-threaded` to ghc-options for executable (#4130, fixes a build
    error on linux).
  * Add `--print-highlight-style` option.  This generates a JSON version
    of a highlighting style, which can be saved as a `.theme` file, modified,
    and used with `--highlight-style` (#4106, #4096).
  * Add `--strip-empty-paragraphs` option.  This works for any input format.
    It is primarily intended for use with docx and odt documents where
    empty paragraphs have been used for inter-paragraph spaces.
  * Support `--webtex` for `gfm` output.
  * Recognize `.muse` file extension.
  * Support beamer `\alert` in LaTeX reader. Closes #4091.
  * Docx reader: don't strip out empty paragraphs (#2252).
    Users who have a conversion pipeline from docx may want to consider adding
    `--strip-empty-paragraphs` to the command line.
  * Org reader (Albert Krewinkel): Allow empty list items (#4090).
  * Muse reader (Alexander Krotov):
    + Parse markup in definition list terms.
    + Allow definition to end with EOF.
    + Make code blocks round trip.
    + Drop common space prefix from list items.
    + Add partial round trip test.
    + Don't interpret XML entities.
    + Remove `nested`.
    + Parse `~~` as non-breaking space in Emacs mode.
    + Correctly remove indentation from notes.  Exactly one space is
    required and considered to be part of the marker.
    + Allow list items to be empty.
    + Add ordered list test.
    + Add more multiline definition tests.
    + Don't allow blockquotes within lists.
    + Fix reading of multiline definitions.
    + Add inline `<literal>` support.
    + Concatenate inlines of the same type
  * Docx writer: allow empty paragraphs (#2252).
  * CommonMark/gfm writer:
    + Use raw html for native divs/spans (#4113).  This allows a pandoc
    markdown native div or span to be rendered in gfm using raw html tags.
    + Implement `raw_html` and `raw_tex` extensions.  Note that `raw_html`
    is enabled by default for `gfm`, while `raw_tex` is disabled by default.
  * Muse writer (Alexander Krotov):
    + Test that inline math conversion result is normalized.
    Without normalization this test produced
    `<em>a</em><em>b</em><em>c</em>`.
    + Improve inline list normalization and move to writer.
    + Escape hash symbol.
    + Escape `----` to avoid accidental horizontal rules.
    + Escape only `</code>` inside code tag.
    + Additional `<verbatim>` is not needed as `<code>` is verbatim already.
  * LaTeX writer:
    + Allow specifying just width or height for image size.
    Previously both needed to be specified (unless the image was
    being resized to be smaller than its original size).
    If height but not width is specified, we now set width to
    textwidth. If width but not height is specified, we now set
    height to textheight.  Since we have `keepaspectratio`, this
    yields the desired result.
    + Escape `~` and `_` in code with `--listings` (#4111).
  * HTML writer: export `tagWithAttributes`.  This is a helper allowing
    other writers to create single HTML tags.
  * Let papersizes `a0`, `a1`, `a2`, ... be case-insensitive by
    converting the case as needed in LaTeX and ConTeXt writers.
  * Change `fixDisplayMath` from `Text.Pandoc.Writers.Shared`
    so that it no longer produces empty `Para`'s as an artifact.
  * `Text.Pandoc.Shared.blocksToInlines`:  rewrote using builder.
    This gives us automatic normalization, so we don't get
    for example two consecutive Spaces.
  * Include default CSS for 'underline' class in HTML-based templates.
  * revealjs template:  add `tex2jax` configuration for the
    math plugin.  With the next release of reveal.js, this will
    fix the problem of `$`s outside of math contexts being
    interpreted as math delimiters (#4027).
  * `pandoc.lua` module for use in lua filters (Albert Krewinkel):
    + Add basic lua List module (#4099, #4081).  The List module is
    automatically loaded, but not assigned to a global variable. It can be
    included in filters by calling `List = require 'List'`.  Lists of blocks,
    lists of inlines, and lists of classes are now given `List` as a metatable,
    making working with them more convenient.  E.g., it is now possible to
    concatenate lists of inlines using Lua's concatenation operator `..`
    (requires at least one of the operants to have `List` as a metatable):
    function Emph (emph)
    local s = {pandoc.Space(), pandoc.Str 'emphasized'}
    return pandoc.Span(emph.content .. s)
    end
    The `List` metatable is assigned to the tables which get passed to
    the constructors `MetaBlocks`, `MetaInline`, and `MetaList`. This
    enables the use of the resulting objects as lists.
    + `Lua/StackInstances`: push Pandoc and Meta via constructor.
    Pandoc and Meta elements are now pushed by calling the respective
    constructor functions of the pandoc Lua module. This makes serialization
    consistent with the way blocks and inlines are pushed to lua and allows
    to use List methods with the `blocks` value.
    + Add documentation for pandoc.List in `lua-filters.md`.
  * Use latest tagsoup.  This fixes a bug in parsing HTML tags with
    `&` (but not a valid entity) following them (#4094, #4088).
  * Use skylighting 0.4.4.1, fixing the color of unmarked code text
    when `numberLines` is used (#4103).
  * Make `normalizeDate` more forgiving (Mauro Bieg, #4101), not
    requiring a leading 0 on single-digit days.
  * Fix `--help` output for `--highlight-style` to include `FILE` (Mauro
    Bieg, #4095).
  * Clearer deprecation warning for `--latexmathml, --asciimathml, -m`.
    Previously we only mentioned `--latexmathml`, even if `-m` was
    used.
  * Changelog: fix description of lua filters in 2.0 release
    (Albert Krewinkel).  Lua filters were initially run *after* conventional
    (JSON) filters.  However, this was changed later to make it easier to deal
    with files in the mediabag. The changelog is updated to describe that
    feature of the 2.0 release correctly.
  * Change Generic JSON instances to TemplateHaskell (Jasper Van der Jeugt,
    [#4085]).  This reduces compile time and memory usage significantly.
  * `lua-filters.md`: Added tikz filter example.
  * Create alternative zip file for macOS binaries.
  * Create alternative zip file for Windows binaries.
  * Update INSTALL.md since we now provide zips for binaries.
  * Relax `http-types` dependency (Justus Sagemüller, #4084).
  * Add `epub.md`, `getting-started.md` to docs.  These used to live in
    the website repo.
  * Add `packages` target to Makefile.
  * Bump bounds for binary, http-types, tasty-hunit
  * Lua filters: preload text module (Albert Krewinkel, #4077).
    The `text` module is preloaded in lua. The module contains some UTF-8
    aware string functions, implemented in Haskell.  The module is loaded on
    request only, e.g.:
    text = require 'text'
    function Str (s)
    s.text = text.upper(s.text)
    return s
    end
  * Allow table-like access to attributes in lua filters (Albert Krewinkel,
    [#4071]).  Attribute lists are represented as associative lists in Lua. Pure
    associative lists are awkward to work with. A metatable is attached to
    attribute lists, allowing to access and use the associative list as if
    the attributes were stored in as normal key-value pair in table.
    Note that this changes the way `pairs` works on attribute lists. Instead
    of producing integer keys and two-element tables, the resulting iterator
    function now returns the key and value of those pairs.  Use `ipairs` to
    get the old behavior.  Warning: the new iteration mechanism only works if
    pandoc has been compiled with Lua 5.2 or later (current default: 5.3).
  * Text.Pandoc.Parsing.uri:  allow `&` and `=` as word characters (#4068).
    This fixes a bug where pandoc would stop parsing a URI with an
    empty attribute:  for example, `&a=&b=` wolud stop at `a`.
    (The uri parser tries to guess which punctuation characters
    are part of the URI and which might be punctuation after it.)
  * Introduce `HasSyntaxExtensions` typeclass (Alexander Krotov, #4074).
    + Added new `HasSyntaxExtensions` typeclass for `ReaderOptions` and
    `WriterOptions`.
    + Reimplemented `isEnabled` function from `Options.hs` to accept both
    `ReaderOptions` and `WriterOptions`.
    + Replaced `enabled` from `CommonMark.hs` with new `isEnabled`.
  * Add `amuse` extension (Alexander Krotov) to enable Amuse wiki
    behavior for `muse`.  New `Ext_amuse` constructor for
    `Extension`. Note: this is switched on by default; for
    Emacs behavior, use `muse-amuse`.
  * Muse reader (Alexander Krotov):
    + Count only one space as part of list item marker.
    + Produce SoftBreaks on newlines. Now wrapping can be preserved
    with `--wrap=preserve`.
    + Add Text::Amuse footnote extensions.  Footnote end is indicated by
    indentation, so footnotes can be placed anywhere in the text,
    not just at the end of it.
    + Accept Emacs Muse definition lists when `-amuse`.
    Emacs Muse does not require indentation.
  * HTML reader:
    + Ensure we don't produce level 0 headers (#4076), even for chapter
    sections in epubs.  This causes problems because writers aren't set
    up to expect these.
    + Allow spaces after `\(` and before `\)` with `tex_math_single_backslash`.
    Previously `\( \frac{1}{a} < \frac{1}{b} \)` was not parsed as math in
    `markdown` or `html` `+tex_math_single_backslash`.
    + Parse div with class `line-block` as LineBlock.
    + Don't fail with block-level content in figcaption (Mauro Bieg, #4183).
  * MANUAL: clarify that math extensions work with HTML.
    Clarify that `tex_math_dollars` and `tex_math_single_backslash`
    will work with HTML as well as Markdown.
  * Creole reader: Fix performance issue for longer lists (Sascha Wilde,
    [#4067]).
  * RST reader: better support for 'container' directive (#4066).
    Create a div, incorporate name attribute and classes.
  * LaTeX reader:
    + Support column specs like `*{2}{r}` (#4056).  This is equivalent to
    `rr`.  We now expand it like a macro.
    + Allow optional args for parbox (#4056).
    + Allow optional arguments on `\footnote` (#4062).
  * EPUB writer: Fixed path for cover image (#4069).  It was previously
    `media/media/imagename`, and should have been `media/imagename`.
  * Markdown writer: fix bug with doubled footnotes in grid tables
    (#4061).
  * LaTeX template:  include natbib/biblatex after polyglossia (#4073).
    Otherwise we seem to get an error; biblatex wants polyglossia
    language to be defined.
  * Added examples to lua filters documentation.
  * Deprecated ancient HTML math methods: `--latexmathml`, `--gladtex`,
    `--mimetex`, `--jsmath`.
  * Fixed URIs in `data/jats.csl`.  They were being rendered twice,
    leading to invalid XML in default JATS output with pandoc-citeproc.
  * `lua-filters.md`: use real-world man page filter as example.
  * Add lua filter functions `walk_inline` and `walk_block`
    in the pandoc module, to apply filters inside particular
    inline and block elements.
  * Refactored some code from `Text.Pandoc.Lua.PandocModule`
    into new internal module `Text.Pandoc.Lua.Filter`.
  * Markdown reader:
    + Allow fenced code blocks to be indented 1-3 spaces (#4011).
    This brings our handling of them into alignment with CommonMark's.
    + Fix YAML metadata with "chomp" (`|-`).  Previously if a
    YAML block under `|-` contained a blank line, pandoc would
    not parse it as metadata.
  * Removed `etc.` from abbreviations file.  Often `etc.` ends a
    sentence, and we want the period to be treated as a
    sentence-ending period.
  * Fix regression with `--metadata` (#4054).  Values specified with
    `--metadata` should replace a metadata value set in the document
    itself, rather than creating a list including a new value.
  * EPUB writer:
    + Fix EPUB OCF structure.  #3720 had been improperly implemented.
    + Fix modified paths for raw HTML tags (src, poster, etc.)
    (#4050, #4055). This had not been updated for the new EPUB
    container layout, with a separate text/ subdirectory.
    + Fix image paths with empty `--epub-subdirectory`.
  * Miscellaneous code cleanup (Alexander Krotov).
  * Use pandoc-types 1.17.3, which adds `Walkable` instances
    for `[Block] Block` and `[Inline] Inline`.
  * Remove obsolete `stack.full.yaml` (#4052).
  * Change to using pandoc-citeproc 0.12.1 in binary packages.
  * Consolidate math output method documentation (#4049, Mauro Bieg).
  * `MANUAL.txt`: fix header level of "Extension: emoji" (Albert Krewinkel).
  * Use lua filter to generate man page from `MANUAL.txt`, replacing old
    Haskell filters.  This is easier and faster.
  * Improved `INSTALL.md`.
  * Update commands to extract deb archive on Linux (#4043, Salim B).
  * Improved fix to #3989 (parsing of HTML tags containing
    `>` in an attribute or comment). The previous fix (in 2.0.1) only
    worked in certain cases.
  * FB2 writer (Alexander Krotov):
    + Add `unrecognised` genre to `<title-info>`
    (Alexander Krotov).  XML schema requires at least one genre.
    + Remove `<annotation>` from `<body>`.
  * CommonMark writer: fix strikethrough for `gfm` (#4038).
  * Use texmath 0.10, which adds support for a wider range of
    symbols and fixes default column alignments in MathML
    and OMML.
  * Highlighting fixes, using skylighting 0.4.3.2:
    + Fix invalid CSS.
    + Support `lineAnchors` (or `line-anchors`) in HTML code blocks.
    + Ensure that code lines don't get duplicate identifiers (#4031).
    The line identifiers are built using the code block's identifier
    as a prefix. If the code block has null identifier, we use
    `cb1`, `cb2`, etc.
  * Added a few abbreviations to `data/abbreviations`,
    and sorted the list (#3984, Wandmalfarbe).
  * Improved support for columns in HTML writer (#4028).
    + Remove `width` attribute from the `div`.
    + Remove space between `<div class="column">` elements,
    since this prevents columns whose widths sum to 100%%
    (the space takes up space).
    + Move as much as possible of the CSS to the template.
    + Ensure that all the HTML-based templates (including epub)
    contain the CSS for columns.
    + Columns default to 50%% width unless they are given a width
    attribute.  So if you want two equal-width columns, you
    can use a div with class `column` and no `width` attribute.
  * SelfContained: use `base64` for css links with media attribute (#4026).
    This fixes `--self-contained` with S5.
  * Improve `pandoc-template-mode.el` (Vaclav Haisman).
  * Issue INFO, not WARNING, when a .sty file cannot be
    read in LaTeX reader.  It is normally not an issue requiring
    a fix from the user if .sty files are not found.
  * INSTALL.md: MacOS instructions needed xar -f (adam234).
  * MANUAL.txt:
    + Clarify that --setext-headers doesn't affect gfm output (#4035).
    + Clarify what is needed to open and close a div in `fenced_divs`
    (#4039, Tristano Ajmone).
    + Removed reference to `default.beamer` in docs (#4024).
    Also added mention of other templates affecting PDF output
    with different settings.
  * Fixed regression in parsing of HTML comments in markdown and other
    non-HTML formats (`Text.Pandoc.Readers.HTML.htmlTag`) (#4019).
    The parser stopped at the first `>` character, even if it wasn't
    the end of the comment.
  * Creole reader (Sascha Wilde):
    + Fix some minor typos and formatting.
    + Add additional test on nowiki-block after para.
    + Fix lists with trailing white space.
  * LaTeX reader: handle `%%` comment right after command.
    For example, `\emph%%`.
  * Markdown reader:  make sure fenced div closers work in lists.
    Previously the following failed:
    ::: {.class}
    1. one
    2. two
    :::
    and you needed a blank line before the closing `:::`.
  * Make `fenced_divs` affect the Markdown writer.  If `fenced_divs` is
    enabled, Divs will be rendered as fenced divs.
  * LaTeX/Beamer writer: support "blocks" inside columns and other Divs
    (#4016).
  * HTML Writer: consistently use dashed class-names (Mauro Bieg, #3556).
    Note: this change may require some changes in CSS rules.
    `footnoteRef` has become `footnote-ref`, `titleslide` has
    become `title-slide`, and `footnoteBack` has become `footnote-back`.
  * JATS writer: Properly pass through author metadata (#4020).
  * FB2 writer (Alexander Krotov):
    + Write blocks outside of `<p>` in definitions.
    + Make bullet lists consistent with ordered lists, repeating
    the marker for the outer list rather than indenting sublists,
    since indentation does not work in readers.
    + Add new style FB2 tests.
  * `Text.Pandoc.ImageSize`: Add `Millimeter` constructor to `Dimension`
    (#4012) [API change]. Now sizes given in 'mm' are no longer converted
    to 'cm'.
  * Revise documentation of small caps syntax (Andrew Dunning, #4013).
  * Fix broken reference links in manual (Andrew Dunning, #4014)
  * Fixed example of slide columns structure in changelog (#4015).
    Also documented this feature in MANUAL.txt.
  * EPUB writer:
    + Fixed filepaths for nonstandard epub-subdirectory values.
    + Ensure that epub2 is recognized as a non-text format,
    so that a template is used.
    + Don't include "prefix" attribute for ibooks for epub2.
    It doesn't validate.
    + Fix stylesheet paths; previously we had an incorrect
    stylesheet path for the cover page and nav page.
  * LaTeX reader:
    + Insert space when needed in macro expansion (#4007).
    Sometimes we need to insert a space after a control sequence
    to prevent it merging with a following letter.
    + Allow unbraced arguments for macros (#4007).
    + Allow body of macro definition to be unbraced (#4007).
  * Linux package build: ensure that pandoc-citeproc is statically linked.
  * trypandoc: add native, ms.
  [new features]
  * New output format `ms` (groff ms). Complete support, including
    tables, math, syntax highlighting, and PDF bookmarks. The writer uses
    texmath's new eqn writer to convert math to eqn format, so a ms file
    produced with this writer should be processed with `groff -ms -e` if
    it contains math.
  * New output format `jats` (Journal Article Tag Suite).  This is an XML
    format used in archiving and publishing articles.  Note that a
    URI-encoded CSL stylesheet (`data/jats.csl`) is added automatically
    unless a stylesheet is specified using `--css`.
  * New output format `gfm` (GitHub-flavored CommonMark) (#3841).
    This uses bindings to GitHub's fork of cmark, so it should parse
    gfm exactly as GitHub does (excepting certain postprocessing
    steps, involving notifications, emojis, etc.).  `markdown_github`
    has been deprecated in favor of `gfm`.
  * New output format `muse` (Emacs Muse) (Alexander Krotov, #3489).
  * New input format `gfm` (GitHub-flavored CommonMark) (#3841).
    This uses bindings to GitHub's fork of cmark.  `markdown_github`
    has been deprecated in favor of `gfm`.
  * New input format `muse` (Emacs Muse) reader (Alexander Krotov, #3620).
  * New input format `tikiwiki` (TikiWiki markup) (rlpowell, #3800).
  * New input format `vimwiki` (Vimwiki markup) (Yuchen Pei, #3705).
    Note that there is a new data file, `data/vimwiki.css`, which can
    be used to display the HTML produced by this reader and
    pandoc's HTML writer in the style of vimwiki's own HTML
    export.
  * New input format `creole` (Creole 1.0) (#3994, Sascha Wilde).
  * New syntax for Divs, with `fenced_divs` extension enabled by
    default (#168).  This gives an attractive, plain-text way to create
    containers for block-level content.
  * Added new syntax for including raw content in any output format,
    enabled by the `raw_attribute` extension (which is on by default
    for `markdown` and `multimarkdown`).  The syntax is the same as
    for fenced code blocks or code inlines, only with `{=FORMAT}` for
    attributes, where `FORMAT` is the name of the output format
    (e.g., `ms`, `html`).
  * Implement multicolumn support for slide formats (#1710).
    The structure expected is:
    :::::::::::::: {.columns}
    ::: {.column width="40%%"}
    contents...
    :::
    ::: {.column width="60%%"}
    contents...
    :::
    ::::::::::::::
    Support has been added for beamer and all HTML slide formats.
  * Allows line comments in templates, beginning with `$--` (#3806).
    (Requires doctemplates 0.2.1.)
  * Add `--eol=crlf|lf|native` flag and writer option to control line endings
    (Stefan Dresselhaus, #3663, #2097).
  * Add `--log` option to save log messages in JSON format to a file (#3392).
  * Add `--request-header` option, to set request headers when pandoc
    makes HTTP requests to fetch external resources. For example:
    `--request-header User-Agent:blah`.
  * Added lua filters (Albert Krewinkel, #3514).  The new `--lua-filter`
    option works like `--filter` but takes pathnames of special lua filters
    and uses the lua interpreter baked into pandoc, so that no external
    interpreter is needed.  Note that lua filters are all applied before
    regular filters, regardless of their position on the command line.
    For documentation of lua filters, see `doc/lua-filters.md`.
  * Set `PANDOC_READER_OPTIONS` in environment where filters are run.
    This contains a JSON representation of `ReaderOptions`, so filters
    can access it.
  * Support creation of pdf via groff `ms` and pdfroff.
    `pandoc -t ms -o output.pdf input.txt`.
  * Support for PDF generation via HTML and `weasyprint` or `prince`
    (Mauro Bieg, #3909).  `pandoc -t html5 -o output.pdf --pdf-engine=prince`.
  * Added `--epub-subdirectory` option (#3720).  This specifies the
    subdirectory in the OCF container that holds the EPUB specific content.
    We now put all EPUB related content in an `EPUB/` subdirectory by default
    (later this will be configurable).
    ```
    mimetype
    META-INF/
    com.apple.ibooks.display-options.xml
    container.xml
    EPUB/ <<--configurable-->>
    fonts/ <<--static-->>
    font.otf
    media/ <<--static-->>
    cover.jpg
    fig1.jpg
    styles/ <<--static-->>
    stylesheet.css
    content.opf
    toc.ncx
    text/ <<--static-->>
    ch001.xhtml
    ```
  * Added `--resource-path=SEARCHPATH` command line option (#852).
    SEARCHPATH is separated by the usual character, depending on OS
    (: on unix, ; on windows).  Default resource path is just working
    directory.  However, the working directory must be explicitly
    specified if the `--resource-path` option is used.
  * Added `--abbreviations=FILE` option for custom abbreviations file
    (#256).  Default abbreviations file (`data/abbreviations`) contains
    a list of strings that will be recognized by pandoc's
    Markdown parser as abbreviations.  (A nonbreaking space will
    be inserted after the period, preventing a sentence space in
    formats like LaTeX.) Users can override the default by putting a file
    abbreviations in their user data directory (`~/.pandoc` on *nix).
  * Allow a theme file as argument to `--highlight-style`.
    Also include a sample, `default.theme`, in `data/`.
  * Allow `--syntax-definition` option for dynamic loading of syntax
    highlighting definitions (#3334).
  * Lists in `markdown` by default now use the CommonMark variable
    nesting rules (#3511). The indentation required for a block-level
    item to be included in a list item is no longer fixed, but is
    determined by the first line of the list item.  To be included in
    the list item, a block must be indented to the level of the first
    non-space content after the list marker. Exception: if are 5 or more
    spaces after the list marker, then the content is interpreted as an
    indented code block, and continuation paragraphs must be indented
    two spaces beyond the end of the list marker.  See the CommonMark
    spec for more details and examples.
    Documents that adhere to the four-space rule should, in most cases,
    be parsed the same way by the new rules.  Here are some examples
    of texts that will be parsed differently:
  - a
  - b
    will be parsed as a list item with a sublist; under the four-space
    rule, it would be a list with two items.
  - a
    code
    Here we have an indented code block under the list item, even though it
    is only indented six spaces from the margin, because it is four spaces
    past the point where a continuation paragraph could begin.  With the
    four-space rule, this would be a regular paragraph rather than a code
    block.
  - a
    code
    Here the code block will start with two spaces, whereas under
    the four-space rule, it would start with `code`.  With the four-space
    rule, indented code under a list item always must be indented eight
    spaces from the margin, while the new rules require only that it
    be indented four spaces from the beginning of the first non-space
    text after the list marker (here, `a`).
    This change was motivated by a slew of bug reports from people
    who expected lists to work differently (#3125, #2367, #2575, #2210,
    [#1990], #1137, #744, #172, #137, #128) and by the growing prevalance
    of CommonMark (now used by GitHub, for example).  Those who
    prefer the old behavior can use `-f markdown+four_space_rule`.
  * Added `four_space_rule` extension.  This triggers the old pandoc
    parsing rule for content nested under list items (the "four space
    rule").
  * Added `spaced_reference_links` extension (#2602).  It allows whitespace
    between the two parts of a reference link:  e.g.
    [a] [b]
    [b]: url
    This was previously enabled by default; it is now forbidden by default.
  * Add `space_in_atx_header` extension (#3512).  This is enabled by default
    in pandoc and GitHub markdown but not the other flavors.
    This requires a space between the opening #'s and the header
    text in ATX headers (as CommonMark does but many other implementations
    do not).  This is desirable to avoid falsely capturing things like
    [#]hashtag
    or
    [#5]
  * Add `sourcefile` and `outputfile` template variables (Roland Hieber,
    [#3431]).
  * Allow ibooks-specific metadata in epubs (#2693).  You can now have
    the following fields in your YAML metadata, and it will be treated
    appropriately in the generated EPUB:
    ```
    ibooks:
    version: 1.3.4
    specified-fonts: false
    ipad-orientation-lock: portrait-only
    iphone-orientation-lock: landscape-only
    binding: true
    scroll-axis: vertical
    ```
  [behavior changes]
  * Reader functions no longer presuppose that CRs have been
    stripped from the input. (They strip CRs themselves, before
    parsing, to simplify the parsers.)
  * Added support for translations (localization) (#3559).
    Currently this only affects the LaTeX reader, for things
    like `\figurename`.  Translation data files for 46 languages
    can be found in `data/translations`.
  * Make `--ascii` work with DocBook output too.
  * Rename `--latex-engine` to `--pdf-engine`,
    and `--latex-engine-opt` to `--pdf-engine-opt`.
  * Removed `--parse-raw` and `readerParseRaw`.  These were confusing.
    Now we rely on the `+raw_tex` or `+raw_html` extension with latex or html
    input.  Thus, instead of `--parse-raw -f latex` we use `-f latex+raw_tex`,
    and instead of `--parse-raw -f html` we use `-f html+raw_html`.
  * With `--filter` R filters are now recognized, even if they are
    not executable (#3940, #3941, Andrie de Vries).
  * Support SVG in PDF output, converting with `rsvg2pdf` (#1793).
  * Make epub an alias for epub3, not epub2.
  * Removed `--epub-stylesheet`; use `--css` instead (#3472, #847).
    Multiple stylesheets may be used.  Stylesheets will be taken both from
    `--css` and from the `stylesheet` metadata field (which can contain
    either a file path or a list of them).
  * `--mathml` and MathML in HTMLMathMethod no longer take an argument.
    The argument was for a bridge JavaScript that used to be necessary
    in 2004.  We have removed the script already.
  * `--katex` improvements.  The latest version is used, and the
    autoload script is loaded by default.
  * Change MathJax CDN default since old one is shutting down (#3544).
    Note:  The new URL requires a version number, which we'll have
    to update manually in subsequent pandoc releases in order to
    take advantage of mathjax improvements.
  * `--self-contained`: don't incorporate elements with `data-external="1"`
    (#2656).  You can leave an external link as it is by adding the attribute
    data-external="1" to the element.  Pandoc will then not try to
    incorporate its content when `--self-contained` is used.  This is
    similar to a feature already supported by the EPUB writer.
  * Allow `--extract-media` to work with non-binary input formats
    (#1583, #2289).  If `--extract-media` is supplied with a non-binary
    input format, pandoc will attempt to extract the contents of all
    linked images, whether in local files, data: uris, or external uris.
    They will be named based on the sha1 hash of the contents.
  * Make `papersize: a4` work regardless of the case of `a4`.
    It is converted to `a4` in LaTeX and `A4` in ConTeXt.
  * Make `east_asian_line_breaks` affect all readers/writers (#3703).
  * Underlined elements are now treated consistently by readers
    (#2270, hftf); they are always put in a Span with class `underline`.
    This allows the user to treat them differently from other emphasis,
    using a filter.  Docx, Org, Textile, Txt2Tags, and HTML readers
    have been changed.
  * Improved behavior of `auto_identifiers` when there are explicit ids
    (#1745).  Previously only autogenerated ids were added to the list
    of header identifiers in state, so explicit ids weren't taken
    into account when generating unique identifiers.  Duplicated
    identifiers could result.  This simple fix ensures that explicitly given
    identifiers are also taken into account.
  * Use `table-of-contents` for contents of toc, make `toc` a boolean
    (#2872).  Changed markdown, rtf, and HTML-based templates accordingly.
    This allows you to set `toc: true` in the metadata; this
    previously produced strange results in some output formats.
    For backwards compatibility, `toc` is still set to the
    toc contents.  But it is recommended that you update templates
    to use `table-of-contents` for the toc contents and `toc`
    for a boolean flag.
  * Change behavior with binary format output to stdout.
    Previously, for binary formats, output to stdout was disabled
    unless we could detect that the output was being piped (and not
    sent to the terminal).  Unfortunately, such detection is not
    possible on Windows, leaving windows users no way to pipe binary
    output.  So we have changed the behavior in the following way:
    + Output to stdout is allowed when it can be determined that
    the output is being piped (on non-Windows platforms).
    + If the `-o` option is not used, binary output is never sent
    to stdout by default; instead, an error is raised.
    + If `-o -` is used, binary output is sent to stdout, regardless
    of whether it is being piped. This works on Windows too.
  * Better error behavior:  uses of `error` have been replaced by
    raising of `PandocError`, which can be trapped and handled by the
    calling program.
  * Removed `hard_line_breaks` extension from `markdown_github` (#3594).
    GitHub has two Markdown modes, one for long-form documents like READMEs
    and one for short things like issue coments. In issue comments, a line
    break is treated as a hard line break. In README, wikis, etc., it is
    treated as a space as in regular Markdown.  Since pandoc is more likely to
    be used to convert long-form documents from GitHub Markdown,
    `-hard_line_breaks` is a better default.
  * Include `backtick_code_blocks` extension in `mardkown_mmd` (#3637).
  * Escape `MetaString` values (as added with `-M/--metadata` flag) (#3792).
    Previously they would be transmitted to the template without any
    escaping.  Note that `--M title='*foo*'` yields a different result from
  - --
    title: *foo*
  - --
    In the latter case, we have emphasis; in the former case, just
    a string with literal asterisks (which will be escaped
    in formats, like Markdown, that require it).
  * Allow `em`, `cm`, `in` for image height/width in HTML, LaTeX (#3450).
  * HTML writer: Insert `data-` in front of unsupported attributes.  Thus,
    a span with attribute `foo` gets written to HTML5 with `data-foo`, so
    it is valid HTML5.  HTML4 is not affected.  This will allow us to use
    custom attributes in pandoc without producing invalid HTML. (With help
    from Wandmalfarbe, #3817.)
  * Plain writer:  improved super/subscript rendering.  We now
    handle more non-digit characters for which there are
    sub/superscripted unicode characters.  When unicode
    sub/superscripted characters are not available, we use
    `_(..)` or `^(..)` (#3518).
  * Docbook, JATS, TEI writers: print INFO message when omitting interior
    header (#3750).  This only applies to section headers inside list items,
    e.g., which were otherwise silently omitted.
  * Change to `--reference-links` in Markdown writer (#3701).  With
    `--reference-location` of `section` or `block`, pandoc will now repeat
    references that have been used in earlier sections.  The Markdown
    reader has also been modified, so that *exactly* repeated references
    do not generate a warning, only references with the same label but
    different targets.  The idea is that, with references after every block,
    one might want to repeat references sometimes.
  * ODT/OpenDocument writer:
    + Support `lang` attribute (#1667).
    + Added support for `--toc` (#2836).  Thanks to @anayrat.
  * Docx writer:
    + `lang` meta, see #1667 (Mauro Bieg, #3515).
    + Change `FigureWithCaption` to `CaptionedFigure` (iandol, #3658).
    + Use `Table` rather than `Table Normal` for table style (#3275).
    `Table Normal` is the default table style and can't be modified.
    + Pass through comments (#2994).  We assume that comments are defined as
    parsed by the docx reader:
    I want <span class="comment-start" id="0" author="Jesse Rosenthal"
    date="2016-05-09T16:13:00Z">I left a comment.</span>some text to
    have a comment <span class="comment-end" id="0"></span>on it.
    We assume also that the id attributes are unique and properly
    matched between comment-start and comment-end.
    + Bookmark improvements.  Bookmark start/end now surrounds content rather
    than preceding it.  Bookmarks generated for Div with id
    (jgm/pandoc-citeproc#205).
    + Add `keywords` metadata to docx document properties (Ian).
  * RST writer: support unknown interpreted text roles by
    parsing them as `Span` with `role` attributes (#3407).  This
    way they can be manipulated in the AST.
  * HTML writer:
    + Line block: Use class instead of style attribute (#1623).  We now
    issue `<div class="line-block">` and include a default definition
    for `line-block` in the default templates, instead of hard-coding a
    `style` on the div.
    + Add class `footnoteBack` to footnote back references (Timm Albers).
    This allows for easier CSS styling.
    + Render SmallCaps as span with smallcaps class (#1592), rather than
    using a style attribute directly.  This gives the user more flexibility
    in styling small caps in CSS.
    + With reveal.js we use `data-src` instead of `src` for images for
    lazy loading.
    + Special-case `.stretch` class for images in reveal.js (#1291).
    Now in reveal.js, an image with class `stretch` in a paragraph
    by itself will stretch to fill the whole screen, with no
    caption or figure environment.
  * Added warnings for non-rendered blocks to writers.
  * Writers now raise an error on template failure.
  * When creating a PDF via LaTeX, warn if the font is missing some
    characters (#3742).
  * Remove initial check for PDF-creating program (#3819).
    Instead, just try running it and raise the exception if it
    isn't found at that point.  This improves things for users of Cygwin
    on Windows, where the executable won't be found by `findExecutable`
    unless `.exe` is added.  The same exception is raised as before, but
    at a later point.
  * Readers issue warning for duplicate header identifiers (#1745).
    Autogenerated header identifiers are given suffixes so as not to clash
    with previously used header identifiers. But they may still coincide with
    an explicit identifier that is given for a header later in the document,
    or with an identifier on a div, span, link, or image. We now issue
    a warning in this case, so users can supply an explicit identifier.
  * CommonMark reader now supports `emoji`, `hard_line_breaks`, `smart`,
    and `raw_html` extensions.
  * Markdown reader:
    + Don't allow backslash + newline to affect block structure (#3730).
    Note that as a result of this change, the following, which formerly
    produced a header with two lines separated by a line break, will
    now produce a header followed by a paragraph:
    [#] Hi\
    there
    This may affect some existing documents that relied on
    this undocumented and unintended behavior.  This change makes pandoc
    more consistent with other Markdown implementations, and with itself
    (since the two-space version of a line break doesn't work inside ATX
    headers, and neither version works inside Setext headers).
  * Org reader (Albert Krewinkel, unless noted):
    + Support `table.el` tables (#3314).
    + Support macros (#3401).
    + Support the `#+INCLUDE:` file inclusion mechanism (#3510).
    Recognized include types are `example`, `export`, `src`, and
    normal org file inclusion.  Advanced features like line numbers
    and level selection are not implemented yet.
    + Interpret more meta value as inlines.  The values of the following
    meta variables are now interpreted using org-markup instead of
    treating them as pure strings: `keywords` (comma-separated list of
    inlines), `subtitle` (inline values), `nocite` (inline values, can
    be repeated).
    + Support `\n` export option (#3940).  This turns all newlines in the
    text into hard linebreaks.
  * RST reader:
    + Improved admonition support (#223).  We no longer add an
    `admonition` class, we just use the class for the type of admonition,
    `note` for example.  We put the word corresponding to the label in
    a paragraph inside a `Div` at the beginning of the admonition with
    class `admonition-title`.  This is about as close as we can get to
    RST's own output.
    + Initial support of `.. table` directive.  This allows adding captions
    to tables.
    + Support `.. line-block` directive.  This is deprecated but may still
    be in older documents.
    + Support scale and align attributes of images (#2662).
    + Implemented implicit internal header links (#3475).
    + Support RST-style citations (#853).  The citations appear at the end
    of the document as a definition list in a special div with id
    `citations`. Citations link to the definitions.
    + Recurse into bodies of unknown directives (#3432).
    In most cases it's better to preserve the content than
    to emit it.  This isn't guaranteed to have good results;
    it will fail spectacularly for unknown raw or verbatim directives.
    + Handle chained link definitions (#262).  For example,
    .. _hello:
    .. _goodbye: example.com
    Here both `hello` and `goodbye` should link to `example.com`.
    + Support anchors (#262).  E.g.
    `hello`
    .. _hello:
    paragraph
    This is supported by putting "paragraph" in a `Div` with id `hello`.
    + Support `:widths:` attribute for table directive.
    + Implement csv-table directive (#3533).  Most attributes are supported,
    including `:file:` and `:url:`.
    + Support unknown interpreted text roles by parsing them as Span
    with "role" attributes (#3407).  This way they can be manipulated in
    the AST.
  * HTML reader: parse a span with class `smallcaps` as `SmallCaps`.
  * LaTeX reader:
    + Implemented `\graphicspath` (#736).
    + Properly handle column prefixes/suffixes.  For example, in
    `\begin{tabular}{>{$}l<{$}>{$}l<{$} >{$}l<{$}}`
    each cell will be interpreted as if it has a `$`
    before its content and a `$` after (math mode).
    + Handle komascript `\dedication` (#1845).  It now adds a
    `dedication` field to metadata.  It is up to the user to supply
    a template that uses this variable.
    + Support all `\textXX` commands, where XX = `rm`, `tt`, `up`, `md`,
    `sf`, `bf` (#3488).  Spans with a class are used when there is
    nothing better.
    + Expand `\newenvironment` macros (#987).
    + Add support for LaTeX subfiles package (Marc Schreiber, #3530).
    + Better support for subfigure package (#3577).
    A figure with two subfigures turns into two pandoc
    figures; the subcaptions are used and the main caption
    ignored, unless there are no subcaptions.
    + Add support for \vdots (Marc Schreiber, #3607).
    + Add basic support for hyphenat package (Marc Schreiber, #3603).
    + Add basic `\textcolor` support (Marc Schreiber).
    + Add support for `tabularx` environment (Marc Schreiber, #3632).
    + Better handling of comments inside math environments (#3113).
    This solves a problem with commented out `\end{eqnarray}` inside
    an eqnarray (among other things).
    + Parse tikzpicture as raw verbatim environment if `raw_tex` extension
    is selected (#3692).  Otherwise skip with a warning.  This is better
    than trying to parse it as text!
    + Add `\colorbox` support (Marc Schreiber).
    + Set identifiers on Spans used for `\label`.
    + Have `\setmainlanguage` set `lang` in metadata.
    + Support etoolbox's `\ifstrequal`.
    + Support `plainbreak`, `fancybreak` et al from the memoir class
    (bucklereed, #3833).
    + Support `\let`.  Also, fix regular macros so they're expanded at the
    point of use, and NOT also the point of definition.  `\let` macros,
    by contrast, are expanded at the point of definition.  Added an
    `ExpansionPoint` field to `Macro` to track this difference.
    + Support simple `\def` macros.  Note that we still don't support
    macros with fancy parameter delimiters, like `\def\foo#1..#2{...}`.
    + Support \chaptername, \partname, \abstractname, etc.  (#3559,
    obsoletes #3560).
    + Put content of `\ref`, `\label`, `\eqref` commands into `Span` with
    attributes, so they can be handled in filters (Marc Schreiber, #3639)
    + Add Support for `glossaries` and `acronym` package (Marc Schreiber,
    [#3589]). Acronyms are not resolved by the reader, but acronym and
    glossary information is put into attributes on Spans so that they
    can be processed in filters.
    + Use `Link` instead of `Span` for `\ref`.  This makes more sense
    semantically and avoids unnecessary `Span [Link]` nestings when
    references are resolved.
    + Rudimentary support for `\hyperlink`.
    + Support `\textquoteleft|right`, `\textquotedblleft|right` (#3849).
    + Support `\lq`, `\rq`.
    + Implement `\newtoggle`, `\iftoggle`, `\toggletrue|false` from etoolbox
    (#3853).
    + Support `\RN` and `\Rn`, from biblatex (bucklereed, #3854).
    + Improved support for `\hyperlink`, `\hypertarget` (#2549).
    + Support `\k` ogonek accent.
    + Improve handling of accents.  Handle ogonek, and fall back correctly
    with forms like `\"{}`.
    + Better support for ogonek accents.
    + Support for `\faCheck` and `\faClose` (Marc Schreiber, #3727).
    + Support for `xspace` (Marc Schreiber, #3797).
    + Support `\setmainlanguage` or `\setdefaultlanguage` (polyglossia)
    and `\figurename`.
    + Better handling of `\part` in LaTeX (#1905).  Now we parse chapters as
    level 0 headers, and parts as level -1 headers.  After parsing, we
    check for the lowest header level, and if it's less than 1 we bump
    everything up so that 1 is the lowest header level.  So `\part` will
    always produce a header; no command-line options are needed.
    + Add block version of `\textcolor` (Marc Schreiber).
    + `\textcolor` works as inline and block command (Marc Schreiber).
    + `\textcolor` will be parse as span at the beginning of a paragraph
    (Marc Schreiber).
    + Read polyglossia/babel `\text(LANG){...}` (bucklereed)
    + Improved handling of include files in LaTeX reader (#3971).
    Previously `\include` wouldn't work if the included file
    contained, e.g., a begin without a matching end.
    + Support `\expandafter` (#3983).
    + Handle `\DeclareRobustCommand` (#3983).  Currently it's just treated
    as a synonym for `\newcommand`.
    + Handle `\lettrine` (Mauro Bieg).
  * Math improvements due to updates in texmath:
    + Improved handling of accents and upper/lower delimiters.
    + Support for output in GNU eqn format (used with *roff).
    + Allow `\boldsymbol` + a token without braces, and similarly
    with other styling commands.
    + Improve parsing of `\mathop` to allow multi-character operator names.
    + Add thin space after math operators when "faking it with
    unicode."
  * `walk` is now used instead of `bottomUp` in the `ToJSONFilter`
    instance for `a -> [a]` (pandoc-types).  Note that behavior
    will be slightly different, since `bottomUp`'s treatment of
    a function `[a] -> [a]` is to apply it to each sublist of a
    list, while walk applies it only to maximal sublists.
    Usually the latter behavior is what is wanted, and the
    former can be simulated when needed.  But there may be
    existing filters that need to be rewritten in light of the
    new behavior.  Performance should be improved.
  * There are some changes to syntax highlighting due to revisions
    in the `skylighting` library:
    + Support for `powershell` has been added, and many syntax
    definitions have been updated.
    + Background colors have been added to the `kate` style.
    + The way highlighted code blocks are formatted in HTML has
    been changed (David Baynard), in ways that may require
    changes in hard-coded CSS affecting highlighting.
    (If you haven't included hard-coded highlighting CSS in
    your template, you needn't change anything.)
  [API changes]
  * New module `Text.Pandoc.Class` (Jesse Rosenthal, John MacFarlane).
    This contains definitions of the `PandocMonad` typeclass, the
    `PandocIO` and `PandocPure` monads, and associated functions.
  * Changed types of all writers and readers.
    + We now use `Text` instead of `String` in the interface (#3731).
    (We have not yet changed the internals of most readers to work
    with `Text`, but making this change in the API now opens up a
    path to doing that.)
    + The result is now of form `m a` with constraint `PandocMonad m`.
    Readers and writers can be combined to form monadic values which
    can be run using either `runIO` or `runPure`.  If `runIO` is used,
    then both readers and writers will be able to do IO when needed
    (for include files, for example); if `runPure` is used,
    then the functions are pure and will not touch IO.
    + Where previously you used
    `writeRST def (readMarkdown def "[foo](url)")`, now you
    would use
    `runPure $ readMarkdown def (pack "[foo](url)") >>= writeRST def`.
  * New module `Text.Pandoc.Readers` (Albert Krewinkel).  This
    contains reader helper functions formerly defined in the
    top-level `Text.Pandoc` module.
    + Changed `StringReader` -> `TextReader`.
    + `getReader` now returns a pair of a reader and
    `Extensions`, instead of building the extensions into the
    reader (#3659).  The calling code must explicitly set
    `readerExtensions` using the `Extensions` returned.  The
    point of the change is to make it possible for the calling
    code to determine what extensions are being used.
  * New module `Text.Pandoc.Writers` (Albert Krewinkel).
    This contains writer helper functions formerly defined in the
    top-level `Text.Pandoc` module.
    + Changed `StringWriter` -> `TextWriter`.
    + `getWriter` now retuns a pair of a reader and
    `Extensions`, instead of building the extensions into the
    reader (#3659).  The calling code must explicitly set
    `readerExtensions` using the `Extensions` returned.  The
    point of the change is to make it possible for the calling
    code to determine what extensions are being used.
  * New module `Text.Pandoc.Lua`, exporting `runLuaFilter` (Albert Krewinkel,
    [#3514]).
  * New module `Text.Pandoc.App`.  This abstracts out the functionality
    of the command line program (`convertWithOpts`), so it can be reproduced
    e.g. in a desktop or web application.  Instead of exiting, we throw errors
    (#3548), which are caught (leading to exit) in pandoc.hs, but allow other
    users of `Text.Pandoc.App` to recover.  `pandoc.hs` is now a 2-liner.
    The module also exports some utility functions for parsing options
    and running filters.
  * New module `Text.Pandoc.Logging` (exported module) (#3392).
    This now contains the `Verbosity` definition previously in
    `Text.Pandoc.Options`, as well as a new `LogMessage` datatype that will
    eventually be used instead of raw strings for warnings.  This will enable
    us, among other things, to provide machine-readable warnings if desired.
    Include ToJSON instance and showLogMessage.  This gives us the possibility
    of both machine-readable and human-readable output for log messages.
  * New module `Text.Pandoc.BCP47`, with `getLang`, `Lang(..)`, `parseBCP47`.
  * New module `Text.Pandoc.Translations`, exporting `Term`,
    `Translations`, `readTranslations`.
  * New module `Text.Pandoc.Readers.LaTeX.Types', exporting `Macro`, `Tok`,
    `TokType`, `Line`, `Column`.
  * `Text.Pandoc.Error`: added many new constructors for `PandocError`.
  * Expose some previously private modules (#3260).  These are often
    helpful to people writing their own reader or writer modules:
    + `Text.Pandoc.Writers.Shared`
    + `Text.Pandoc.Parsing`
    + `Text.Pandoc.Asciify`
    + `Text.Pandoc.Emoji`
    + `Text.Pandoc.ImageSize`
    + `Text.Pandoc.Highlighting`
  `
  * New module `Text.Pandoc.Extensions` (Albert Krewinkel):
    Extension parsing and processing functions were defined in the top-level
    `Text.Pandoc` module.  These functions are moved to the Extensions
    submodule as to enable reuse in other submodules.
  * Add `Ext_raw_attribute` constructor for `Extension`.
  * Add `Ext_fenced_divs` constructor for `Extension'.
  * Add `Ext_four_space_rule` constructor in `Extension`.
  * Add `Ext_gfm_auto_identifiers` constructor for `Extension`.
  * Add `Monoid` instance for `Extensions`.
  * Add `Text.Pandoc.Writers.Ms`, exporting `writeMs`.
  * Add `Text.Pandoc.Writers.JATS`, exporting `writeJATS`.
  * Add `Text.Pandoc.Writers.Muse`, exporting `writeMuse`.
  * Add `Text.Pandoc.Readers.Muse`, exporting `readMuse`.
  * Add `Text.Pandoc.Readers.TikiWiki`, exporting `readTikiWiki`.
  * Add `Text.Pandoc.Readers.Vimwiki`, exporting `readVimwiki`.
  * Add `Text.Pandoc.Readers.Creole`, exporting `readCreole`.
  * Export `setVerbosity` from `Text.Pandoc`.
  * `Text.Pandoc.Pretty`: Add `Eq` instance for `Doc`.
  * `Text.Pandoc.XML`: `toEntities`: changed type to `Text -> Text`.
  * `Text.Pandoc.UTF8`:
    + Export `fromText`, `fromTextLazy`, `toText`, `toTextLazy`.
    Define `toString`, `toStringLazy` in terms of them.
    + Add new functions parameterized on `Newline`: `writeFileWith`,
    `putStrWith`, `putStrLnWith`, `hPutStrWith`, `hPutStrLnWith`.
  * `Text.Pandoc.MediaBag`: removed `extractMediaBag`.
  * `Text.Pandoc.Highlighting`:
    + `highlighting` now returns an Either rather than Maybe.
    This allows us to display error information returned by the skylighting
    library.  Display a warning if the highlighting library throws an error.
    + Add parameter for `SyntaxMap` to `highlight`.
  * `Text.Pandoc.Writers.Math`:
    + Export `defaultMathJaxURL`, `defaultKaTeXURL`.  This will ensure that
    we only need to update these in one place.
  * `Text.Pandoc.SelfContained`:
    + Removed `WriterOptions` parameter from `makeSelfContained`.
    + Put `makeSelfContained` in PandocMonad instead of IO.  This removes
    the need to pass MediaBag around and improves exceptions.  It also
    opens up the possibility of using makeSelfContained purely.
    + Export `makeDataURI`.
  * `Text.Pandoc.ImageSize`:
    + Export `lengthToDim`, new function `scaleDimension`.
    + Export `inEm` from ImageSize (#3450).
    + Change `showFl` and `show` instance for `Dimension` so
    extra decimal places are omitted.
    + Added `Em` as a constructor of `Dimension`.
    + Add `WriterOptions` parameter to `imageSize` signature (Mauro Bieg).
  * `Text.Pandoc.Templates`:
    + Change type of `renderTemplate'`.  Now it runs in `PandocMonad`
    and raises a proper `PandocTemplateError` if there are problems, rather
    than failing with uncatchable `error`.
    + Change signature of `getDefaultTemplate`.  Now it runs in any instance
    of `PandocMonad`, and returns a `String` rather than an `Either` value.
    And it no longer takes a `datadir` parameter, since this can be
    retrieved from `CommonState`.
  * `Text.Pandoc.Options`:
    + Added `writerEpubSubdirectory` to `WriterOptions` (#3720).
    The EPUB writer now takes its EPUB subdirectory from this option.
    + In `WriterOptions`, rename `writerLaTeXEngine` to `writerPdfEngine`
    and `writerLaTeXArgs` to `writerPdfArgs` (Mauro Bieg, #3909).
    + Add `writerSyntaxMap` to `WriterOptions`.
    + Removed `writerEpubStylesheet` from `WriterOptions`.
    + Remove `writerUserDataDir` from `WriterOptions`.  It is now carried
    in `CommonState` in `PandocMonad` instances.  (And thus it can be used
    by readers too.)
    + Changed `writerEpubMetadata` to a `Maybe String`.
    + Removed `readerApplyMacros` from `ReaderOptions`.  Now we just check
    the `latex_macros` reader extension.
    + FromJSON/ToJSON instances for `ReaderOptions`.
    + In `HTMLMathMethod`, the `KaTeX` contsructor now takes only
    one string (for the KaTeX base URL), rather than two.
    + Removed `writerSourceURL` from `WriterOptions`.  We now use
    `stSourceURL` in `CommonState`, which is set by `setInputFiles`.
  * `Text.Pandoc.Shared`:
    + `tabFilter` now takes a `Text`, not `String`.
    + `openURL`: Changed type from an Either.  Now it will just raise
    an exception to be trapped later.
    + Remove `normalizeSpaces` (#1530).
    + Remove `warn`.  (Use `report` from `Text.Pandoc.Class` instead.)
    + Export a new function `crFilter`.
    + Add `eastAsianLineBreakFilter` (previously in Markdown reader).
    + Provide custom `isURI` that rejects unknown schemes.
    (Albert Krewinkel, #2713).  We also export the set of known
    `schemes`.  The new function replaces the function of the same name
    from `Network.URI`, as the latter did not check whether a scheme is
    well-known.  All official IANA schemes (as of 2017-05-22) are
    included in the set of known schemes.  The four non-official schemes
    `doi`, `isbn`, `javascript`, and `pmid` are kept.
    + Remove `err`.
    + Remove `readDataFile`, `readDefaultDataFile`, `getReferenceDocx`,
    `getReferenceODT`. These now live in `Text.Pandoc.Class`,
    where they are defined in terms of `PandocMonad`
    primitives and have different signatures.
    + Remove `openURL`.  Use `openURL` from `Text.Pandoc.Class` instead.
    + Add `underlineSpan`.
  * `Text.Pandoc.Readers.HTML`: export new `NamedTag` class.
  * `Text.Pandoc.Readers.Markdown`: remove `readDocxWithWarnings`.
    With the new API one can simply use `getLog` after running
    the reader.
  * `Text.Pandoc.Readers.LaTeX`: Changed types for `rawLaTeXInline`
    and `rawLaTeXBlock`.  (Both now return a `String`, and they are
    polymorphic in state.)
  [bug fixes and under-the-hood improvements]
  * TEI writer: Added identifiers on `<div>` elements.
  * DokuWiki reader: Better handling for code block in list item (#3824).
  * Custom writer: Remove old preprocesesor conditionals (Albert Krewinkel).
  * ZimWiki writer: Removed internal formatting from note and table cells,
    because ZimWiki does not support it (Alex Ivkin, #3446).
  * MediaWiki writer:
    + Updated list of syntax highlighting languages (#3461).
    Now `r` gets you `<source>` rather than `<code>` (among others).
    + Add display attribute on `<math>` tags (#3452).  This allows display
    math to be rendered properly.
    + Remove newline before `</ref>` (#2652).
    + Don't softbreak lines inside list items (#3531).
  * Org writer:
    + Reduce to two spaces after bullets (#3417, Albert Krewinkel).
    + Add unit tests (Alexander Krotov).
    + Stop using raw HTML to wrap divs (Albert Krewinkel, #3771).
    + Do not strip `#` from Org anchor links (Alexander Krotov).
  * CommonMark writer:
    + Avoid excess blank lines at end of output.
    + Prefer pipe tables to HTML tables even if it means losing relative
    column width information (#3734).
    + Support table, strikethrough extensions, when enabled (as with gfm).
    Note that we bypass the commonmark writer from cmark and construct our
    own pipe tables, with better results.
    + Properly support `--wrap=none`.
    + Use smallcaps class for `SmallCaps` (#1592).
    + Omit "fig:" prefix in image titles.  This is used internally to
    indicate internal figures.
  * RST writer:
    + Properly handle table captions.
    + Don't wrap lines in in definition list terms.  Wrapping is not allowed.
    + Implemented `+/-smart` and improved escaping with `+smart`.
    + Add empty comments when needed to avoid including a blockquote
    in the indented content of a preceding block (#3675).
    + Improve grid table output, fix bug with empty rows (#3516).
    Uses the new `gridTable` in Writers.Shared, which is here
    improved to better handle 0-width cells.
    + Remove space at beginning/end of RST code span (#3496).  Otherwise
    we get invalid RST.  There seems to be no way to escape the space.
    + Add header anchors when header has non-standard id (#3937).
    + Correctly handle inline code containing backticks, using a `:literal:`
    role (#3974).
    + Don't backslash-escape word-internal punctuation (#3978).
  * Markdown writer:
    + Don't include variables in metadata blocks.  Previously variables set
    on the command line were included in e.g. YAML metadata, contrary to
    documentation and intentions.
    + Improved escaping with `+smart`.
    + Fixed grid tables embedded in grid tables (#2834).
    + Use span with class 'smallcaps' for SmallCaps, instead of a style
    attribute as before (#1592).
    + Escape initial `%%` in a paragraph if the `pandoc_title_blocks`
    extension is enabled (#3454).  Otherwise in a document starting with
    a literal `%%` the first line is wrongly interpreted as a title.
    + Fixed false ordered lists in YAML metadata (#3492, #1685).  Now we
    properly escape things that would otherwise start ordered lists,
    such as
  - --
    title: 1. inline
    ...
    + Better handling of tables with empty columns (#3337).  We now
    calculate the number of columns based on the longest row (or the
    length of aligns or widths).
    + Escape unordered list markers at beginning of paragraph (#3497), to
    avoid false interpretation as a list.
    + Escape `|` appropriately.
    + Ensure space before list at top level (#3487).
    + Avoid spurious blanklines at end of document after tables and list,
    for example.
    + Fixed bugs in simple/multiline list output (#3384).
    Previously we got overlong lists with `--wrap=none`.  This is fixed.
    Previously a multiline list could become a simple list (and would
    always become one with `--wrap=none`).
    + Don't emit a simple table if `simple_tables` disabled (#3529).
    + Case-insensitive reference links (David A Roberts, #3616).
    Ensure that we do not generate reference links whose labels differ only
    by case.  Also allow implicit reference links when the link
    text and label are identical up to case.
    + Put space before reference link definitions (Mauro Bieg, #3630).
    + Better escaping for links (David A. Roberts, #3619).  Previously the
    Markdown writer would sometimes create links where there were none
    in the source.  This is now avoided by selectively escaping bracket
    characters when they occur in a place where a link might be created.
    + Added missing `\n` (David A. Roberts, #3647).
    + Fixed duplicated reference links with `--reference-links`
    and `--reference-location=section` (#3674).  Also ensure that there
    are no empty link references `[]`.
    + Avoid inline surround-marking with empty content (#3715).
    E.g. we don't want `<strong></strong>` to become `****`.
    Similarly for emphasis, super/subscript, strikeout.
    + Don't allow soft break in header (#3736).
    + Make sure `plain`, `markdown_github`, etc. work for raw.
    Previously only `markdown` worked.  Note: currently a raw block labeled
    `markdown_github` will be printed for any `markdown` format.
    + Ensure that `+` and `-` are escaped properly so they don't cause
    spurious lists (#3773).  Previously they were only
    if succeeded by a space, not if they were at end of line.
    + Use pipe tables if `raw_html` disabled and `pipe_tables` enabled,
    even if the table has relative width information (#3734).
    + Markdown writer: don't crash on `Str ""`.
    + Make `Span` with null attribute transparent.  That is, we don't use
    brackets or `<span>` tags to mark spans when there are no attributes;
    we simply output the contents.
    + Escape pipe characters when `pipe_tables` enabled (#3887).
    + Better escaping of `<` and `>`.  If `all_symbols_escapable` is set,
    we backslash escape these.  Otherwise we use entities as before.
    + When writing plain, don't use `&nbsp;` to separate list and indented
    code.  There's no need for it in this context, since this isn't to be
    interpreted using Markdown rules.
    + Preserve classes in JS obfuscated links (Timm Albers, #2989).
    HTML links containing classes originally now preserve them when using
    JavaScript email obfuscation.
    + Render `SmallCaps` as a native span when `native_spans` are enabled.
    + Always write attributes with `bracketed_spans` (d-dorazio).
  * Man writer:
    + Fix handling of nested font commands (#3568).  Previously pandoc emitted
    incorrect markup for bold + italic, for example, or bold + code.
    + Avoid error for definition lists with no definitions (#3832).
  * DocBook writer:
    + Fix internal links with `writerIdentifierPrefix opt`
    (#3397, Mauro Bieg).
  * Docx writer:
    + Don't include bookmarks on headers unless non-null id (#3476).
    + Support 9 levels of headers (#1642).
    + Allow 9 list levels (#3519).
    + Don't take `distArchive` from datadir (#3322).  The docx writer takes
    components from the distribution's version of `reference.docx` when it
    can't find them in a user's custom `reference.docx`.  Previously, we
    allowed a `reference.docx` in the data directory (e.g. `~/.pandoc`)
    to be used as the distribution's reference.docx.  This led to a
    bizarre situation where pandoc would produce a good docx using
    `--template ~/.pandoc/ref.docx`, but if `ref.docx` were moved to
    `~/.pandoc/reference.docx`, it would then produce a corrupted docx.
    + Fixed handling of soft hyphen (0173) (#3691).
    + Better handling of keywords (#3719).
    + Cleaner code for handling dir and style attributes for `Div`.
    + Use `Set` for dynamic styles to avoid duplicates.
    + Removed redundant element from data/docx/word/numbering.xml.
    The elements we need are generated when the document is
    compiled; this didn't do anything.
    + Activate `evenAndOddHeaders` from reference docx (#3901,
    Augustín Martín Barbero).
  * ODT/OpenDocument writer:
    + Calculate aspect ratio for percentage-sized images (Mauro Bieg, #3239).
    + Use more widely available bullet characters (#1400).  The old
    characters weren't available in some font sets.  These seem to work
    well on Windows and Linux versions of LibreOffice.
    + Wider labels for lists (#2421).  This avoids overly narrow labels for
    ordered lists with `()` delimiters.  However, arguably it creates
    overly wide labels for bullets.  Also, lists now start flush with
    the margin, rather than indented.
    + Fixed dropped elements in some ordered lists (#2434).
  * FB2 writer:
    + Don't render `RawBlock` as code.
    + Don't fail with an error on interior headers (e.g. in list) (#3750).
    Instead, omit them with an INFO message.
    + Add support for "lang" metadata (Alexander Krotov, #3625).
    + Format `LineBlock` as poem (Alexander Krotov).  Previously writer
    produced one paragraph with `<empty-line/>` elements, which are not
    allowed inside `<p>` according to FB2 schema.
    + Replace `concatMap` with `cMap` (Alexander Krotov).
    + Write FB2 lists without nesting blocks inside `<p>` (Alexander
    Krotov, #4004)
  * HTML writer:
    + Make sure `html4`, `html5` formats work for raw blocks/inlines.
    + Render raw inline environments when `--mathjax` used (#3816).
    We previously did this only with raw blocks, on the assumption
    that math environments would always be raw blocks. This has changed
    since we now parse them as inline environments.
    + Ensure we don't get two style attributes for width and height.
    + Report when not rendering raw inline/block.
    + Issue warning if no title specified and template used (#3473).
    + Info message if `lang` is unspecified (#3486).
    + Removed unused parameter in `dimensionsToAttributeList`.
    + Avoid two class attributes when adding `uri` class (#3716).
    + Fix internal links with `writerIdentifierPrefix opt` (#3397, Mauro
    Bieg).
    + Use revealjs's math plugin for mathjax (#3743).  This is a thin
    wrapper around mathjax that makes math look better on revealjs.
    + Slidy:  use h1 for all slides, even if they were originally
    level 2 headers (#3566).  Otherwise the built-in table of contents
    in Slidy breaks.
  * LaTeX writer:
    + Don't render LaTeX images with data: URIs (#3636).  Note that
    `--extract-media` can be used when the input contains data: URIs.
    + Make highlighted code blocks work in footnotes (Timm Albers).
    + Don't use figure inside table cell (#3836).
    + Use proper code for list enumerators (#3891).  This should fix problems
    with lists that don't use arabic numerals.
    + Always add hypertarget when there's a non-empty identifier (#2719).
    Previously the hypertargets were only added when there was actually
    a link to that identifier.
    + Use `%%` after hypertarget before code block.
    + Add `\leavevmode` before hypertarget at start of paragraph (#2704,
    fixes formatting problems in beamer citations).
    + Don't use `lstinline` in \item[..] (#645).  If you do, the contents
    of item disappear or are misplaced.  Use `\texttt` instead.
    + Fix problem with escaping in `lstinline` (#1629).  Previously the
    LaTeX writer created invalid LaTeX when `--listings` was specified and
    a code span occured inside emphasis or another construction.
    + Fix error with line breaks after empty content (#2874).  LaTeX
    requires something before a line break, so we insert a `~` if no
    printable content has yet been emitted.
    + Use BCP47 parser.
    + Fixed detection of otherlangs (#3770).  We weren't recursing into
    inline contexts.
    + Handle language in inline code with `--listings` (#3422).
    + Write euro symbol directly in LaTeX (Andrew Dunning, #3801).
    The textcomp package allows pdfLaTeX to parse `€` directly, making the
    `\euro` command unneeded.
    + Fixed footnotes in table captions (#2378).  Note that if the table has
    a first page header and a continuation page header, the notes will
    appear only on the first occurrence of the header.
    + In `writeBeamer` output, allow hyperlinks to frames (#3220).
    Previously you could link to a header above or below slide level but
    not *to* slide level.  This commit changes that.  Hypertargets are
    inserted inside frame titles; technically the reference is to just
    after the title, but in normal use (where slides are viewed full
    screen in a slide show), this does not matter.
    + Remove `\strut` at beginning of table cells (#3436).  This fixes a
    problem with alignment of lists in table cells.  The `\strut` at the
    end seems to be enough to avoid the too-close spacing that motivated
    addition of the strut  in #1573.
    + Add partial siunitx Support (Marc Schreiber, #3588).
  * ConTeXt writer:
    + Refactored to use BCP47 module.
    + Remove unnecessary `$` (Alexander Krotov, #3482).
    + Use header identifiers for chapters (#3968).
  * EPUB writer:
    + `title_page.xhtml` is now put in `text/`.
    + Don't strip formatting in TOC (#1611).
  * Textile reader:
    + Fix bug for certain links in table cells (#3667).
    + Allow 'pre' code in list item (#3916).
  * HTML reader:
    + Added warnings for ignored material (#3392).
    + Better sanity checks to avoid parsing unintended things as
    raw HTML in the Markdown reader (#3257).
    + Revise treatment of `li` with `id` attribute (#3596).  Previously we
    always added an empty div before the list item, but this created
    problems with spacing in tight lists.  Now we do this: If the list
    item contents begin with a `Plain` block, we modify the `Plain`
    block by adding a `Span` around its contents.  Otherwise, we add a
    `Div` around the contents of the list item (instead of adding an
    empty `Div` to the beginning, as before).
    + Add `details` tag to list of block tags (#3694).
    + Removed `button` from block tag list (#3717).  It is already in the
    `eitherBlockOrInlineTag` list, and should be both places.
    + Use `Set`s instead of lists for block tag lookup.
    + Rewrote to use `Text` throughout.  Effect on memory usage is modest
    (< 10%%).
    + Use the lang value of `<html>` to set the lang meta value (bucklereed,
    [#3765]).
    + Ensure that paragraphs are closed properly when the parent block
    element closes, even without `</p>` (#3794).
    + Parse `<figure>` and `<figcaption>` (Mauro Bieg, #3813).
    + Parse `<main>` like `<div role=main>` (bucklereed, #3791).
    `<main>` closes `<p>` and behaves like a block element generally
    + Support column alignments (#1881).  These can be set either
    with a `width` attribute or with `text-width` in a `style` attribute.
    + Modified state type to be an instance of `HasLogMessages`, so
    `registerHeader` can issue warnings.
    + `</td>` or `</th>` should close any open block tag (#3991).
    + `<td>` should close an open `<th>` or `<td>`.
    + `htmlTag` improvements (#3989).  We previously failed on cases
    where an attribute contained a `>` character. This patch fixes the
    bug, which especially affects raw HTML in Markdown.
  * Txt2Tags reader:
    + Newline is not indentation (Alexander Krotov).
  * MediaWiki reader:
    + Allow extra hyphens after `|-` in tables (#2649).
    + Allow blank line after table start (#2649).
    + Fixed more table issues (#2649).
    + Ensure that list starts begin at left margin (#2606).  Including when
    they're in tables or other list items.
    + Make smart double quotes depend on `smart` extension (#3585).
    + Don't do curly quotes inside `<tt>` contexts (#3585).  Even if `+smart`.
    + Modified state type to be an instance of `HasLogMessages`, so
    `registerHeader` can issue warnings.
  * TWiki reader (Alexander Krotov):
    + Remove unnecessary `$` (#3597).
    + Simplify `linkText` (#3605).
  * EPUB reader:
    + Minor refactoring, avoiding explicit MediaBag handling.
    This all works behind the scenes in CommonState plumbing.
  * Docx reader:
    + Don't drop smartTag contents (#2242).
    + Handle local namespace declarations (#3365).  Previously we didn't
    recognize math, for example, when the xmlns declaration occured on
    the element and not the root.
    + More efficient trimSps (#1530).  Replacing `trimLineBreaks`.  This
    does the work of `normalizeSpaces` as well, so we avoid the need for
    that function here.
    + Avoid 0-level headers (Jesse Rosenthal, #3830).  We used to parse
    paragraphs styled with "HeadingN" as "nth-level header." But if a
    document has a custom style named "Heading0", this will produce a
    0-level header, which shouldn't exist. We only parse this style
    if N>0. Otherwise we treat it as a normal style name, and
    follow its dependencies, if any.
    + Add tests for avoiding zero-level header (Jesse Rosenthal).
  * ODT reader:
    + Replaced `collectRights` with Rights from `Data.Either`.
    + Remove dead code (Albert Krewinkel).
  * Org reader (Albert Krewinkel, unless noted).
    + Don't allow tables inside list items (John MacFarlane, #3499).
    + Disallow tables on list marker lines (#3499).
    + Convert markup at beginning of footnotes (John MacFarlane, #3576).
    + Allow emphasized text to be followed by `[` (#3577).
    + Handle line numbering switch for src blocks.
    The line-numbering switch that can be given to source blocks (`-n` with
    an start number as an optional parameter) is parsed and translated to a
    class/key-value combination used by highlighting and other readers and
    writers.
    + Stop adding rundoc prefix to src params.  Source block parameter names
    are no longer prefixed with `rundoc`. This was intended to simplify
    working with the rundoc project, a babel runner. However, the rundoc
    project is unmaintained, and adding those markers is not the reader's
    job anyway.  The original language that is specified for a source
    element is now retained as the `data-org-language` attribute and only
    added if it differs from the translated language.
    + Allow multi-word arguments to src block params (#3477).  The reader now
    correctly parses src block parameter list even if parameter arguments
    contain multiple words.
    + Avoid creating `nullMeta` by applying `setMeta` directly
    (Alexander Krotov).
    + Replace `sequence . map` with `mapM`.
    + Fix smart parsing behavior.  Parsing of smart quotes and special
    characters can either be enabled via the `smart` language extension or
    the `'` and `-` export options. Smart parsing is active if either the
    extension or export option is enabled.  Only smart parsing of special
    characters (like ellipses and en and em dashes) is enabled by default,
    while smart quotes are disabled.  Previously, all smart parsing was
    disabled unless the language extension was enabled.
    + Subject full doc tree to headline transformations (Albert Krewinkel,
    [#3695]).  Emacs parses org documents into a tree structure, which is
    then post-processed during exporting. The reader is changed to do the
    same, turning the document into a single tree of headlines starting
    at level 0.
    + Fix cite parsing behaviour (Herwig Stuetz).  Until now, `org-ref`
    cite keys included special characters also at the end. This caused
    problems when citations occur right before colons or at the end of
    a sentence.  With this change, all non alphanumeric characters at
    the end of a cite key are ignored.  This also adds `,` to the list
    of special characters that are legal in cite keys to better mirror
    the behaviour of org-export.
    + Fix module names in haddock comments.  Copy-pasting had lead to
    haddock module descriptions containing the wrong module names.
    + Recognize babel result blocks with attributes (#3706).  Babel
    result blocks can have block attributes like captions and names.
    Result blocks with attributes were not recognized and were parsed
    as normal blocks without attributes.
    + Include tags in headlines.  The Emacs default is to include tags in the
    headline when exporting.  Instead of just empty spans, which contain the
    tag name as attribute, tags are rendered as small caps and wrapped in
    those spans.  Non-breaking spaces serve as separators for multiple tags.
    + Respect export option for tags (#3713).  Tags are appended to
    headlines by default, but will be omitted when the `tags` export option
    is set to nil.
    + Use `tag-name` attribute instead of `data-tag-name`.
    + Use `org-language` attribute rather than `data-org-language`.
    + Modified state type to be an instance of `HasLogMessages`, so
    `registerHeader` can issue warnings.
    + End footnotes after two blank lines.  Footnotes can not only be
    terminated by the start of a new footnote or a header, but also by two
    consecutive blank lines.
    + Update emphasis border chars (#3933).  The org reader was updated to
    match current org-mode behavior: the set of characters which are
    acceptable to occur as the first or last character in an org emphasis
    have been changed and now allows all non-whitespace chars at the
    inner border of emphasized text (see `org-emphasis-regexp-components`).
  * RST reader:
    + Fixed small bug in list parsing (#3432).  Previously the parser didn't
    handle properly this case:
  * - a
  - b
  * - c
  - d
    + Handle multiline cells in simple tables (#1166).
    + Parse list table directive (Keiichiro Shikano, #3432).
    + Make use of `anyLineNewline` (Alexander Krotov, #3686).
    + Use `anyLineNewline` in `rawListItem` (Alexander Krotov, #3702).
    + Reorganize block parsers for ~20%% faster parsing.
    + Fixed `..include::` directive (#3880).
    + Handle blank lines correctly in line blocks (Alexander Krotov, #3881).
    Previously pandoc would sometimes combine two line blocks separated
    by blanks, and ignore trailing blank lines within the line block.
    + Fix indirect hyperlink targets (#512).
  * Markdown reader:
    + Allow attributes in reference links to start on next line (#3674).
    + Parse YAML metadata in a context that sees footnotes defined in
    the body of the document (#1279).
    + When splitting pipe table cells, skip tex math (#3481).
    You might have a `|` character inside math.  (Or for that matter
    something that the parser might mistake for raw HTML.)
    + Treat span with class `smallcaps` as SmallCaps.
    This allows users to specify small caps in Markdown this way:
    `[my text]{.smallcaps}` (#1592).
    + Fixed internal header links (#2397).
    This patch also adds `shortcut_reference_links` to the list
    of mmd extensions.
    + Treat certain environments as inline
    when they occur without space surrounding them (#3309, #2171).
    E.g. equation, math.  This avoids incorrect vertical space
    around equations.
    + Optimized `nonindentSpaces`.  Makes the benchmark go from 40 to 36 ms.
    + Allow latex macro definitions indented 1-3 spaces.
    Previously they only worked if nonindented.
    + Improved parsing of indented raw HTML blocks (#1841).
    Previously we inadvertently interpreted indented HTML as
    code blocks.  This was a regression.  We now seek to determine the
    indentation level of the contents of an HTML block, and (optionally)
    skip that much indentation.  As a side effect, indentation may be
    stripped off of raw HTML blocks, if `markdown_in_html_blocks` is
    used. This is better than having things interpreted as indented
    code blocks.
    + Fixed smart quotes after emphasis (#2228).  E.g. in `*foo*'s 'foo'`.
    + Warn for notes defined but not used (#1718).
    + Use `anyLineNewline` (Alexander Krotov).
    + Interpret YAML metadata as Inlines when possible (#3755).  If
    the metadata field is all on one line, we try to interpret it as
    Inlines, and only try parsing as Blocks if that fails.  If it
    extends over one line (including possibly the `|` or `>` character
    signaling an indented block), then we parse as Blocks.  This was
    motivated by some German users finding that `date: '22. Juin 2017'`
    got parsed as an ordered list.
    + Fixed spurious parsing as citation as reference def (#3840).
    We now disallow reference keys starting with `@` if the
    `citations` extension is enabled.
    + Parse `-@roe` as suppress-author citation (pandoc-citeproc#237).
    Previously only `[-@roe]` (with brackets) was recognized as
    suppress-author, and `-@roe` was treated the same as `@roe`.
    + Fixed parsing of fenced code after list when there is no intervening
    blank line (#3733).
    + Allow raw latex commands starting with `\start` (#3558).  Previously
    these weren't allowed because they were interpreted as starting
    ConTeXt environments, even without a corresponding `\stop`...
    + Added `inlines`, `inlines1`.
    + Require nonempty alt text for `implicit_figures` (#2844).
    A figure with an empty caption doesn't make sense.
    + Removed texmath macro material; now all this is handled
    in the LaTeX reader functions.
    + Fixed bug with indented code following raw LaTeX (#3947).
  * LaTeX reader:
    + Rewrote LaTeX reader with proper tokenization (#1390,
    [#2118], #3236, #3779, #934, #982).  This rewrite is primarily
    motivated by the need to get macros working properly.  A side benefit
    is that the reader is significantly faster.  We now tokenize the
    input text, then parse the token stream.  Macros modify the token
    stream, so they should now be effective in any context, including
    math. Thus, we no longer need the clunky macro processing
    capacities of texmath.
    + Parse `\,` to `\8198` (six-per-em space) (Henri Werth).
    + Allow `\newcommand\foo{blah}` without braces.
    + Support `\lstinputlisting` (#2116).
    + Issue warnings when skipping unknown latex commands (#3392).
    + Include contents of `\parbox`.
    + Allow `\hspace` and `\vspace` to count as raw block or inline.
    Previously we would refuse to parse anything as raw inline if
    it was in the `blockCommands` list.  Now we allow exceptions
    if they're listed under ignoreInlines in inlineCommands.
    This should make it easier e.g. to include an `\hspace`
    between two side-by-side raw LaTeX tables.
    + Don't drop contents of `\hypertarget`.
    + Handle spaces before `\cite` arguments.
    + Allow newpage, clearpage, pagebreak in inline contexts as well as
    block contexts (#3494).
    + Treat `{{xxx}}` the same as `{xxx}` (#2115).
    + Use `pMacroDefinition` in macro (for more direct parsing).
    Note that this means that `macro` will now parse one
    macro at a time, rather than parsing a whole group together.
    + Fixed failures on \ref{}, \label{} with `+raw_tex`.  Now these
    commands are parsed as raw if `+raw_tex`; otherwise, their argument
    is parsed as a bracketed string.
    + Don't crash on empty `enumerate` environment (#3707).
    + Handle escaped `&` inside table cell (#3708).
    + Handle block structure inside table cells (#3709).  `minipage` is no
    longer required.
    + Handle some width specifiers on table columns (#3709).  Currently
    we only handle the form `0.9\linewidth`.  Anything else would have
    to be converted to a percentage, using some kind arbitrary assumptions
    about line widths.
    + Make sure `\write18` is parsed as raw LaTeX.  The change is in the
    LaTeX reader's treatment of raw commands, but it also affects the
    Markdown reader.
    + Fixed regression with starred environment names (#3803).
    + Handle optional args in raw `\titleformat` (#3804).
    + Improved heuristic for raw block/inline.  An unknown command at the
    beginning of the line that could be either block or inline is
    treated as block if we have a sequence of block commands followed by
    a newline or a `\startXXX` command (which might start a raw ConTeXt
    environment).
    + Don't remove macro definitions from the output, even if
    `Ext_latex_macros` is set, so that macros will be applied.
    Since they're only applied to math in Markdown, removing the macros
    can have bad effects.  Even for math macros, keeping them should be
    harmless.
    + Removed `macro`.  It is no longer necessary, since the
    `rawLaTeXBlock` parser will parse macro definitions.  This also avoids
    the need for a separate `latexMacro` parser in the Markdown reader.
    + Use `label` instead of `data-label` for label in caption (#3639).
    + Fixed space after \figurename etc.
    + Resolve references to section numbers.
    + Fix `\let\a=0` case, with single character token.
    + Allow `@` as a letter in control sequences.  `@` is commonly used
    in macros using `\makeatletter`.  Ideally we'd make the tokenizer
    sensitive to `\makeatletter` and `\makeatother`, but until then this
    seems a good change.
    + Track header numbers and correlate with labels.
    + Allow `]` inside group in option brackets (#3857).
    + lstinline with braces can be used (verb cannot be used with braces)
    (Marc Schreiber, #3535).
    + Fix keyval funtion: pandoc did not parse options in braces correctly
    (Marc Schreiber, #3642).
    + When parsing raw LaTeX commands, include trailing space (#1773).
    Otherwise things like `\noindent foo` break and turn into
    `\noindentfoo`.  Affects `-f latex+raw_tex` and `-f markdown` (and other
    formats that allow `raw_tex`).
    + Don't treat "..." as Quoted (#3958).  This caused quotes to be omitted in
    `\texttt` contexts.
    + Add tests for existing `\includegraphics` behaviour (Ben Firshman).
    + Allow space before `=` in bracketd options (Ben Firshman).
    + Be more forgiving in parsing command options.  This was needed, for
    example, to make some minted options work.
    + Strip off quotes in `\include` filenames.
  * Added `Text.Pandoc.CSV`, simple (unexported) CSV parser.
  * `Text.Pandoc.PDF`:
    + Got `--resource-path` working with PDF output (#852).
    + Fetch images when generating PDF via context (#3380).
    To do this, we create the temp directory as a subdirectory
    of the working directory. Since context mk IV by default looks
    for images in the parent directory, this works.
    + Use `report` instead of `warn`, make it sensitive to verbosity settings.
    + Use `fillMediaBag` and `extractMedia` to extract media to temp dir.
    This reduces code duplication.
    + `html2pdf`: use stdin instead of intermediate HTML file
    + Removed useless `TEXINPUTS` stuff for `context2pdf`.  mkiv context
    doesn't use `TEXINPUTS`.
  * `Text.Pandoc.Pretty`:
    + Simplified definition of `realLength`.
    + Don't error for blocks of size < 1.  Instead, resize to 1 (see #1785).
  * `Text.Pandoc.MIME`:
    + Use `application/javascript` (not `application/x-javascript`).
    + Added `emf` to mimeTypes with type `application/x-msmetafile` (#1713).
  * `Text.Pandoc.ImageSize`:
    + Improve SVG image size code (Marc Schreiber, #3580).
    + Make `imageSize` recognize basic SVG dimensions (Mauro Bieg, #3462).
  * Use `Control.Monad.State.Strict` throughout.  This gives 20-30%% speedup
    and reduction of memory usage in most of the writers.
  * Use `foldrWithKey` instead of deprecated `foldWithKey`.
  * `Text.Pandoc.SelfContained`:
    + Fixed problem with embedded fonts (#3629).
    + Refactored getData from `getDataURI` in `SelfContained`.
    + Don't use data URIs for script or style (#3423).  Instead, just use
    script or style tags with the content inside.  The old method with
    data URIs prevents certain optimizations outside pandoc.  Exception:
    data URIs are still used when a script contains `</script>` or a
    style contains `</`.
    + SelfContained: Handle URL inside material retrieved from a URL
    (#3629).  This can happen e.g. with an @import of a google web font.
    (What is imported is some CSS which contains an url reference
    to the font itself.) Also, allow unescaped pipe (|) in URL.
    + Load resources from `data-src` (needed for lazy loading in
    reveal.js slide shows).
    + Handle `data-background-image` attribute on section (#3979).
  * `Text.Pandoc.Parsing`:
    + Added `indentWith` (Alexander Krotov, #3687).
    + Added `stateCitations` to `ParserState`.
    + Removed `stateChapters` from `ParserState`.
    + In `ParserState`, make `stateNotes'` a Map, add `stateNoteRefs`.
    + Added `gobbleSpaces` and `gobbleAtMostSpaces`.
    + Adjusted type of `insertIncludedFile` so it can be used with token
    parser.
    + Replace old texmath macro stuff from Parsing.  Use Macro from
    Text.Pandoc.Readers.LaTeX.Types instead.
    + Export `insertIncludedFile`.
    + Added `HasLogMessages`, `logMessage`, `reportLogMessages` (#3447).
    + Replace partial with total function (Albert Krewinkel).
    + Introduce `HasIncludeFiles` type class (Albert Krewinkel).  The
    `insertIncludeFile` function is generalized to work with all parser
    states which are instances of that class.
    + Add `insertIncludedFilesF` which returns F blocks (Albert Krewinkel).
    The `insertIncludeFiles` function was generalized and renamed
    to `insertIncludedFiles'`; the specialized versions are based on that.
    + `many1Till`: Check for the end condition before parsing (Herwig
    Stuetz).  By not checking for the end condition before the first
    parse, the parser was applied too often, consuming too much of the
    input. This only affects `many1Till p end` where `p` matches on a
    prefix of `end`.
    + Provide `parseFromString` (#3690).  This is a verison of
    `parseFromString` specialied to ParserState, which resets
    `stateLastStrPos` at the end.  This is almost always what we want.
    This fixes a bug where `_hi_` wasn't treated as emphasis in the
    following, because pandoc got confused about the position of the
    last word: `- [o] _hi_`.
    + Added `takeP`, `takeWhileP` for efficient parsing of `[Char]`.
    + Fix `blanklines` documentation (Alexander Krotov, #3843).
    + Give less misleading line information with `parseWithString`.
    Previously positions would be reported past the end of the chunk.
    We now reset the source position within the chunk and report
    positions "in chunk."
    + Add `anyLineNewline` (Alexander Krotov).
    + Provide shared F monad functions for Markdown and Org readers
    (Albert Krewinkel).  The `F` monads used for delayed evaluation
    of certain values in the Markdown and Org readers are based on a
    shared data type capturing the common pattern of both `F` types.
    + Add `returnF` (Alexander Krotov).
    + Avoid parsing `Notes:**` as a bare URI (#3570).  This avoids parsing
    bare URIs that start with a scheme + colon + `*`, `_`, or `]`.
    + Added `readerAbbreviations` to `ParserState`.  Markdown reader
    now consults this to determine what is an abbreviation.
    + Combine grid table parsers (Albert Krewinkel, #3638).  The grid table
    parsers for markdown and rst was combined into one single
    parser `gridTable`, slightly changing parsing behavior of both
    parsers: (1) The markdown parser now compactifies block content
    cell-wise: pure text blocks in cells are now treated as paragraphs
    only if the cell contains multiple paragraphs, and as plain blocks
    otherwise. Before, this was true only for single-column tables. (2)
    The rst parser now accepts newlines and multiple blocks in header
    cells.
    + Generalize tableWith, gridTableWith (Albert Krewinkel).
    The parsing functions `tableWith` and `gridTableWith` are generalized
    to work with more parsers. The parser state only has to be an
    instance of the `HasOptions` class instead of requiring a concrete
    type. Block parsers are required to return blocks wrapped into a
    monad, as this makes it possible to use parsers returning results
    wrapped in `Future`s.
  * `Text.Pandoc.Shared`:
    + Simplify `toRomanNumeral` using guards (Alexander Krotov, #3445)
    + `stringify`: handle Quoted better (#3958).  Previously we were losing
    the quotation marks in Quoted elements.
  * `Text.Pandoc.Writers.Shared`:
    + Export `metaToJSON'`, `addVariablesToJSON` (#3439).
    This allows us to add the variables AFTER using the metadata
    to generate a YAML header (in the Markdown writer).
    + Added `unsmartify` (previously in RST writer).
    Undo literal double curly quotes.  Previously we left these.
    + Generalize type of `metaToJSON` so it can take a Text.  Previously a
    String was needed as argument; now any ToJSON instance will do.
    + Added `gridTable` (previously in Markdown writer).
    + `gridTable`: Refactored to use widths in chars.
    + `gridTable`:  remove unnecessary extra space in cells.
    + Fixed `addVariablesToJSON`.  It was previously not allowing multiple
    values to become lists.
    + Pipe tables: impose minimum cell size (see #3526).
  [default template changes]
  * HTML templates (including EPUB and HTML slide show templates):
    + Make default.html5 polyglot markup conformant (John Luke Bentley,
    [#3473]).  Polyglot markup is HTML5 that is also valid XHTML. See
    <https://www.w3.org/TR/html-polyglot>.  With this change, pandoc's
    html5 writer creates HTML that is both valid HTML5 and valid XHTML.
    + Regularized CSS in html/epub/html slide templates (#3485).
    All templates now include `code{white-space: pre-wrap}`
    and CSS for `q` if `--html-q-tags` is used.  Previously some templates
    had `pre` and others `pre-wrap`; the `q` styles were only sometimes
    included.
    + CSS for `.smallcaps`, (Mauro Bieg, #1592)
    + `default.revealjs`: make `history` default to true.
    + `default.revealjs`: use lazy loading (#2283).
    + `default.revealjs`: add `mathjax` variable and some conditional code
    to use the MathJaX plugin.
    + `default.slidy` uses `https` instead of `http` (ickc, #3848).
    + `default.dzslides`: Load Google Font using HTTPS by default
    (Yoan Blanc).
  * DocBook5 template: Use `lang` and `subtitle` variables (Jens Getreu,
    [#3855]).
  * LaTeX/Beamer template:
    + Combine LaTeX/Beamer templates (Andrew Dunning, #3878).
    `default.beamer` has been removed; beamer now uses the
    `default.latex` template.  Beamer-specific parts are conditional
    on the `beamer` variable set by the writer. Note that
    `pandoc -D beamer` will return this (combined) template.
    + Use `xcolor` for `colorlinks` option (Andrew Dunning, #3877).
    Beamer loads `xcolor` rather than `color`, and thus the
    `dvipsnames` option doesn't take effect. This also provides a wider
    range of colour selections with the `svgnames` option.
    + Use starred versions of `xcolor` names (Andrew Dunning).
    Prevents changes to documents defined using the `dvipsnames` list (e.g.
    `Blue` gives a different result with svgnames enabled).
    + Load `polyglossia` after header-includes (#3898).  It needs to be
    loaded as late as possible.
    + Use `unicode-math` (Vaclav Haisman).  Use `mathspec` with only
    XeLaTeX on request.
    + Don't load `fontspec` before `unicode-math` (over there).
    The `unicode-math` package loads `fontspec` so explict loading of
    `fontspec` before `unicode-math` is not necessary.
    + Use `unicode-math` by default in default.latex template.  mathspec will
    be used in xelatex if the `mathspec` variable is set; otherwise
    unicode-math will be used (Václav Haisman).
    + Use `dvipsnames` options when `colorlinks` specified (otherwise
    we get an error for `maroon`) (Thomas Hodgson).
    + Added beamer `titlegraphic` and `logo` variables (Thomas Hodgson).
    + Fix typo in fix for notes in tables (#2378, zeeMonkeez).
    + Fix `hyperref` options clash (Andrew Dunning, #3847) Avoids an options
    clash when loading a package (e.g. `tufte-latex`) that uses
    `hyperref` settings different from those in the template.
    + Add `natbiboptions` variable (#3768).
    + Fix links inside captions in LaTeX output with links-as-notes
    (Václav Haisman, #3651).  Declare our redefined `\href` robust.
    + Load `parskip` before `hyperref` (Václav Haisman, #3654).
    + Allow setting Japanese fonts when using LuaLaTeX (Václav Haisman,
    [#3873]).  by using the `luatexja-fontspec` and `luatexja-preset`
    packages. Use existing `CJKmainfont` and `CJKoptions` template
    variables. Add `luatexjafontspecoptions` for `luatexja-fontspec`
    and `luatexjapresetoptions` for `luatexja-preset`.
    + Added `aspectratio` variable to beamer template (Václav Haisman,
    [#3723]).
    + Modified template.latex to fix XeLaTex being used with tables
    (lwolfsonkin, #3661).  Reordered `lang` variable handling to
    immediately before `bidi`.
  * ConTeXt template: Improved font handling: `simplefonts` is now
    obsolete in ConTeXt (Pablo Rodríguez).
  [documentation improvements]
  * MANUAL.txt:
    + Add URL for Prince HTML > PDF engine (Ian, #3919).
    + Document that content above slide-level will be omitted in
    slide shows.  See #3460, #2265.
    + Explain `--webtex` SVG url (Mauro Bieg, #3471)
    + Small clarification in YAML metadata section.
    + Document that html4 is technically XHTML 1.0 transitional.
    + Remove refs to highlighting-kate (#3672).
    + Document ibooks specific epub metadata.
    + Clarify that mathml is used for ODT math.
    + Mention limitations of Literate Haskell Support (#3410,
    Joachim Breitner).
    + Add documentation of limitations of grid tables (Stephen
    McDowell, #3864).
    + Clarify that meta-json contains transformed values (Jakob Voß,
    [#3491]) Make clear that template variable `meta-json` does not
    contain plain text values or JSON output format but field values
    transformed to the selected output format.
  * COPYRIGHT:
    + Clarify that templates are dual-licensed.
    + Clarify that pandoc-types is BSD3 licensed.
    + List new files not written by jgm (Albert Krewinkel).
    + Update dates in copyright notices (Albert Krewinkel).  This follows
    the suggestions given by the FSF for GPL licensed software.
    <https://www.gnu.org/prep/maintain/html_node/Copyright-Notices.html>
  * INSTALL.md:
    + Improved instructions for tests with patterns.
    + Put RPM-based distros on separate point (Mauro Bieg, #3449)
  * CONTRIBUTING.md:
    + Fixed typos (Wandmalfarbe, #3479).
    + Add "ask on pandoc-discuss" (Mauro Bieg).
  * Add lua filter documentation in `doc/lua-filters.md`.  Note that the
    end of this document is autogenerated from `data/pandoc.lua`
    using `make doc/lua-filters.md`, which uses `tools/ldoc.ltp`
    (Albert Krewinkel).
  * Add `doc/filters.md`. This is the old scripting tutorial from
    the website.
  * Add `doc/using-the-pandoc-api.md` (#3289).  This gives an introduction
    to using pandoc as a Haskell library.
  [build infrastructure improvements]
  * Removed `data/templates` submodule.  Templates are now a subtree
    in `data/templates`.  This removes the need to do `git submodule
    update`.
  * Renamed `tests` -> `test`.
  * Remove `https` flag.  Always build with HTTPS support.
  * Use `file-embed` instead of `hsb2hs` to embed data files when
    `embed_data_files` flag is set.  `file-embed` gives us better dependency
    tracking:  if a data file changes, ghc/stack/cabal know to recompile
    the Data module.  This also removes `hsb2hs` as a build dependency.
  * Add `custom-setup` stanza to pandoc, lowercase field names.
  * Add `static` Cabal flag.
  * Name change OSX -> MacOS.  Add a -MacOS suffix to mac package rather
    than -OSX.  Changed local names from osx to macos.
  * make_macos_package.sh - Use strip to reduce executable size.
  * Revised binary linux package.  Now a completely static executable
    is created, using Docker and alpine.  We create both a deb and a
    tarball.  The old `deb` directory has been replaced with a `linux`
    directory.  Running `make` in the `linux` directory should
    perform the build, putting the binary packages in `artifacts/`.
  * `linux/control.in`: add `Replaces:`, so existing pandoc-citeproc and
    pandoc-data packages will be uninstalled; this package provides
    both (#3822).  Add latex packages as 'suggested', update
    description.
  * Remove cpphs build requirement -- it is no longer needed.
  * Replaced `{deb,macos,windows}/stack.yaml` with `stack.pkg.yaml`.
  * Name change OSX -> macOS (ickc, #3869).
  * Fix casing of Linux, UNIX, and Windows (ickc).
  * `.travis.yml`:  create a source dist and do cabal build and test there.
    That way we catch errors due to files missing from the data
    section of pandoc.cabal.
  * Makefile:
    + Split `make haddock` from `make full`.
    + Add BRANCH variable for winpkg.
    + Add `lint` target.
    + Improve `make full`. Disable optimizations.
    Build everything, inc. trypandoc and benchmarks.  Use parallel build.
    + Allow `make test` to take `TESTARGS`.
  * Added new command tests (`Tests.Command`), using small text files
    in `test/command/`.  Any files added in this directory will be treated
    as shell tests (see smart.md for an example).  This makes it very easy
    to add regression tests etc.
  * Test fixes so we can find data files.  In old tests & command tests,
    we now set the environment variable `pandoc_datadir`.  In lua tests,
    we set the datadir explicitly.
  * Refactored `compareOutput` in docx writer test.
  * Consolidated some common functions in `Tests.Helper`.
  * Small change to unbalanced bracket test to speed up test suite.
  * Speed up Native writer quickcheck tests.
  * Use tasty for tests rather than test-framework.
  * Add simple Emacs mode to help with Pandoc templates editing.
    (Václav Haisman, #3889). `tools/pandoc-template-mode.el`
  * Use skylighting library instead of highlighting-kate for syntax
    highlighting. Skylighting is faster and more accurate (#3363).
    Later we'll be able to add features like warning messages, dynamic
    loading of xml syntax definitions, and dynamic loading of themes.
  * Added a new highlight style, `breezeDark`.
  * Text.Pandoc.Highlighting: Update list of `listings` languages (#3374).
    This allows more languages to be used when using the `--listings`
    option.
  * OpenDocument writer:
    + Small refactoring.  Removed separate 'parent' parameter in paraStyle.
    + Don't profilerate text styles unnecessarily (#3371).
    This change makes the writer create only as many temporary
    text styles as are absolutely necessary. It also consolidates
    adjacent nodes with the same style.
  * Org reader (Albert Krewinkel):
    + Allow short hand for single-line raw blocks (Albert Krewinkel,
    [#3366]).  Single-line raw blocks can be given via `#+FORMAT: raw line`,
    where `FORMAT` must be one of `latex`, `beamer`, `html`, or `texinfo`.
    + Accept org-ref citations followed by commas (Albert Krewinkel).
    Bugfix for an issue which, whenever the citation was immediately
    followed by a comma, prevented correct parsing of org-ref citations.
    + Ensure emphasis markup can be nested.  Nested emphasis markup (e.g.
    `/*strong and emphasized*/`) was interpreted incorrectly in that the
    inner markup was not recognized.
    + Remove pipe char irking the haddock coverage tool (Albert Krewinkel).
  * Docx reader: Empty header should be list of lists (Jesse Rosenthal).
    In the past, the docx reader wrote an empty header as an empty list. It
    should have the same width as a row (and be filled with empty cells).
  * MediaWiki reader:
    + Improved handling of display math (#3362).  Sometimes display math is
    indented with more than one colon.  Previously we handled these cases
    badly, generating definition lists and missing the math.
    + Fix quotation mark parsing (#3336, tgkokk).  Change MediaWiki reader's
    behavior when the smart option is parsed to match other readers'
    behavior.
  * Markdown reader:
    + Fixed `-f markdown_github-hard_line_breaks+escaped_line_breaks`
    (#3341).  Previously this did not properly enable escaped line breaks.
    + Disallow space between inline code and attributes (#3326, #3323,
    Mauro Bieg).
  * DocBook5 writer: make id attribute xml:id, fixes #3329 (#3330, Mauro Bieg).
  * Added some test cases for ODT reader (#3306, #3308, Hubert Plociniczak).
  * LaTeX writer: allow tables with empty cells to count as "plain."
    This addresses a problem of too-wide tables when empty cells
    are used.  Thanks to Joost Kremers for reporting the issue.
  * Org writer: prefix footnote numbers with `fn:` (Albert Krewinkel).
    Unprefixed numbers where used by older org-mode versions, but are no
    longer supported.
  * HTML writer: don't process pars with empty RawInline, (#1040, #3327,
    Mauro Bieg).
  * Markdown writer: Fix display math with `--webtex` (#3298).
  * Fix sample.lua so it properly handles raw blocks/inlines (#3358,
    bumper314).
  * Templates:
    + default.latex: Moved geometry after hyperref (Václav Haisman).
    Otherwise PDF sizes can be wrong in some circumstances.
    + Copied a few changes from default.latex to default.beamer
    (Wandmalfarbe).
    + default.latex, default.beamer: Changed position of `\VerbatimNotes`
    and `fancyvrb`.  This fixes hyperlinks on footnotes in documents
    that contain verbatim in notes (#3361).  (Note: the beamer template
    was updated to match the LaTeX template, but at this point verbatim
    in notes seems not to work in beamer.)
    + default.latex: Allow passing `microtypeoptions` to microtype
    (Václav Haisman).
    + default.latex: Add hyphen option to url package.
    + default.docbook5: Fix namespace declarations (Mauro Bieg).
  * Moved `make_osx_package.sh` to `osx/` directory.
  * Travis continuous integration:
    + Fix false positives with dist build.
    + Speed improvements (Kolen Cheung, #3304, #3357).
  * MANUAL.txt:
    + Clarify that blank space is needed around footnotes (#3352).
    + Fixed typo (#3351, Alexey Rogechev).
    + Note that `--wrap=auto` does not work in HTML output.
    + Default `--columns` width is 72, not 80.
    + Fixed broken links (#3316, Kolen Cheung).
    + Document usage of `@*` in nocite section (#3333, John Muccigrosso).
  * INSTALL.md:
    + Indent code so it's properly formatted (#3335, Bheesham Persaud).
    + Added instructions for extracting binary from OSX, Windows packages.
  * CONTRIBUTING.md: Describe labels currently used in issue tracker
    (Albert Krewinkel).  The labels have changed over time, the list of
    labels is updated to reflect the current set of labels used in the
    issue tracker.
  * Rearrange and extend badges in README (Albert Krewinkel, #3354)
  * Bumped version bounds for dependencies.
* Thu Aug  3 2017 psimons@suse.com
- Updated with latest spec-cleaner version 0.9.8-8-geadfbbf.
* Mon Jun 19 2017 psimons@suse.com
- Update to version 1.19.2.1 revision 5.
* Thu Jun  1 2017 schwab@suse.de
- Fix requires
* Wed May 31 2017 psimons@suse.com
- Update to version 1.19.2.1 revision 4.
* Mon Apr 24 2017 psimons@suse.com
- Update to version 1.19.2.1 revision 3 with cabal2obs.
* Wed Mar 22 2017 psimons@suse.com
- Update to version 1.19.2.1 revision 2 with cabal2obs.
* Thu Mar  2 2017 psimons@suse.com
- Update to version 1.19.2.1 revision 1 with cabal2obs.
* Sun Feb 12 2017 psimons@suse.com
- Update to version 1.19.2.1 with cabal2obs.
* Fri Dec  9 2016 psimons@suse.com
- Drop obsolete suggestion of "texlive-latex-bin-bin". This package
  is now a dependency of the pandoc-pdf sub-package.
* Wed Sep 14 2016 astieger@suse.com
- add constraints to fix build on aarch64
* Sun Jul 10 2016 psimons@suse.com
- Update to version 1.17.1 revision 1 with cabal2obs.
* Sun Jun  5 2016 mimi.vx@gmail.com
- update to 1.17.1
  * New output format: `docbook5`
  * `Text.Pandoc.Options`: Add `writerDocBook5` to `WriterOptions`
  * Org writer:
  + Add :PROPERTIES: drawer support
    This allows header attributes to be added to org documents in the form
    of `:PROPERTIES:` drawers.  All available attributes are stored as
    key/value pairs.  This reflects the way the org reader handles
    `:PROPERTIES:` blocks.
  + Add drawer capability. For the implementation of the
    Drawer element in the Org Writer, we make use of a generic Block
    container with attributes.  The presence of a `drawer` class defines
    that the `Div` constructor is a drawer. The first class defines the
    drawer name to use.  The key-value list in the attributes defines
    the keys to add inside the Drawer.  Lastly, the list of Block elements
    contains miscellaneous blocks elements to add inside of the Drawer.
  + Use `CUSTOM_ID` in properties.  The `ID` property is
    reserved for internal use by Org-mode and should not be used.
    The `CUSTOM_ID` property is to be used instead, it is converted to the
    `ID` property for certain export format.
  * LaTeX writer:
  + Ignore `--incremental` unless output format is beamer.
  + Fix polyglossia to babel env mapping.
    Allow for optional argument in square brackets.
  + Recognize `la-x-classic` as Classical Latin.
    This allows one to access the hyphenation patterns in CTAN's
    hyph-utf8.
  + Add missing languages from hyph-utf8.
  + Improve use of `\strut` with `\minipage` inside tables
    .  This improves spacing in multiline
    tables.
  + Use `{}` around options containing special chars.
  + Avoid lazy `foldl`.
  + Don't escape underscore in labels.  Previously they were
    escaped as `ux5f`.
  + brazilian -> brazil for polyglossia.
  * HTML writer: Ensure mathjax link is added when math appears in footnote
  . Previously if a document only had math in a footnote, the
  MathJax link would not be added.
  * EPUB writer: set `navpage` variable on nav page.
  This allows templates to treat it differently.
  * DocBook writer:
  + Use docbook5 if `writerDocbook5` is set.
  + Properly handle `ulink`/`link`.
  * EPUB reader:
  + Unescape URIs in spine.
  + EPUB reader:  normalise link id.
  * Docx Reader:
  + Parse `moveTo` and `moveFrom`.
    `moveTo` and `moveFrom` are track-changes tags that are used when a
    block of text is moved in the document. We now recognize these tags and
    treat them the same as `insert` and `delete`, respectively. So,
    `--track-changes=accept` will show the moved version, while
    `--track-changes=reject` will show the original version.
  + Tests for track-changes moving.
  * ODT, EPUB, Docx readers: throw `PandocError` on unzip failure
  Previously, `readDocx`, `readEPUB`, and `readOdt`
  would error out if zip-archive failed. We change the archive extraction
  step from `toArchive` to `toArchiveOrFail`, which returns an Either value.
  * Markdown, HTML readers:  be more forgiving about unescaped `&` in
  HTML (#2410).  We are now more forgiving about parsing invalid HTML with
  unescaped `&` as raw HTML.  (Previously any unescaped `&`
  would cause pandoc not to recognize the string as raw HTML.)
  * Markdown reader:
  + Fix pandoc title blocks with lines ending in 2 spaces.
  + Added `-s` to markdown-reader-more test.
  * HTML reader: fixed bug in `pClose`.  This caused exponential parsing
  behavior in documnets with unclosed tags in `dl`, `dd`, `dt`.
  * MediaWiki reader: Allow spaces before `!` in MediaWiki table header
  * RST reader: Support `:class:` option for code block in RST reader
  * Org reader:
  + Stop padding short table rows.
    Emacs Org-mode doesn't add any padding to table rows.  The first
    row (header or first body row) is used to determine the column count,
    no other magic is performed.
  + Refactor rows-to-table conversion.  This refactors
    the codes conversing a list table lines to an org table ADT.
    The old code was simplified and is now slightly less ugly.
  + Fix handling of empty table cells, rows.
    This fixes Org mode parsing of some corner cases regarding empty cells
    and rows.  Empty cells weren't parsed correctly, e.g. `|||` should be
    two empty cells, but would be parsed as a single cell containing a pipe
    character.  Empty rows where parsed as alignment rows and dropped from
    the output.
  + Fix spacing after LaTeX-style symbols.
    The org-reader was droping space after unescaped LaTeX-style symbol
    commands: `\ForAll \Auml` resulted in `∀Ä` but should give `∀ Ä`
    instead.  This seems to be because the LaTeX-reader treats the
    command-terminating space as part of the command.  Dropping the trailing
    space from the symbol-command fixes this issue.
  + Print empty table rows.  Empty table rows should not
    be dropped from the output, so row-height is always set to be at least 1.
  + Move parser state into separate module.
    The org reader code has become large and confusing.  Extracting smaller
    parts into submodules should help to clean things up.
  + Add support for sub/superscript export options.
    Org-mode allows to specify export settings via `#+OPTIONS` lines.
    Disabling simple sub- and superscripts is one of these export options,
    this options is now supported.
  + Support special strings export option Parsing of special strings
    (like `...` as ellipsis or `--` as en dash) can be toggled using the `-`
    option.
  + Support emphasized text export option.  Parsing of emphasized text can
    be toggled using the `*` option.  This influences parsing of text marked
    as emphasized, strong, strikeout, and underline.  Parsing of inline math,
    code, and verbatim text is not affected by this option.
  + Support smart quotes export option.  Reading of smart quotes can be
    toggled using the `'` option.
  + Parse but ignore export options. All known export options are parsed
    but ignored.
  + Refactor block attribute handling.  A parser state attribute was used
    to keep track of block attributes defined in meta-lines.  Global state
    is undesirable, so block attributes are no longer saved as part of the
    parser state.  Old functions and the respective part of the parser state
    are removed.
  + Use custom `anyLine`.  Additional state changes need to be made after
    a newline is parsed, otherwise markup may not be recognized correctly.
    This fixes a bug where markup after certain block-types would not be
    recognized.
  + Add support for `ATTR_HTML` attributes.
    Arbitrary key-value pairs can be added to some block types using a
    `#+ATTR_HTML` line before the block.  Emacs Org-mode only includes these
    when exporting to HTML, but since we cannot make this distinction here,
    the attributes are always added.  The functionality is now supported
    for figures.
  + Add `:PROPERTIES:` drawer support.
    Headers can have optional `:PROPERTIES:` drawers associated with them.
    These drawers contain key/value pairs like the header's `id`.  The
    reader adds all listed pairs to the header's attributes; `id` and
    `class` attributes are handled specially to match the way `Attr` are
    defined.  This also changes behavior of how drawers of unknown type
    are handled.  Instead of including all unknown drawers, those are not
    read/exported, thereby matching current Emacs behavior.
  + Use `CUSTOM_ID` in properties.  See above on Org writer changes.
  + Respect drawer export setting.  The `d` export option can be used
    to control which drawers are exported and which are discarded.
    Basic support for this option is added here.
  + Ignore leading space in org code blocks.
    Also fix up tab handling for leading whitespace in code blocks.
  + Support new syntax for export blocks.  Org-mode version 9
    uses a new syntax for export blocks.  Instead of `#+BEGIN_<FORMAT>`,
    where `<FORMAT>` is the format of the block's content, the new
    format uses `#+BEGIN_export <FORMAT>` instead.  Both types are
    supported.
  + Refactor `BEGIN...END` block parsing.
  + Fix handling of whitespace in blocks, allowing content to be indented
    less then the block header.
  + Support org-ref style citations.  The *org-ref* package is an
    org-mode extension commonly used to manage citations in org
    documents.  Basic support for the `cite:citeKey` and
    `[[cite:citeKey][prefix text::suffix text]]` syntax is added.
  + Split code into separate modules, making for cleaner code and
    better decoupling.
  * Added `docbook5` template.
  * `--mathjax` improvements:
  + Use new CommonHTML output for MathJax (updated default MathJax URL)
  + Change default mathjax setup to use `TeX-AMS_CHTML` configuration.
    This is designed for cases where the input is always TeX and maximal
    conformity with TeX is desired.  It seems to be smaller and load faster
    than what we used before.  See #2858.
  + Load the full MathJax config to maximize loading speed.
  * Require texmath 0.8.6.2.  Closes several texmath-related bugs
  This fixes behavior of roots, e.g.
  `\sqrt[3]{x}`, and issues with sub/superscript positioning
  and matrix column alignment in docx.
  * README:
  + Clarified documentation of `implicit_header_references`.
  + Improved documentation of `--columns` option.
  * Added appveyor setup, with artefacts.
  * stack.yaml versions: Use proper flags used for texmath, pandoc-citeproc.
  * LaTeX template: support for custom font families.
  Needed for correct polyglossia operation with Cyrillic fonts and perhaps
  can find some other usages.  Example usage in YAML metadata:
    fontfamilies:
  - name: \cyrillicfont
    font: Liberation Serif
  - name: \cyrillicfonttt
    options: Scale=MatchLowercase
    font: Liberation
* Tue Mar 29 2016 mimi.vx@gmail.com
- update to 1.17.0.3
  * LaTeX writer: Fixed position of label in figures. Previously the label wasn't
    in the right place, and `\ref` wouldn't work properly.
  * Added .tei test files to pandoc.cabal so they'll be included in tarball.
* Fri Mar 25 2016 mimi.vx@gmail.com
- update to 1.17.0.2
  * Fixed serious regression in `htmlInBalanced`, which caused
    newlines to be omitted in some raw HTML blocks in Markdown
  * File scope is no longer used when there are no input files (i.e.,
    when input comes from stdin).  Previously file scope was triggered
    when the `json` reader was specified and input came from `stdin`,
    and this caused no output to be produced.
  * Improved documentation of templates
  * Added `--file-scope` option (Jesse Rosenthal).
    By default pandoc operates on multiple files by first concatenating
    them (around extra line breaks) and then processing the joined file. So
    it only parses a multi-file document at the document scope. This has the
    benefit that footnotes and links can be in different files, but for
    some purposes it is useful to parse the individual files first
    and then combine their outputs (e.g. when the files use footnotes
    or links with the same labels).  The `--file-scope` option causes
    pandoc to parse the files first, and then combine the parsed output,
    instead of combining before parsing. `--file-scope` is selected
    automatically for binary input files (which cannot be concatenated)
    and for pandoc json.
  * Add TEI Writer (Chris Forster) and `tei` output format.
  * Added a general `ByteStringReader` with warnings, used by the docx
    reader (API change, Jesse Rosenthal).
  * Add `readDocxWithWarnings` (API change, Jesse Rosenthal).
  * Changed type of `Shared.uniqueIdent`'s argument from `[String]`
    to `Set String.` This avoids performance problems in documents with
    many identically named headers (API change, #2671).
  * Removed `tex_math_single_backslash` from `markdown_github` options
  * Make language extensions as well as full language names
    trigger syntax highlighting.  For example, `py` will now work as
    well as `python` (jgm/highlighting-kate#83).
  * Added `institute` variable to latex, beamer templates (Fraser
    Tweedale, Josef Svenningsson).
  * Docx reader (Jesse Rosenthal):
    + Handle alternate content.  Some word functions (especially graphics)
    give various choices for content so there can be backwards compatibility.
    + Don't turn numbered headers into lists.
    + Docx Reader: Add state to the parser, for warnings
    + Update feature checklist in source code.
    + Get rid of `Modifiable` typeclass.
    + Add tests for adjacent hyperlinks.
    + Add a "Link" modifier to `Reducible`. We want to make sure that
    links have their spaces removed, and are appropriately smushed
    together (#2689).
  * HTML reader:
    + Fixed behavior of base tag (#2777).
    If the base path does not end with slash, the last component
    will be replaced.  E.g. base = `http://example.com/foo`
    combines with `bar.html` to give `http://example.com/bar.html`.
    If the href begins with a slash, the whole path of the base
    is replaced.  E.g. base = `http://example.com/foo/` combines
    with `/bar.html` to give `http://example.com/bar.html`.
    + Rewrote `htmlInBalanced`.  This version avoids an exponential
    performance problem with `<script>` tags, and it should be faster
    in general (#2730).
    + Properly handle an empty cell in a simple table (#2718).
    + Handle multiple `<meta>` tags with same name.  Put them in a list
    in the metadata so they are all preserved, rather than (as before)
    throwing out all but one..
  * Markdown reader:
    + Improved pipe table parsing (#2765).
    + Allow `+` separators in pipe table cells.  We already allowed
    them in the header, but not in the body rows, for some reason.
    This gives compatibility with org-mode tables.
    + Don't cross line boundary parsing pipe table row.
    Previously an Emph element could be parsed across the newline
    at the end of the pipe table row.
    + Use `htmlInBalanced` for `rawVerbatimBlock`, for better
    performance (#2730).
    + Fixed bug with smart quotes around tex math.
  * LaTeX reader:
    + Handle interior `$` characters in math (#2743).  For example,
    `$$\hbox{$i$}$$`.
    + `inlineCommand` now gobbles an empty `{}` after any command (#2687).
    This gives better results when people write e.g. `\TeX{}` in Markdown.
    + Properly handle LaTeX "math" environment as inline math (#2171).
  * Textile reader: Support `>`, `<`, `=`, `<>` text alignment attributes.
  * Org reader (Albert Krewinkel):
    + Prefix even empty figure names with "fig:" (#2643).  The
    convention used by pandoc for figures is to mark them by prefixing
    the name with `fig:`.  The org reader failed to do this if a figure
    had no name.
    + Refactor link-target processing (#2684).
  * ConTeXt writer: Fix whitespace at line beginning in line blocks (#2744).
    Thanks to @c-foster.
  * HTML writer: Don't include alignment attribute for default table columns.
    Previously these were given "left" alignment.  Better to leave off
    alignment attributes altogether (#2694).
  * Markdown writer: Use hyphens for YAML metadata block bottom line, for
    better compatibility with other Markdown flavors (Henrik Tramberend).
  * LaTeX writer:
    + Use image identifier to create a label and hypertarget for
    figures (Mauro Bieg).
    + Avoid double toprule in headerless table with caption (#2742).
    + Clean up options parser (Jesse Rosenthal).
    + Treat `memoir` template with `article` option as article, instead
    of treating all `memoir` templates as books.
    + Allow more flexible table alignment (Henrik Tramberend, #2665).
    New default is not to include `[c]` option (which is the default
    anyway if no positioning is specified).  Now LaTeX emplates can
    control the overall table alignment in a document by setting the
    longtable length variables `LTleft` and `LTright`.  For example,
    `\setlength\LTleft\parindent\setlength\LTright\fill`
    will create left-aligned tables that respect paragraph indentation.
  * Docx writer: Handle image alt text (#2754, Mauro Bieg).
  * Org writer - pass through RawInline with format "org".
  * DokuWiki writer: use `$$` for display math.
  * Custom writer: Pass attributes parameter to CaptionedImage (#2697).
  * Make protocol-relative URIs work again (#2737).
  * make_osx_package.sh:  Use env variable for developer id certs.
  * Raise `tagsoup` lower bound to 0.13.7 to fix entity-related
    problems (#2734).
  * Allow `zip-archive` 0.3.
  * Allow `aeson` 0.11.
* Sun Mar 13 2016 mimi.vx@gmail.com
- remove unused flag
* Sat Jan 23 2016 mimi.vx@gmail.com
- update to 1.16.0.2
- very long changelog again. For details please see changelog file or
    https://hackage.haskell.org/package/pandoc-1.16.0.2/changelog
* Wed Dec 23 2015 mimi.vx@gmail.com
- create placeholder package for pdf support
* Mon Nov 16 2015 mimi.vx@gmail.com
- update to 1.15.2.1
- correct license to GPL-2.0+
- very long changelog again, for details please see changelog file or
  https://hackage.haskell.org/package/pandoc-1.15.2.1/changelog
* Sun Oct 25 2015 mimi.vx@gmail.com
- update to 1.15.1.1
  * `Text.Pandoc.Data`:  store paths in dataFiles using posix separators.
  + add Suggests: texlive-latex-bin-bin
* Sun Oct 18 2015 mimi.vx@gmail.com
- update to 1.15.1
  * `pandocVersion` is now defined in `Text.Pandoc.Shared`
    and reexported from `Text.Pandoc` (Alex Vong).  This allows
    writers to access it.  (Alex Vong) (API change)
  * For `markdown_mmd`, add: `implicit_figures`, `superscripts`,
    `subscripts` (#2401).
  * Added `odt` as input format (MarLinn).  Added new module
    `Text.Pandoc.Reader.ODT` (API change). Fully implemented features:
    Paragraphs, Headers, Basic styling, Unordered lists, Ordered lists,
    External Links, Internal Links, Footnotes, Endnotes, Blockquotes.
    Partly implemented features: Citations, Tables.
  * Markdown Reader:
    + Add basic tests for each header style (Ophir Lifshitz).
    + Add implicit header ref tests for headers with spaces (Ophir Lifshitz).
    + Skip spaces in headers (Ophir Lifshitz).
    + Handle 'id' and 'class' in parsing key/value attributes (#2396).
    `# Header {id="myid" class="foo bar"}`
    is now equivalent to `# Header {#myid .foo .bar}`.
    + Use '=' instead of '#' for atx-style headers in markdown+lhs.
    (Kristof Bastiaensen)
    + Pipe tables: allow indented columns.  Previously the left-hand column
    could not start with 4 or more spaces indent.  This was inconvenient
    for right-aligned left columns.  Note that the first (header column)
    must still have 3 or fewer spaces indentation, or the table will be
    treated as an indented code  block.
    + Fix regression:  allow HTML comments containing `--`.
    Technically this isn't allowed in an HTML comment, but
    we've always allowed it, and so do most other implementations.
    It is handy if e.g. you want to put command line arguments
    in HTML comments.
  * LaTeX reader:
    + Don't eat excess whitespace after macros with only optional
    arguments (#2446).
    + Support longtable (#2411).
    + Implement `\Cite` (#2335).
    + Support abstract environment.  The abstract populates an
    `abstract` metadata field.
    + Properly handle booktabs lines.  Lines aren't part of the
    pandoc table model, so we just ignore them (#2307).
  * HTML reader:
    + Handle type attribute on ol, e.g. `<ol type="i">` (#2313).
    + Updated for new automatic header attributes.
    + Add auto identifiers if not present on headers.  This makes
    TOC linking work properly.
    + Detect `font-variant` with `pickStyleAttrProps` (Ophir Lifshitz).
    + Test `<ol>` type, class, and inline list-style(-type) CSS
    (Ophir Lifshitz).
    + Better handling of "section" elements (#2438).  Previously
    `<section>` tags were just parsed as raw HTML blocks.  With
    this change, section elements are parsed as Div elements with
    the class "section".
  * MediaWiki reader:  handle unquoted table attributes (#2355).
  * DocBook reader:
    + Added proper support for DocBook `xref` elements (Frerich Raabe).
    Added `dbContent` field to reader state, so we can lookup
    cross refs.
    + Handle `informalexample` (#2319).
  * Docx Reader:
    + Create special punctuation test (Ophir Lifshitz).
    + Parse soft, no-break hyphen elements (Ophir Lifshitz).
    + Updated headers test (Ophir Lifshitz). Replaced `styles.xml`
    in `headers.docx` with pandoc's current `styles.xml`, which
    contains styles for Heading 1 through 6. Added Heading 4
    through 7 to the test document. Note that Heading 7 is not
    parsed as a Heading because there is no Heading 7 style.
  * RST reader:  better handling of indirect roles.
    Previously the parser failed on this kind of case
    .. role:: indirect(code)
    .. role:: py(indirect)
    :language: python
    :py:`hi`
    Now it correctly recognizes `:py:` as a code role.
  * Org reader:
    + Add auto identifiers if not present on headers
    (#2354, Juliusz Gonera).
    + Allow verse blocks to contain empty lines (#2402,
    Albert Krewinkel).
  * EPUB reader:  stop mangling external URLs (#2284).
  * RST writer:
    + Don't insert `\ ` when complex expression in matched pairs.
    E.g. `` [:sup:`3`] `` is okay; you don't need `` [:sup:`3`\ ] ``.
    + Ensure that `\ ` is inserted when needed before Cite and Span
    elements that begin with a "complex" element (jgm/pandoc-citeproc#157).
    + Normalize headers only in "standalone" mode (#2394).
  * Haddock writer: escape `*` and `^` (G. Bataille).
  * Markdown writer:
    + In TOC, add links to headers (#829).
    + Use unicode super/subscripts for digits in plain output
    (when the `superscripts` and `subscripts` extensions are
    not enabled).
  * Docx writer:
    + Moved invalid character stripping to `formattedString`.
    This avoids an inefficient generic traversal (#2356).
    + Use user data directory for `reference.docx` archive.
    This allows the test suite to work without installing pandoc first.
    It also brings the docx writer in line with the odt writer.
    + Tests:  docx writer tests now use `../data` for data directory.
    This allows tests to be run without installing first.
    + Tests: Use real jpg (not empty) for docx tests to avoid warning.
  * LaTeX writer:
    + Fixed detection of 'chapters' from template.
    If a documentclass isn't specified in metadata, but the
    template has a hardwired bookish documentclass, act as if
    `--chapters` was used.  This was the default in earlier
    versions, but it has been broken for a little while.
    + Correctly recognize book documentclass in metadata (#2395).
    + Set language-related variables automatically, depending
    on the value of the `lang` field, which is now always
    assumed to be in BCP47 format (mb21, #1614, #2437).
    + Add `\protect` to `\hyperdef` in inline context.  This way we
    don't get an error when this is used as a moveable argument (#2136).
    + Support all frame attributes in Beamer.
    + Percent-encode more special characters in URLs (#1640, #2377).
    The special characters are '<','>','|','"','{','}','[',']','^', '`'.
  * HTML writer:
    + Update KaTeX JS and CSS versions (Emily Eisenberg).
    + For dzslides, add `role="note"` for speaker notes (#1693).
    + Percent-encode more special characters in URLs (#1640, #2377).
    The special characters are '<','>','|','"','{','}','[',']','^', '`'.
    + Render Div with class `section` as `<section>` in HTML5.
  * EPUB writer:
    + In TOC, replace literal "<br/>" with space (#2105).
    + With `--webtex`, include image file rather than `data:` URI (#2363).
  * Native writer: format Div properly, with blocks separated.
  * Support bidirectional text output with XeLaTeX, ConTeXt and HTML
  * Reference Docx:
    + Add missing Header 6 style (steel blue) (Ophir Lifshitz).
    + Correct `outlineLvl` for Header styles (Ophir Lifshitz).
  * Templates
    + Beamer:  Add `innertheme`, `outertheme` variables
    (Guilhem Bonnefille, #121). Add space after colon in figure caption.
    Integrate recent font and language updates from LaTeX template;
    allow use of `mainfont` variable for changing the slide text
    in XeTeX and LuaTeX (Andrew Dunning, #131).
    + LaTeX:  Add `mainfontoptions`, `sansfontoptions`,
    `monofontoptions`, `mathfontoptions`, `fontfamilyoptions`
    (Andrew Dunning, #122).  Support handling of bidirectional
    text (mb21, #120). Improve reliability of superscripts/subscripts
    under XeTeX and prevent letters and numbers from appearing on a
    different baseline by removing use of the `realscripts` package
    (via `xltxtra`).  To restore use of OpenType characters for these
    features under XeTeX or LuaTeX, add `\usepackage{realscripts}` to
    `header-includes` (Andrew Dunning, #130).  Remove redundant
    reference to `xunicode` (Andrew Dunning, #130).  Add `fontenc`,
    `indent`, `subparagraph` variables (Andrew Dunning).
    Allow use of `hidelinks` variable for `hyperref` package (Hugo Roy,
    [#113]).  Prevent package clash with `tufte-latex` and other classes that
    include `hyperref` or `color` (Xavier Olive, #115).
    + ConTeXt:  Support handling of bidirectional text (mb21, #120).
    + LaTeX and ConTeXt: Use more specific language variables.
    Instead of directly using `lang`, we now use `babel-lang` and
    `polyglossia-lang` and `context-lang`.  These variables are set by
    the writers to the necessary values, based on the `lang` variable
    (which now always takes a value in BCP47 format). (mb21, #114, #129).
    + HTML:  Support handling of bidirectional text (mb21, #120).
    Move HTML5 shiv after CSS and fix URL (Andrew Dunning).
    Add dir attribute in html5 (Andrew Dunning).
    + reveal.js: Add `controls`, `progress` variables (Grégoire Pineau, #127).
    Add `width`, `height` variables (Anrew Dunning).  Update template
    from 3.1 source (Andrew Dunning).  All configuration options are now
    available as variables, but are only be included if set (reveal.js
    uses defaults otherwise).
    + man: Added comment stating that the page is autogenerated by pandoc,
    giving version.  Added `adjusting` and `hyphenate` variables
    (Alex Vong, #123).
  * epub.css: added selectors for nested emphasis (Pablo Rodriguez).
  * MediaBag:  ensure that `/` is always used as path separator.
  * `sample.lua`: define `CaptionedImage`, add newline at end (#2393).
  * Added `--bash-completion` option.  This generates a bash completion
    script.  To use: `eval "$(pandoc --bash-completion)"`.
  * Text.Pandoc.Error: Define Typeable and Exception instances
    for PandocError (#2386).
  * Text.Pandoc.Parsing: `toKey`: strip off outer brackets.
    This makes keys with extra space at the beginning and end
    work:  e.g.
    [foo]: bar
    [ foo ]
    will now be a link to bar (it wasn't before).
  * Text.Pandoc: disable `auto_identifiers` for epub.
    The epub writer inserts its own auto identifiers;
    this is more complex due to splitting into "chapter" files.
  * Renamed Text.Pandoc.Compat.Locale -> Text.Pandoc.Compat.Time.
    It now reexports Data.Time.
  * Use custom Prelude to avoid compiler warnings.
    + The (non-exported) prelude is in prelude/Prelude.hs.
    + It exports Monoid and Applicative, like base 4.8 prelude,
    but works with older base versions.
    + It exports (<>) for mappend.
    + It hides 'catch' on older base versions.
  * Added a `stack.ymal` and stack install instructions to INSTALL.
  * Clarified what is "out of scope" in README and CONTRIBUTING.md.
  * Added note to CONTRIBUTING.md about ghc versions and travis.
  * Clarify docs on block quotes.  The space after `>` is optional (#2346).
  * Removed obsolete reference to default.csl (#2372).
  * List all styles in manual for `--reference-docx` (Chris Black)
  * Don't capitalize header links in man page.
  * Added section on repl to CONTRIBUTING.md.
  * README:  Added space after backslash in image example (#2329).
  * Document details of citation locator terms (Nick Bart).
  * Fixed some internal links in README (#2309).
  * Improve CSL documentation, variables documentations,
    links, and cross-references in README. (Andrew Dunning)
  * Fix build failure with `--flags=-https` (Sergei Trofimovich).
  * Use `newManager` instead of `withManager` in recent `http-client`.
    This avoids a deprecation warning.
  * Allow building with latest versions of http-types,
    HUnit, criterion, syb, aeson.
  * Setup.hs: rewrite so as not to use process, directory, filepath.
    Using anything outside base is dangerous, since older
    versions of ghc may link against two different versions.
* Tue Jul 28 2015 mimi.vx@gmail.com
- update to 1.15.0.6
- removed man.patch , pandoc.1.gz and pandoc_markdown.5.gz
  * `--self-contained`:  Fixed overaggressive CSS minimization (#2301, 2286).
    Previously `--self-contained` wiped out all spaces in CSS,
    including semantically significant spaces.  This was a regression
    from 1.14.x.
  * Markdown reader: don't allow bare URI links or autolinks in link
    label (#2300).  Added test cases.
  * `Text.Pandoc.Parsing`, `uri`: Improved bare autolink detection (#2299).
    Previously we disallowed `-` at the end of an autolink,
    and disallowed the combination `=-`.  This commit liberalizes the
    rules for allowing punctuation in a bare URI, and adds test cases.
    One potential drawback is that you can no longer put a bare
    URI in em dashes like this:
    `this uri---http://example.com---is an example.`
    But in this respect we now match github's treatment of bare URIs.
  * HTML writer:  support speaker notes in dzslides.
    With this change `<div class="notes">` and also `<div class="notes"
    role="note">` will be output if `-t dzslides` is used. So we can
    have speaker notes in dzslides too.  Thanks to maybegeek.
  * Updated dzslides template.
  * Improved documentation of options to print system default files (#2298).
    `--print-default-data-file` and `--print-default-template`.
  * DokuWiki writer: use `$..$` for Math instead of `<math>..</math>`
    (Tiziano Müller).  MathJax seems currently to be the only maintained
    math rendering extension for DokuWiki.
  * `Text.Pandoc.Shared`: Changed `hierarchicalize` so it treats references
    div as top-level header (#2294).  This fixes a bug with `--section-divs`,
    where the final references section added by pandoc-citeproc, enclosed in
    its own div, got nested in the div for the section previous to it.
  * Allow vector 0.11.
  * Require cmark > 0.4.
  * HTML writer: Fixed email javascript obfuscation with `mailto:`
    URLs (#2280).  This fixes a potential security issue.  Because
    single quotes weren't being escaped in the link portion, a
    specially crafted email address could allow javascript code injection.
  * Markdown/HTML readers:  Avoid parsing partial URLs like
    `<www.pandoc.org/blah#foo>` as HTML tags (#2277).
  * RST reader:  allow inline formatting in definition list field
    names (Lars-Dominik Braun).
  * PDF:  Make sure `--latex-engine-opt` goes before the filename
    on the command line.  LaTeX needs the argument to come after
    the options (#1779).
  * CommonMark writer: fixed tags used for super/subscript.
  * ConTeXt template:  activate hanging indent for definition lists
    (mb21).
  * Make cabal require `hsb2hs` >= 0.3.1 if `embed_data_files` specified.
    This is done by adding `hookedPrograms` in `Setup.hs`, which allows us
    to include `hsb2hs` in Build-Tools in cabal.
    + Admin privileges are no longer required for a per-user install
  * Travis:  unpack sdist for build to catch packaging bugs.
  * Improved documentation on where user templates go (#2272).
  * Added pandoc.1 man page to the repository.  It is no longer
    built as part of the cabal build process. (This proved too
    fragile.)  pandoc.1 can be regenerated (`make man/pandoc.1`)
    when `README` is changed.
  * Copying of the man page now respects `--destdir` (#2262).
  * Improved error messages for filters.  User is now informed if
    the filter requires an interpreter that isn't found in the path,
    or if the filter returns an error status.
  * Ensure target directory is created when installing man page.
  * Added files needed for building man page to Extra-Source-Files.
  * Man page is now built and installed as part of the cabal build
    process. Removed Makefile target for man page.
  * Man page changes:
    + Removed `--man1`, `--man5` options (breaking change).
    + Removed `Text.Pandoc.ManPages` module (breaking API change).
    + Makefile target for `man/man1/pandoc.1`.  This uses pandoc to
    create the man page from README using a custom template and filters.
    + Added `man/` directory with template and filters needed to build
    man page.
    + We no longer have two man pages: `pandoc.1` and `pandoc_markdown.5`.
    Now there is just pandoc.1, which has all the content from README.
    This change was needed because of the extensive cross-references
    between parts of the README.
    + Removed old `data/pandoc.1.template` and
    `data/pandoc_markdown.5.template`.
  * OpenDocument writer: Do not add a carriage return after a hard
    line break (Michael Chladek).
  * ConTeXt writer:
    + use `\goto` for internal links.
    + Added a `%%` at end for `\reference` to avoid spurious space.
  * Ignore sandbox on 'make quick'
  * Added new unexported module:  `Text.Pandoc.ManPages`.
  * `README` now acts like a data file (even though it isn't in
    `data/`).  So, for example, `pandoc --print-default-data-file README`
    will produce the README.)  This change was required for the `--man1`
    and `--man5` options, since the man pages are produced from the
    README, but it may be useful for other purposes as well.
  * Allow `reference.docx` and `reference.odt` to be used with
    `--print-default-data-file` and to shadow defaults if placed in
    the user data directory.  Note that as of 1.14, we no longer
    include these files as data files; instead, we include their
    components.  This change causes pandoc to behave as if it has
    these data files; they are constructed on demand when needed
    using `getDefaultReferenceDocx` and `getDefaultReferenceODT`.
  * Fixed regression in CSS parsing with `--self-contained` (#2224).
    Pandoc 1.14.0.x used css-text to parse the CSS, but its parser
    silently drops big sections of CSS.  This commit replaces the
    use of css-text with a small but principled CSS preprocessor,
    which removes whitespace and comments and replaces `url()` with
    base 64 data when possible.
  * Use `https://` instead of `//` for MathJax and KaTeX CDN URLs (#1920).
    This will allow math to work when pages are being viewed locally.
  * `Text.Pandoc.Options`:  Export `plainExtensions`.
    These are the extensions used in `plain` output.
  * LaTeX reader: Don't parse `_` and `^` as sub/superscript outside of
    math mode; treat them as regular inline text.  Normally these will
    cause an error in LaTeX, but there are contexts (e.g. `alltt`
    environments) where they are allowed.
  * HTML reader:  allow `<body>` to close `<head>`.
  * DocBook reader: support `mediaobject`s and `figures` (#2184, mb21).
  * RST reader: Fix reference names with special characters
    (Lars-Dominik Braun).
  * Textile writer:  escape `+` and `-` as entities (#2225).
  * DokuWiki writer: Use proper `<code>` tags for code blocks (#2213).
  * Plain writer:  don't use symbols for super/subscript (#2237).
    Simplified code by using `plainExtensions`.
  * InDesign writer: Properly escape URLs containing more than one
    colon character (gohai).
  * Docx writer: Make sure we use dist version of `reference.docx`
    (and not the user's version) for certain settings.  Taking some
    settings values from a user-supplied reference.docx can lead to
    corruption.  This fixes a regression from the last release (#2249).
  * `Text.Pandoc.Shared`: exports `getDefaultReferenceDocx` and
    `getDefaultReferenceODT` (API change).  These functions have been
    removed from the Docx and ODT writers.
  * LaTeX template (Xavier Olive):
    + Added `CJKmainfont` and `CJKoptions` variables.
    + Allow dvipsnames (e.g. `MidnightBlue`) for colors (Xavier Olive).
  * Epub templates:  use `author.role`, not `author.type`.
  * Bump cmark version to >= 0.3.4.
  * Improved Windows installer (#2205, thanks to nkalvi).
    Users can now select a per-user or systemwide install, and can set
    the installation path.  At the end of installation, the install location
    is given.  The install location is also now given in the list of
    installed programs in Control Panel.  Cleaner WiX syntax is used for
    setting the path.
  * Added `download_stats` target to Makefile.
* Thu Jun  4 2015 mimi.vx@gmail.com
- update to 1.14.0.4
  * Added missing commonmark template.
* Tue Jun  2 2015 mimi.vx@gmail.com
- update to 1.14.0.3
  * Allow compilation with syb 0.5.*.
  * Custom writer: fixed some compiler warnings for ghc < 7.10.
* Tue Jun  2 2015 mimi.vx@gmail.com
- reworked man patch
* Sun May 31 2015 mimi.vx@gmail.com
- update to 1.14.0.2
- man.patch to remove generating of man pages
  * for changes please see upstream 'changelog' file
* Thu May 14 2015 mimi.vx@gmail.com
- disable old-locale support
* Sun Apr 26 2015 mimi.vx@gmail.com
- correct ghc-http-client-tls dep
* Fri Apr 24 2015 mimi.vx@gmail.com
- update to 1.13.2.1
  pandoc (1.13.2)
  ===============
  * TWiki Reader: add new new twiki reader (API chaneg, Alexander Sulfrian).
  * Markdown reader:
    + Better handling of paragraph in div (#1591).
    Previously text that ended a div would be parsed as Plain
    unless there was a blank line before the closing div tag.
    + Don't treat a citation as a reference link label (#1763).
    + Fix autolinks with following punctuation (#1811).
    The price of this is that autolinked bare URIs can no longer
    contain `>` characters, but this is not a big issue.
    + Fix `Ext_lists_without_preceding_blankline` bug (#1636, Artyom).
    + Allow `startnum` to work without `fancy_lists`. Formerly
    `pandoc -f markdown-fancy_lists+startnum` did not work properly.
  * RST reader (all Daniel Bergey):
    + Parse quoted literal blocks (#65).  RST quoted literal blocks are
    the same as indented literal blocks (which pandoc already supports)
    except that the quote character is preserved in each line.
    + Parse RST class directives. The class directive accepts one or more
    class names, and creates a Div value with those classes.  If the
    directive has an indented body, the body is parsed as the children of
    the Div.  If not, the first block folowing the directive is made a
    child of the Div. This differs from the behavior of rst2xml, which
    does not create a Div element.  Instead, the specified classes are
    applied to each child of the directive.  However, most Pandoc Block
    constructors to not take an Attr argument, so we can't duplicate this
    behavior.
    + Warn about skipped directives.
    + Literal role now produces Code. Code role should have "code" class.
    + Improved support for custom roles
  - Added `sourceCode` to classes for `:code:` role, and anything
    inheriting from it.
  - Add the name of the custom role to classes if the Inline
    constructor supports Attr.
  - If the custom role directive does not specify a parent role,
    inherit from the `:span:` role.
    This differs somewhat from the `rst2xml.py` behavior.  If a custom
    role inherits from another custom role, Pandoc will attach both
    roles' names as classes.  `rst2xml.py` will only use the class of
    the directly invoked role (though in the case of inheriting from a
    `:code:` role with a `:language:` defined, it will also provide the
    inherited language as a class).
    + Warn about ignored fields in role directives.
  * LaTeX reader:
    + Parse label after caption into a span instead of
    inserting an additional paragraph of bracketed text (#1747).
    + Parse math environments as inline when possible (#1821).
    + Better handling of `\noindent` and `\greektext` (#1783).
    + Handle `\texorpdfstring` more gracefully.
    + Handle `\cref` and `\sep` (Wikiwide).
    + Support `\smartcite` and `\Smartcite` from biblatex.
  * HTML reader:
    + Retain display type of MathML output (#1719, Matthew Pickering).
    + Recognise `<br>` tags inside `<pre>` blocks (#1620, Matthew Pickering).
    + Make `embed` tag either block or inline (#1756).
  * DocBook reader:
    + Handle `keycombo`, `keycap` (#1815).
    + Get string content in inner tags for literal elements (#1816).
    + Handle `menuchoice` elements better, with a `>` between (#1817).
    + Include `id` on section headers (#1818).
    + Document/test "type" as implemented (Brian O'Sullivan).
    + Add support for calloutlist and callout (Brian O'Sullivan).
    We treat a calloutlist as a bulleted list. This works well in practice.
    + Add support for `classname` (Bryan O'Sullivan).
  * Docx reader:
    + Fix window path for image lookup (Jesse Rosenthal).
    Don't use os-sensitive "combine", since we always want the paths in our
    zip-archive to use forward-slashes.
    + Single-item headers in ordered lists are headers (Jesse Rosenthal).
    When users number their headers, Word understands that as a single item
    enumerated list. We make the assumption that such a list is, in fact,
    a header.
    + Rewrite rewriteLink to work with new headers (Jesse Rosenthal).
    There could be new top-level headers after making lists, so we have to
    rewrite links after that.
    + Use polyglot header list (Jesse Rosenthal).
    We're just keeping a list of header formats that different languages
    use as their default styles. At the moment, we have English, German,
    Danish, and French. We can continue to add to this.
    This is simpler than parsing the styles file, and perhaps less
    error-prone, since there seems to be some variations, even within a
    language, of how a style file will define headers.
    + Remove header class properly in other langs (Jesse Rosenthal).
    When we encounter one of the polyglot header styles, we want to remove
    that from the par styles after we convert to a header. To do that, we
    have to keep track of the style name, and remove it appropriately.
    + Account for external link URLs with anchors. Previously, if a URL
    had an anchor, the reader would incorrectly identify it as an
    internal link and return only the anchor as URL. (Caleb McDaniel)
    + Fix for Issue #1692 (i18n styles) (Nikolay Yakimov).
  * Org reader:
    + Added state changing blanklines (Jesse Rosenthal).
    This allows us to emphasize at the beginning of a new paragraph (or, in
    general, after blank lines).
    + Fixed bug with bulleted lists:
  - a
  - b
  * c
    was being parsed as a list, even though an unindented `*`
    should make a heading.  See
    <http://orgmode.org/manual/Plain-lists.html#fn-1>.
    + Org reader: absolute, relative paths in link (#1741, Albert
    Krewinkel). The org reader was too restrictive when parsing links;
    some relative links and links to files given as absolute paths
    were not recognized correctly.
    + Org reader:  allow empty links (jgm/gitit#471, Albert Krewinkel).
    This is important for use in gitit, which uses empty links
    for wikilinks.
    + Respect indent when parsing Org bullet lists (#1650, Timothy
    Humphries).  Fixes issue with top-level bullet list parsing.
    + Fix indent issue for definition lists (Timothy Humphries,
    see #1650, #1698, #1680).
    + Parse multi-inline terms correctly in definition list (#1649,
    Matthew Pickering).
    + Fix rules for emphasis recognition (Albert Krewinkel).
    Things like `/hello,/` or `/hi'/` were falsy recognized as emphasised
    strings.  This is wrong, as `,` and `'` are forbidden border chars and
    may not occur on the inner border of emphasized text.
    + Drop COMMENT document trees (Albert Krewinkel).
    Document trees under a header starting with the word `COMMENT` are
    comment trees and should not be exported.  Those trees are dropped
    silently (#1678).
    + Properly handle links to `file:target` (Albert Krewinkel).
    Org links like `[[file:target][title]]` were not handled correctly,
    parsing the link target verbatim.  The org reader is changed such that
    the leading `file:` is dropped from the link target (see #756, #1812).
    + Parse LaTeX-style MathML entities (#1657, Albert Krewinkel).
    Org supports special symbols which can be included using LaTeX syntax,
    but are actually MathML entities.  Examples for this are
    `\nbsp` (non-breaking space), `\Aacute` (the letter A with accent acute)
    or `\copy` (the copyright sign ©)
  * EPUB reader:
    + URI handling improvements. Now we outsource most of the work to
    `fetchItem'`. Also, do not include queries in file extensions (#1671).
  * LaTeX writer:
    + Use `\texorpdfstring` for section captions when needed (Vaclav Zeman).
    + Handle consecutive linebreaks (#1733).
    + Protect graphics in headers (Jesse Rosenthal).
    Graphics in `\section`/`\subsection` etc titles need to be `\protect`ed.
    + Put `~` before header in list item text (Jesse Rosenthal).
    Because of the built-in line skip, LaTeX can't handle a section header
    as the first element in a list item.
    + Avoid using reserved characters as `\lstinline` delimiters (#1595).
    + Better handling of display math in simple tables (#1754).
    We convert display math to inline math in simple tables,
    since LaTeX can't deal with display math in simple tables.
    + Escape spaces in code (#1694, Bjorn Buckwalter).
  * MediaWiki writer:
    + Fixed links with URL = text. Previously these were rendered as bare
    words, even if the URL was not an absolute URL (#1825).
  * ICML writer:
    + Don't force all citations into footnotes.
  * RTF writer:
    + Add blankline at end of output (#1732, Matthew Pickering).
  * RST writer:
    + Ensure blank line after figure.
    + Avoid exces whitespace after last list item (#1777).
    + Wrap line blocks with spaces before continuations (#1656).
    + Fixed double-rendering of footnotes in RST tables (#1769).
  * DokuWiki writer:
    + Better handling of block quotes. This change ensures that
    multiple paragraph blockquotes are rendered using native `>`
    rather than as HTML (#1738).
    + Fix external images (#1739). Preface relative links with ":",
    absolute URIs without. (Timothy Humphries)
  * HTML writer:
    + Use protocol-relative URL for mathjax.
    + Put newline btw img and caption paragraph.
    + MathML now outputted with tex annotation (#1635, Matthew Pickering).
    + Add support for KaTeX HTML math (#1626, Matthew Pickering).
    This adds `KaTeX` to `HTMLMathMethod` (API change).
    + Don't double render when `email-obfuscation=none` (#1625, Matthew
    Pickering).
    + Make header attributes work outside top level (#1711).
    Previously they only appeared on top level header elements.
    Now they work e.g. in blockquotes.
  * ODT writer:
    + Correctly handle images without extensions (#1729).
    + Strip querystring in ODT write (#1682, Todd Sifleet).
  * FB2 writer:
    + Add newline to output.
  * EPUB writer:
    + Don't add `sourceURL` to absolute URIs (#1669).
    + Don't use unsupported `opf:title-type` for epub2.
    + Include "landmarks" section in nav document for epub3 (#1757).
    + Removed playOrder from navpoint elements in ncx file (#1760).
    These aren't required, and they make manual modification of epubs
    difficult.
    + Extract title even from structured title.
    + Don't include nav node in spine unless `--toc` was requested.
    Previously we included it in the spine with `linear="no"`, leading
    to odd results in some readers (#1593).
    + Fixed absolute URI detection (#1672).
    + Correctly resolve relative URIs (#1671).
    + Use regular page template for `nav.xhtml`, including doctype (#1759).
  * Docx writer:
    + Put docx table captions above tables (#1641, Nikolay Yakimov).
    + Get the page width from the reference docx file, and use
    it to scale images that are too large to fit (Grégory Bataille).
    + Partial fix for #1607 (Nikolay Yakimov). International heading styles
    are inferred based on `<w:name val="heading #">` fallback, if there
    are no en-US "Heading#" styles
    + Look in user data dir for archive `reference.docx`.
    + Renumber header and footer relationships to avoid collisions (Jesse
    Rosenthal). We previously took the old relationship names of the
    headers and footer in secptr. That led to collisions. We now make
    a map of availabl names in the relationships file, and then rename
    in secptr.
  * ConTeXt writer:
    + Add function toLabel (Mark Szepieniec).
    This function can be used to sanitize reference labels so that
    they do not contain any of the illegal characters \#[]",{}%%()|= .
    Currently only Links have their labels sanitized, because they
    are the only Elements that use passed labels.
  * `Text.Pandoc.Shared`:
    + Moved import of `toChunks` outside of CPP conditional (#1590).
    + Fix `inDirectory` to reset to the original directory in case
    an exception occurs (Freiric Barral).
  * Templates:
    + LaTeX template: load polyglossia before bibtex (jgm/pandoc-templates#70).
    Thanks to bluebirch.
    + LaTeX template: Added `\VerbatimFootnotes` if there is verbatim in notes
    (#1616).
    + LaTeX template:  Add shorthands=off to babel options (#1648).
    + EPUB, EPUB3 templates: Added `id="cover"` to body of cover page.
    This aids styling, making it possible for example to set 0 margins
    on the title page (#1758).
    + EPUB, EPUB3 templates:  Handle structured metadata on titlepage.
    Previously we just expected 'title', 'subtitle', 'author', 'date'.
    Now we still support those, but also support the format recommended
    for epub metadata in the pandoc README:
  - --
    title:
  - type: main
    text: My Book
  - type: subtitle
    text: An investigation of metadata
    creator:
  - role: author
    text: John Smith
  - role: editor
    text: Sarah Jones
    identifier:
  - scheme: DOI
    text: doi:10.234234.234/33
    publisher:  My Press
    rights:  (c) 2007 John Smith, CC BY-NC
    ...
  * `Text.Pandoc.Templates.getDefaultTemplate`:
    don't fail when called with "fb2" (#1660).
  * `Text.Pandoc.Parsing`:
    + Fixed `inlineMath` so it handles `\text{..}` containing `$`.
    For example: `$x = \text{the $n$th root of $y$}` (#1677).
    + Change `parseFromString` to fail if not all input is consumed.
    (Matthew Pickering)
    + Moved `addWarning` from Markdown reader to `Parsing`, so it can be
    used by more readers (API change, Daniel Bergey).
  * `Text.Pandoc.Pretty`:
    +  Improve performance of `realLength` (Matthew Pickering).
    +  Make CR + BLANKLINE = BLANKLINE. This fixes an extra blank line we
    were getting at the end of markdown fragments (as well as rst, org,
    etc.) (#1705).
  * `Text.Pandoc.MIME`:
    + Add mime type for WebVTT (Jason Ronallo).
    + Changed mime type for `otf` to `application/vnd.ms-opentype` (#1761).
    This is needed for epub3 validation.
  * `Text.Pandoc.MediaBag`:
    + Fix Windows specific path problems (#1597).
  * `Text.Pandoc.Shared`:
    + Make `collapseFilePath` OS-agnostic (Matthew Pickering).
  * Link the test suite using `-threaded`.
    This allows the test suite to be run using `+RTS -N`.
  * Added `network` dependency under `network-uri` flag in test section.
  * Give better error messages when someone tries to convert from
    pdf, doc, odt (#1683).
  * Added `track` to list of tags treated by `--self-contained` (#1664).
  pandoc (1.13.1)
  ===============
  * Fixed `--self-contained` with Windows paths (#1558).
    Previously `C:\foo.js` was being wrongly interpreted as a URI.
  * HTML reader:  improved handling of tags that can be block or inline.
    Previously a section like this would be enclosed in a paragraph,
    with RawInline for the video tags (since video is a tag that can
    be either block or inline):
    <video controls="controls">
    <source src="../videos/test.mp4" type="video/mp4" />
    <source src="../videos/test.webm" type="video/webm" />
    <p>
    The videos can not be played back on your system.<br/>
    Try viewing on Youtube (requires Internet connection):
    <a href="http://youtu.be/etE5urBps_w">Relative Velocity on
    Youtube</a>.
    </p>
    </video>
    This change will cause the video and source tags to be parsed
    as RawBlock instead, giving better output.
    The general change is this:  when we're parsing a "plain" sequence
    of inlines, we don't parse anything that COULD be a block-level tag.
  * Docx reader:
    + Be sensitive to user styles.  Note that "Hyperlink" is
    "blacklisted," as we don't want the default underline styling to be
    inherited by all links by default (Jesse Rosenthal).
    + Read single paragraph in table cell as `Plain` (Jesse Rosenthal).
    This makes to docx reader's native output fit with the way the markdown
    reader understands its markdown output.
  * Textile writer:  Extended the range of cases where native textile
    tables will be used (as opposed to raw HTML):  we now handle any
    alignment type, but only for simple tables with no captions.
  * Txt2Tags reader:
    + Header is now parsed only if standalone flag is set (Matthew Pickering).
    + The header is now parsed as meta information. The first line is the
    `title`, the second is the `author` and third line is the `date`
    (Matthew Pickering).
    + Corrected formatting of `%%%%mtime` macro (Matthew Pickering).
    + Fixed crash when reading from stdin.
  * EPUB writer:  Don't use page-progression-direction in EPUB2, which
    doesn't support it.  Also, if page-progression-direction not specified
    in metadata, don't include the attribute even in EPUB3; not including it
    is the same as including it with the value "default", as we did before.
    (#1550)
  * Org writer: Accept example lines with indentation at the beginning
    (Calvin Beck).
  * DokuWiki writer:
    + Refactor to use Reader monad (Matthew Pickering).
    + Avoid using raw HTML in table cells; instead, use `\\`
    instead of newlines (Jesse Rosenthal).
    + Properly handle HTML table cell alignments, and use spacing
    to make the tables look prettier (#1566).
  * Docx writer:
    + Bibliography entries get `Bibliography` style (#1559).
    + Implement change tracking (Jesse Rosenthal).
  * LaTeX writer:
    + Fixed a bug that caused a table caption to repeat across all pages
    (Jose Luis Duran).
    + Improved vertical spacing in tables and made it customizable using
    standard lengths set by booktab.  See
    <https://groups.google.com/forum/#!msg/pandoc-discuss/qMu6_5lYy0o/ZAU7lzAIKw0J>
    (Jose Luis Duran).
    + Added `\strut` to fix spacing in multiline tables (Jose Luis Duran).
    + Use `\tabularnewline` instead of `\\` in table cells (Jose Luis Duran).
    + Made horizontal rules more flexible (Jose Luis Duran).
  * Text.Pandoc.MIME:
    + Added `MimeType` (type synonym for `String`) and `getMimeTypeDef`.
    Code cleanups (Artyom Kazak).
  * Templates:
    + LaTeX template: disable microtype protrusion for typewriter font (#1549,
    thanks lemzwerg).
  * Improved OSX build procedure.
  * Added `network-uri` flag, to deal with split of `network-uri` from
    `network`.
  * Fix build dependencies for the `trypandoc` flag, so that they are
    ignored if `trypandoc` flag is set to False (Gabor Pali).
  * Updated README to remove outdated claim that `--self-contained`
    looks in the user data directory for missing files.
  pandoc (1.13.0.1)
  =================
  * Docx writer:
    + Fixed regression which bungled list numbering (#1544), causing
    all lists to appear as basic ordered lists.
    + Include row width in table rows (Christoffer Ackelman, Viktor Kronvall).
    Added a property to all table rows where the sum of column widths
    is specified in pct (fraction of 5000).  This helps persuade Word
    to lay out the table with the widths we specify.
  * Fixed a bug in Windows 8 which caused pandoc not to find the
    `pandoc-citeproc` filter (#1542).
  * Docx reader: miscellaneous under-the-hood improvements (Jesse Rosenthal).
    Most significantly, the reader now uses Builder, leading to some
    performance improvements.
  * HTML reader:  Parse appropriately styled span as SmallCaps.
  * Markdown writer: don't escape `$`, `^`, `~` when `tex_math_dollars`,
    `superscript`, and `subscript` extensions, respectively, are
    deactivated (#1127).
  * Added `trypandoc` flag to build CGI executable used in the online
    demo.
  * Makefile:  Added 'quick', 'osxpkg' targets.
  * Updated README in templates to indicate templates license.
    The templates are dual-licensed, BSD3 and GPL2+.
  pandoc (1.13)
  =============
  * Added `docx` as an input format (Jesse Rosenthal).  The docx
    reader includes conversion of native Word equations to pandoc
    LaTeX `Math` elements.  Metadata is taken from paragraphs at the
    beginning of the document with styles `Author`, `Title`, `Subtitle`,
    `Date`, and `Abstract`.
  * Added `epub` as an input format (Matthew Pickering).  The epub
    reader includes conversion of MathML to pandoc LaTeX `Math`
    elements.
  * Added `t2t` (Txt2Tags) as an input format (Matthew Pickering).
    Txt2tags is a lightweight markup format described at
    <http://txt2tags.org/>.
  * Added `dokuwiki` as an output format (Clare Macrae).
  * Added `haddock` as an output format.
  * Added `--extract-media` option to extract media contained in a zip
    container (docx or epub) while adjusting image paths to point to the
    extracted images.
  * Added a new markdown extension, `compact_definition_lists`, that
    restores the syntax for definition lists of pandoc 1.12.x, allowing
    tight definition lists with no blank space between items, and
    disallowing lazy wrapping.  (See below under behavior changes.)
  * Added an extension `epub_html_exts` for parsing HTML in EPUBs.
  * Added extensions `native_spans` and `native_divs` to activate
    parsing of material in HTML span or div tags as Pandoc Span
    inlines or Div blocks.
  * `--trace` now works with the Markdown, HTML, Haddock, EPUB,
    Textile, and MediaWiki readers.  This is an option intended
    for debugging parsing problems; ordinary users should not need
    to use it.
  [behavior changes]
  * Changed behavior of the `markdown_attribute` extension, to bring
    it in line with PHP markdown extra and multimarkdown.  Setting
    `markdown="1"` on an outer tag affects all contained tags,
    recursively, until it is reversed with `markdown="0"` (#1378).
  * Revised markdown definition list syntax (#1429).  Both the reader
    and writer are affected.  This change brings pandoc's definition list
    syntax into alignment with that used in PHP markdown extra and
    multimarkdown (with the exception that pandoc is more flexible about
    the definition markers, allowing tildes as well as colons).  Lazily
    wrapped definitions are now allowed.  Blank space is required
    between list items.  The space before a definition is used to determine
    whether it is a paragraph or a "plain" element.  **WARNING: This change
    may break existing documents!**  Either check your documents for
    definition lists without blank space between items, or use
    `markdown+compact_definition_lists` for the old behavior.
  * `.numberLines` now works in fenced code blocks even if no language
    is given (#1287, jgm/highlighting-kate#40).
  * Improvements to `--filter`:
    + Don't search PATH for a filter with an explicit path.
    This fixed a bug wherein `--filter ./caps.py` would run `caps.py` from
    the system path, even if there was a `caps.py` in the working directory.
    + Respect shebang if filter is executable (#1389).
    + Don't print misleading error message.
    Previously pandoc would say that a filter was not found,
    even in a case where the filter had a syntax error.
  * HTML reader:
    + Parse `div` and `span` elements even without `--parse-raw`,
    provided `native_divs` and `native_spans` extensions are set.
    Motivation:  these now generate native pandoc Div and Span
    elements, not raw HTML.
    + Parse EPUB-specific elements if the `epub_html_exts`
    extension is enabled.  These include `switch`, `footnote`,
    `rearnote`, `noteref`.
  * Org reader:
    + Support for inline LaTeX.  Inline LaTeX is now accepted and parsed by the
    org-mode reader.  Both math symbols (like `\tau`) and LaTeX commands (like
    `\cite{Coffee}`), can be used without any further escaping (Albert
    Krewinkel).
  * Textile reader and writer:
    + The `raw_tex` extension is no longer set by default.  You can
    enable it with `textile+raw_tex`.
  * DocBook reader:
    + Support `equation`, `informalequation`, `inlineequation` elements with
    `mml:math` content.  This is converted into LaTeX and put into a Pandoc
    Math inline.
  * Revised `plain` output, largely following the style of Project
    Gutenberg:
    + Emphasis is rendered with `_underscores_`, strong emphasis
    with ALL CAPS.
    + Headings are rendered differently, with space to set them off,
    not with setext style underlines. Level 1 headers are ALL CAPS.
    + Math is rendered using unicode when possible, but without the
    distracting emphasis markers around variables.
    + Footnotes use a regular `[n]` style.
  * Markdown writer:
    + Horizontal rules are now a line across the whole page.
    + Prettier pipe tables.  Columns are now aligned  (#1323).
    + Respect the `raw_html` extension.  `pandoc -t markdown-raw_html`
    no longer emits any raw HTML, including span and div tags
    generated by Span and Div elements.
    + Use span with style for `SmallCaps` (#1360).
  * HTML writer:
    + Autolinks now have class `uri`, and email autolinks have class
    `email`, so they can be styled.
  * Docx writer:
    + Document formatting is carried over from `reference.docx`.
    This includes margins, page size, page orientation, header,
    and footer, including images in headers and footers.
    + Include abstract (if present) with `Abstract` style (#1451).
    + Include subtitle (if present) with `Subtitle` style, rather
    than tacking it on to the title (#1451).
  * Org writer:
    + Write empty span elements with an id attribute as org anchors.
    For example `Span ("uid",[],[]) []` becomes `<<uid>>`.
  * LaTeX writer:
    + Put table captions above tables, to match the conventional
    standard.  (Previously they appeared below tables.)
    + Use `\(..\)` instead of `$..$` for inline math (#1464).
    + Use `\nolinkurl` in email autolinks.  This allows them to be styled
    using `\urlstyle{tt}`.  Thanks to Ulrike Fischer for the solution.
    + Use `\textquotesingle` for `'` in inline code.  Otherwise we get
    curly quotes in the PDF output (#1364).
    + Use `\footnote<.>{..}` for notes in beamer, so that footnotes
    do not appear before the overlays in which their markers appear
    (#1525).
    + Don't produce a `\label{..}` for a Div or Span element.  Do produce
    a `\hyperdef{..}` (#1519).
  * EPUB writer:
    + If the metadata includes `page-progression-direction` (which can be
    `ltr` or `rtl`, the `page-progression-direction` attribute will
    be set in the EPUB spine (#1455).
  * Custom lua writers:
    + Custom writers now work with `--template`.
    + Removed HTML header scaffolding from `sample.lua`.
    + Made citation information available in lua writers.
  * `--normalize` and `Text.Pandoc.Shared.normalize` now consolidate
    adjacent `RawBlock`s when possible.
  [API changes]
  * Added `Text.Pandoc.Readers.Docx`, exporting `readDocx` (Jesse Rosenthal).
  * Added `Text.Pandoc.Readers.EPUB`, exporting `readEPUB` (Matthew
    Pickering).
  * Added `Text.Pandoc.Readers.Txt2Tags`, exporting `readTxt2Tags` (Matthew
    Pickering).
  * Added `Text.Pandoc.Writers.DokuWiki`, exporting `writeDokuWiki`
    (Clare Macrae).
  * Added `Text.Pandoc.Writers.Haddock`, exporting `writeHaddock`.
  * Added `Text.Pandoc.MediaBag`, exporting `MediaBag`, `lookupMedia`,
    `insertMedia`, `mediaDirectory`, `extractMediaBag`.  The docx and epub
    readers return a pair of a `Pandoc` document and a `MediaBag` with
    the media resources they contain.  This can be extracted using
    `--extract-media`.  Writers that incorporate media (PDF, Docx,
    ODT, EPUB, RTF, or HTML formats with `--self-contained`) will look
    for resources in the `MediaBag` generated by the reader, in addition to
    the file system or web.
  * `Text.Pandoc.Readers.TexMath`: Removed deprecated `readTeXMath`.
    Renamed `readTeXMath'` to `texMathToInlines`.
  * `Text.Pandoc`: Added `Reader` data type (Matthew Pickering).
    `readers` now associates names of readers with `Reader`
    structures.  This allows inclusion of readers, like the docx
    reader, that take binary rather than textual input.
  * `Text.Pandoc.Shared`:
    + Added `capitalize` (Artyom Kazak), and replaced uses of
    `map toUpper` (which give bad results for many languages).
    + Added `collapseFilePath`, which removes intermediate `.` and
    `..` from a path (Matthew Pickering).
    + Added `fetchItem'`, which works like `fetchItem` but searches
    a `MediaBag` before looking on the net or file system.
    + Added `withTempDir`.
    + Added `removeFormatting`.
    + Added `extractSpaces` (from HTML reader) and generalized its type
    so that it can be used by the docx reader (Matthew Pickering).
    + Added `ordNub`.
    + Added `normalizeInlines`, `normalizeBlocks`.
    + `normalize` is now `Pandoc -> Pandoc` instead of
    `Data a :: a -> a`.  Some users may need to change their uses of
    `normalize` to the newly exported `normalizeInlines` or
    `normalizeBlocks`.
  * `Text.Pandoc.Options`:
    + Added `writerMediaBag` to `WriterOptions`.
    + Removed deprecated and no longer used `readerStrict` in
    `ReaderOptions`.  This is handled by `readerExtensions` now.
    + Added `Ext_compact_definition_lists`.
    + Added `Ext_epub_html_exts`.
    + Added `Ext_native_divs` and `Ext_native_spans`.
    This allows users to turn off the default pandoc behavior of
    parsing contents of div and span tags in markdown and HTML
    as native pandoc Div blocks and Span inlines.
  * `Text.Pandoc.Parsing`:
    + Generalized `readWith` to `readWithM` (Matthew Pickering).
    + Export `runParserT` and `Stream` (Matthew Pickering).
    + Added `HasQuoteContext` type class (Matthew Pickering).
    + Generalized types of `mathInline`, `smartPunctuation`, `quoted`,
    `singleQuoted`, `doubleQuoted`, `failIfInQuoteContext`,
    `applyMacros` (Matthew Pickering).
    + Added custom `token` (Matthew Pickering).
    + Added `stateInHtmlBlock` to `ParserState`.  This is used to keep
    track of the ending tag we're waiting for when we're parsing inside
    HTML block tags.
    + Added `stateMarkdownAttribute` to `ParserState`. This is used
    to keep track of whether the markdown attribute has been set in
    an enclosing tag.
    + Generalized type of `registerHeader`, using new type classes
    `HasReaderOptions`, `HasIdentifierList`, `HasHeaderMap` (Matthew
    Pickering).  These allow certain common functions to be reused
    even in parsers that use custom state (instead of `ParserState`),
    such as the MediaWiki reader.
    + Moved `inlineMath`, `displayMath` from Markdown reader to Parsing,
    and generalized their types (Matthew Pickering).
  * `Text.Pandoc.Pretty`:
    + Added `nestle`.
    + Added `blanklines`, which guarantees a certain number of blank lines
    (and no more).
  [bug fixes]
  * Markdown reader:
    + Fixed parsing of indented code in list items.  Indented code
    at the beginning of a list item must be indented eight spaces
    from the margin (or edge of the container), or four spaces
    from the list marker, whichever is greater.
    + Fixed small bug in HTML parsing with `markdown_attribute`, which
    caused incorrect tag nesting for input like
    `<aside markdown="1">*hi*</aside>`.
    + Fixed regression with intraword underscores (#1121).
    + Improved parsing of inline links containing quote characters (#1534).
    + Slight rewrite of `enclosure`/`emphOrStrong` code.
    + Revamped raw HTML block parsing in markdown (#1330).
    We no longer include trailing spaces and newlines in the
    raw blocks.  We look for closing tags for elements (but without
    backtracking).  Each block-level tag is its own `RawBlock`;
    we no longer try to consolidate them (though `--normalize` will do so).
    + Combine consecutive latex environments.  This helps when you have
    two minipages which can't have blank lines between them (#690, #1196).
    + Support smallcaps through span.
    `<span style="font-variant:small-caps;">foo</span>` will be
    parsed as a `SmallCaps` inline, and will work in all output
    formats that support small caps (#1360).
    + Prevent spurious line breaks after list items (#1137).  When the
    `hard_line_breaks` option was specified, pandoc would formerly
    produce a spurious line break after a tight list item.
    + Fixed table parsing bug (#1333).
    + Handle `c++` and `objective-c` as language identifiers in
    github-style fenced blocks (#1318).
    + Inline math must have nonspace before final `$` (#1313).
  * LaTeX reader:
    + Handle comments at the end of tables.  This resolves the issue
    illustrated in <http://stackoverflow.com/questions/24009489>.
    + Correctly handle table rows with too few cells.  LaTeX seems to
    treat them as if they have empty cells at the end  (#241).
    + Handle leading/trailing spaces in `\emph` better.
    `\emph{ hi }` gets parsed as `[Space, Emph [Str "hi"], Space]`
    so that we don't get things like `* hi *` in markdown output.
    Also applies to `\textbf` and some other constructions (#1146).
    + Don't assume preamble doesn't contain environments (#1338).
    + Allow (and discard) optional argument for `\caption` (James Aspnes).
  * HTML reader:
    + Fixed major parsing problem with HTML tables.  Table cells were
    being combined into one cell (#1341).
    + Fixed performance issue with malformed HTML tables.
    We let a `</table>` tag close an open `<tr>` or `<td>` (#1167).
    + Allow space between `<col>` and `</col>`.
    + Added `audio` and `source` in `eitherBlockOrInline`.
    + Moved `video`, `svg`, `progress`, `script`, `noscript`, `svg` from
    `blockTags` to `eitherBlockOrInline`.
    + `map` and `object` were mistakenly in both lists; they have been removed
    from `blockTags`.
    + Ignore `DOCTYPE` and `xml` declarations.
  * MediaWiki reader:
    + Don't parse backslash escapes inside `<source>` (#1445).
    + Tightened up template parsing.
    The opening `{{` must be followed by an alphanumeric or `:`.
    This prevents the exponential slowdown in #1033.
    + Support "Bild" for images.
  * DocBook reader:
    + Better handle elements inside code environments.  Pandoc's document
    model does not allow structure inside code blocks, but at least this way
    we preserve the text (#1449).
    + Support `<?asciidoc-br?>` (#1236).
  * Textile reader:
    + Fixed list parsing. Lists can now start without an intervening
    blank line (#1513).
    + HTML block-level tags that do not start a line are parsed as
    inline HTML and do not interrupt paragraphs (as in RedCloth).
  * Org reader:
    + Make tildes create inline code (#1345).  Also relabeled `code` and
    `verbatim` parsers to accord with the org-mode manual.
    + Respect `:exports` header argument in code blocks (Craig Bosma).
    + Fixed tight lists with sublists (#1437).
  * EPUB writer:
    + Avoid excess whitespace in `nav.xhtml`.  This should improve
    TOC view in iBooks (#1392).
    + Fixed regression on cover image.
    In 1.12.4 and 1.12.4.2, the cover image would not appear properly,
    because the metadata id was not correct.  Now we derive the id from the
    actual cover image filename, which we preserve rather than using
    "cover-image."
    + Keep newlines between block elements.  This allows
    easier diff-ability (#1424).
    + Use `stringify` instead of custom `plainify`.
    + Use `renderTags'` for all tag rendering.  This properly handles tags
    that should be self-closing.  Previously `<hr/>` would appear in EPUB
    output as `<hr></hr>` (#1420).
    + Better handle HTML media tags.
    + Handle multiple dates with OPF `event` attributes.  Note: in EPUB3 we
    can have only one dc:date, so only the first one is used.
  * LaTeX writer:
    + Correctly handle figures in notes.  Notes can't contain figures in
    LaTeX, so we fake it to avoid an error  (#1053).
    + Fixed strikeout + highlighted code (#1294).
    Previously strikeout highlighted code caused an error.
  * ConTeXt writer:
    + Improved detection of autolinks with URLs containing escapes.
  * RTF writer:
    + Improved image embedding: `fetchItem'` is now used to get the
    images, and calculated image sizes are indicated in the RTF.
    + Avoid extra paragraph tags in metadata (#1421).
  * HTML writer:
    + Deactivate "incremental" inside slide speaker notes (#1394).
    + Don't include empty items in the table of contents for
    slide shows.  (These would result from creating a slide
    using a horizontal rule.)
  * MediaWiki writer:
    + Minor renaming of `st` prefixed names.
  * AsciiDoc writer:
    + Double up emphasis and strong emphasis markers in intraword
    contexts, as required by asciidoc (#1441).
  * Markdown writer:
    + Avoid wrapping that might start a list, blockquote, or header (#1013).
    + Use Span instead of (hackish) `SmallCaps` in `plainify`.
    + Don't use braced attributes for fenced code (#1416).
    If `Ext_fenced_code_attributes` is not set, the first class
    attribute will be printed after the opening fence as a bare word.
    + Separate adjacent lists of the same kind with an HTML comment (#1458).
  * PDF writer:
    + Fixed treatment of data uris for images (#1062).
  * Docx writer:
    + Use Compact style for empty table cells (#1353).
    Otherwise we get overly tall lines when there are empty
    table cells and the other cells are compact.
    + Create overrides per-image for `media/` in reference docx.
    This should be somewhat more robust and cover more types of images.
    + Improved `entryFromArchive` to avoid an unneeded parse.
    + Section numbering carries over from reference.docx (#1305).
    + Simplified `abstractNumId` numbering.  Instead of sequential numbering,
    we assign numbers based on the list marker styles.
  * `Text.Pandoc.Options`:
    + Removed `Ext_fenced_code_attributes` from `markdown_github`
    extensions.
  * `Text.Pandoc.ImageSize`:
    + Use default instead of failing if image size not found
    in exif header (#1358).
    + ignore unknown exif header tag rather than crashing.
    Some images seem to have tag type of 256, which was causing
    a runtime error.
  * `Text.Pandoc.Shared`:
    + `fetchItem`:  unescape URI encoding before reading local file (#1427).
    + `fetchItem`:  strip a fragment like `?#iefix` from the extension before
    doing mime lookup, to improve mime type guessing.
    + Improved logic of `fetchItem`:  absolute URIs are fetched from the net;
    other things are treated as relative URIs if `sourceURL` is `Just _`,
    otherwise as file paths on the local file system.
    + `fetchItem` now properly handles links without a protocol (#1477).
    + `fetchItem` now escapes characters not allowed in URIs before trying
    to parse the URIs.
    + Fixed runtime error with `compactify'DL` on certain lists (#1452).
  * `pandoc.hs`: Don't strip path off of `writerSourceURL`: the path is
    needed to resolve relative URLs when we fetch resources (#750).
  * `Text.Pandoc.Parsing`
    + Simplified `dash` and `ellipsis` (#1419).
    + Removed `(>>~)` in favor of the equivalent `(<*)` (Matthew Pickering).
    + Generalized functions to use `ParsecT` (Matthew Pickering).
    + Added `isbn` and `pmid` to list of recognized schemes (Matthew
    Pickering).
  [template changes]
  * Added haddock template.
  * EPUB3:  Added `type` attribute to `link` tags.  They are supposed to
    be "advisory" in HTML5, but kindlegen seems to require them.
  * EPUB3:  Put title page in section with `epub:type="titlepage"`.
  * LaTeX: Made `\subtitle` work properly (#1327).
  * LaTeX/Beamer: remove conditional around date (#1321).
  * LaTeX:  Added `lot` and `lof` variables, which can be set to
    get `\listoftables` and `\listoffigures` (#1407).  Note that
    these variables can be set at the command line with `-Vlot -Vlof`
    or in YAML metadata.
  [under the hood improvements]
  * Rewrote normalize for efficiency (#1385).
  * Rewrote Haddock reader to use `haddock-library` (#1346).
    + This brings pandoc's rendering of haddock markup in line
    with the new haddock.
    + Fixed line breaks in `@` code blocks.
    + alex and happy are no longer build-depends.
  * Added `Text.Pandoc.Compat.Directory` to allow building against
    different versions of the `directory` library.
  + Added `Text.Pandoc.Compat.Except` to allow building against
    different verions of `mtl`.
  * Code cleanup in some writers, using Reader monad to avoid
    passing options parameter around (Matej Kollar).
  * Improved readability in `pandoc.hs`.
  * Miscellaneous code cleanups (Artyom Kazak).
  * Avoid `import Prelude hiding (catch)` (#1309, thanks to Michael
    Thompson).
  * Changed `http-conduit` flag to `https`.  Depend on `http-client`
    and `http-client-tls` instead of `http-conduit`.  (Note:  pandoc still
    depends on `conduit` via `yaml`.)
  * Require `highlighting-kate >= 0.5.8.5` (#1271, #1317, Debian #753299).
    This change to highlighting-kate means that PHP fragments no longer need
    to start with `<?php`.  It also fixes a serious bug causing failures with
    ocaml and fsharp.
  * Require latest `texmath`.  This fixes `\tilde{E}` and allows
    `\left` to be used with `]`, `)` etc. (#1319), among many other
    improvements.
  * Require latest `zip-archive`.  This has fixes for unicode path names.
  * Added tests for plain writer.
  * `Text.Pandoc.Templates`:
    + Fail informatively on template syntax errors.
    With the move from parsec to attoparsec, we lost good error
    reporting.  In fact, since we weren't testing for end of input,
    malformed templates would fail silently.  Here we revert back to
    Parsec for better error messages.
    + Use `ordNub` (#1022).
  * Benchmarks:
    + Made benchmarks compile again (Artyom Kazak).
    + Fixed so that the failure of one benchmark does not prevent others
    from running (Artyom Kazak).
    + Use `nfIO` instead of the `getLength` trick to force full evaluation.
    + Changed benchmark to use only the test suite, so that benchmarks
    run more quickly.
  * Windows build script:
    + Use one install command for pandoc, pandoc-citeproc.
    + Force install of pandoc-citeproc.
  * `make_osx_package`:  Call zip file `pandoc-VERSION-osx.zip`.
    The zip should not be named `SOMETHING.pkg.zip`, or OSX finder
    will extract it into a folder named `SOMETHING.pkg`, which it
    will interpret as a defective package (#1308).
  * `README`:
    + Made headers for all extensions so they have IDs and can be
    linked to (Beni Cherniavsky-Paskin).
    + Fixed typos (Phillip Alday).
    + Fixed documentation of attributes (#1315).
    + Clarified documentation on small caps (#1360).
    + Better documentation for `fenced_code_attributes` extension
    (Caleb McDaniel).
    + Documented fact that you can put YAML metadata in a separate file
    (#1412).
  pandoc (1.12.4.2)
  =================
  * Shared:  `addMetaValue` now behaves slightly differently:
    if both the new and old values are lists, it concatenates their
    contents to form a new list.
  * LaTeX reader:
    + Set `bibliography` in metadata from `\bibliography` or
    `\addbibresource` command.
    + Don't error on `%%foo` with no trailing newline.
  * Org reader:
    + Support code block headers (`#+BEGIN_SRC ...`) (Albert Krewinkel).
    + Fix parsing of blank lines within blocks (Albert Krewinkel).
    + Support pandoc citation extension (Albert Krewinkel).  This can
    be turned off by specifying `org-citations` as the input format.
  * Markdown reader:
    + `citeKey` moved to `Text.Pandoc.Parsing` so it can be used by
    other readers (Albert Krewinkel).
  * `Text.Pandoc.Parsing`:
    + Added `citeKey` (see above).
    + Added `HasLastStrPosition` type class and `updateLastStrPos`
    and `notAfterString` functions.
  * Updated copyright notices (Albert Krewinkel).
  * Added default.icml to data files so it installs with the package.
  pandoc (1.12.4)
  ===============
  * Made it possible to run filters that aren't executable (#1096).
    Pandoc first tries to find the executable (searching the path
    if path isn't given).  If it fails, but the file exists and has
    a `.py`, `.pl`, `.rb`, `.hs`, or `.php` extension, pandoc runs the filter
    using the appropriate interpreter.  This should make it easier to
    use filters on Windows, and make it more convenient for everyone.
  * Added Emacs org-mode reader (Albert Krewinkel).
  * Added InDesign ICML Writer (mb21).
  * MediaWiki reader:
    + Accept image links in more languages (Jaime Marquínez Ferrándiz).
    + Fixed bug in certain nested lists (#1213).  If a level 2 list was
    followed by a level 1 list, the first item of the level 1 list
    would be lost.
    + Handle table rows containing just an HTML comment (#1230).
  * LaTeX reader:
    + Give better location information on errors, pointing to line
    numbers within included files (#1274).
    + LaTeX reader:  Better handling of `table` environment (#1204).
    Positioning options no longer rendered verbatim.
    + Better handling of figure and table with caption (#1204).
    + Handle `@{}` and `p{length}` in tabular.  The length is not actually
    recorded, but at least we get a table (#1180).
    + Properly handle `\nocite`.  It now adds a `nocite` metadata
    field.  Citations there will appear in the bibliography but not
    in the text (unless you explicitly put a `$nocite$` variable
    in your template).
  * Markdown reader:
    + Ensure that whole numbers in YAML metadata are rendered without
    decimal points.  (This became necessary with changes to aeson
    and yaml libraries.  aeson >= 0.7 and yaml >= 0.8.8.2 are now required.)
    + Fixed regression on line breaks in strict mode (#1203).
    + Small efficiency improvements.
    + Improved parsing of nested `div`s.  Formerly a closing `div` tag
    would be missed if it came right after other block-level tags.
    + Avoid backtracking when closing `</div>` not found.
    + Fixed bug in reference link parsing in `markdown_mmd`.
    + Fixed a bug in list parsing (#1154).  When reading a raw list
    item, we now strip off up to 4 spaces.
    + Fixed parsing of empty reference link definitions (#1186).
    + Made one-column pipe tables work (#1218).
  * Textile reader:
    + Better support for attributes.  Instead of being ignored, attributes
    are now parsed and included in Span inlines.  The output will be a bit
    different from stock textile: e.g. for `*(foo)hi*`, we'll get
    `<em><span class="foo">hi</span></em>` instead of
    `<em class="foo">hi</em>`.  But at least the data is not lost.
    + Improved treatment of HTML spans (%%) (#1115).
    + Improved link parsing.  In particular we now pick up on attributes.
    Since pandoc links can't have attributes, we enclose the whole link in
    a span if there are attributes (#1008).
    + Implemented correct parsing rules for inline markup (#1175, Matthew
    Pickering).
    + Use Builder (Matthew Pickering).
    + Fixed list parsing bug (#1500).
    + Don't allow inline formatting to extend over newlines.
    This matches the behavior of RedCarpet, avoids some ugly bugs,
    and improves performance.
  * DocBook reader:
    + Better treatment of `formalpara`.  We now emit the title (if present)
    as a separate paragraph with boldface text (#1215).
    + Set metadata `author` not `authors`.
    + Added recognition of `authorgroup` and `releaseinfo` elements (#1214,
    Matthew Pickering).
    + Converted current meta information parsing in DocBook to a more
    extensible version which is aware of the more recent meta
    representation (Matthew Pickering).
  * HTML reader:
    + Require tagsoup 0.13.1, to fix a bug with parsing of script tags
    (#1248).
    + Treat processing instructions & declarations as block.  Previously
    these were treated as inline, and included in paragraph tags in HTML
    or DocBook output, which is generally not what is wanted (#1233).
    + Updated `closes` with rules from HTML5 spec.
    + Use Builder (Matthew Pickering, #1162).
  * RST reader:
    + Remove duplicate `http` in PEP links (Albert Krewinkel).
    + Make rst figures true figures (#1168, CasperVector)
    + Enhanced Pandoc's support for rST roles (Merijn Verstaaten).
    rST parser now supports: all built-in rST roles, new role definition,
    role inheritance, though with some limitations.
    + Use `author` rather than `authors` in metadata.
    + Better handling of directives.  We now correctly handle field
    lists that are indented more than three spaces.  We treat an
    `aafig` directive as a code block with attributes, so it can be
    processed in a filter (#1212).
  * LaTeX writer:
    + Mark span contents with label if span has an ID (Albert Krewinkel).
    + Made `--toc-depth` work well with books in latex/pdf output (#1210).
    + Handle line breaks in simple table cells (#1217).
    + Workaround for level 4-5 headers in quotes.  These previously produced
    invalid LaTeX: `\paragraph` or `\subparagraph` in a `quote` environment.
    This adds an `mbox{}` in these contexts to work around the problem.
    See <http://tex.stackexchange.com/a/169833/22451> (#1221).
    + Use `\/` to avoid en-dash ligature instead of `-{}-` (Vaclav Zeman).
    This is to fix LuaLaTeX output. The `-{}-` sequence does not avoid the
    ligature with LuaLaTeX but `\/` does.
    + Fixed string escaping in `hyperref` and `hyperdef` (#1130).
  * ConTeXt writer:  Improved autolinks (#1270).
  * DocBook writer:
    + Improve handling of hard line breaks in Docbook writer
    (Neil Mayhew).  Use a `<literallayout>` for the entire paragraph, not
    just for the newline character.
    + Don't let line breaks inside footnotes influence the enclosing
    paragraph (Neil Mayhew).
    + Distinguish tight and loose lists in DocBook output, using
    `spacing="compact"` (Neil Mayhew, #1250).
  * Docx writer:  When needed files are not present in the user's
    `reference.docx`, fall back on the versions in the `reference.docx`
    in pandoc's data files. This fixes a bug that occurs when a
    `reference.docx` saved by LibreOffice is used. (#1185)
  * EPUB writer:
    + Include extension in epub ids.  This fixes a problem with duplicate
    extensions for fonts and images with the same base name but different
    extensions (#1254).
    + Handle files linked in raw `img` tags (#1170).
    + Handle media in `audio` source tags (#1170).
    Note that we now use a `media` directory rather than `images`.
    + Incorporate files linked in `video` tags (#1170).  `src` and `poster`
    will both be incorporated into `content.opf` and the epub container.
  * HTML writer:
    + Add colgroup around col tags (#877).  Also affects EPUB writer.
    + Fixed bug with unnumbered section headings.  Unnumbered section
    headings (with class `unnumbered`) were getting numbers.
    + Improved detection of image links. Previously image links with
    queries were not recognized, causing `<embed>` to be used instead
    of `<img>`.
  * Man writer:  Ensure that terms in definition lists aren't line wrapped
    (#1195).
  * Markdown writer:
    + Use proper escapes to avoid unwanted lists (#980).  Previously we used
    0-width spaces, an ugly hack.
    + Use longer backtick fences if needed (#1206).  If the content contains a
    backtick fence and there are attributes, make sure longer fences are
    used to delimit the code.  Note:  This works well in pandoc, but github
    markdown is more limited, and will interpret the first string of three
    or more backticks as ending the code block.
  * RST writer:  Avoid stack overflow with certain tables (#1197).
  * RTF writer:  Fixed table cells containing paragraphs.
  * Custom writer:
    + Correctly handle UTF-8 in custom lua scripts (#1189).
    + Fix bugs with lua scripts with mixed-case filenames and
    paths containing `+` or `-` (#1267).  Note that `getWriter`
    in `Text.Pandoc` no longer returns a custom writer on input
    `foo.lua`.
  * AsciiDoc writer:  Handle multiblock and empty table cells
    (#1245, #1246).  Added tests.
  * `Text.Pandoc.Options`: Added `readerTrace` to `ReaderOptions`
  * `Text.Pandoc.Shared`:
    + Added `compactify'DL` (formerly in markdown reader) (Albert Krewinkel).
    + Fixed bug in `toRomanNumeral`:  numbers ending with '9' would
    be rendered as Roman numerals ending with 'IXIV' (#1249).  Thanks to
    Jesse Rosenthal.
    + `openURL`: set proxy with value of http_proxy env variable (#1211).
    Note:  proxies with non-root paths are not supported, due to
    limitations in `http-conduit`.
  * `Text.Pandoc.PDF`:
    + Ensure that temp directories deleted on Windows (#1192).  The PDF is
    now read as a strict bytestring, ensuring that process ownership will
    be terminated, so the temp directory can be deleted.
    + Use `/` as path separators in a few places, even on Windows.
    This seems to be necessary for texlive (#1151, thanks to Tim Lin).
    + Use `;` for `TEXINPUTS` separator on Windows (#1151).
    + Changes to error reporting, to handle non-UTF8 error output.
  * `Text.Pandoc.Templates`:
    + Removed unneeded datatype context (Merijn Verstraaten).
    + YAML objects resolve to "true" in conditionals (#1133).
    Note:  If `address` is a YAML object and you just have `$address$`
    in your template, the word `true` will appear, which may be
    unexpected.  (Previously nothing would appear.)
  * `Text.Pandoc.SelfContained`:
    + `mkSelfContained` now takes just two arguments, `WriterOptions` and
    the string.
  * It no longer looks in data files.  This only made sense when we
    had copies of slidy and S5 code there.
  * `fetchItem'` is used instead of the nearly duplicate `getItem`.
    + Handle `poster` attribute in `video` tags (#1188).
  * `Text.Pandoc.Parsing`:
    + Made `F` an instance of Applicative (#1138).
    + Added `stateCaption`.
    + Added `HasMacros`, simplified other typeclasses.
    Removed `updateHeaderMap`, `setHeaderMap`, `getHeaderMap`,
    `updateIdentifierList`, `setIdentifierList`, `getIdentifierList`.
    + Changed the smart punctuation parser to return `Inlines`
    rather than `Inline` (Matthew Pickering).
    + Changed `HasReaderOptions`, `HasHeaderMap`, `HasIdentifierList`
    from typeclasses of monads to typeclasses of states.  This simplifies
    the instance definitions and provides more flexibility.  Generalized
    type of `getOption` and added a default definition.  Removed
    `askReaderOption`.  Added `extractReaderOption`.  Added
    `extractHeaderMap` and `updateHeaderMap` in `HasHeaderMap`.
    Gave default definitions for `getHeaderMap`, `putHeaderMap`,
    `modifyHeaderMap`.  Added `extractIdentifierList` and
    `updateIdentifierList` in `HasIdentifierList`.  Gave defaults
    for `getIdentifierList`, `putIdentifierList`, and
    `modifyIdentifierList`.  The ultimate goal here is to allow different
    parsers to use their own, tailored parser states (instead of
    `ParserState`) while still using shared functions.
  * Template changes:
    + LaTeX template: Use `fontenc` package only with `pdflatex` (#1164).
    + LaTeX template:  Add `linestretch` and `fontfamily` variables.
    + LaTeX template:  Conditionalize author and date commands.
    + Beamer template: Consistent styles for figure and table captions
    (aaronwolen).
    + LaTeX and beamer template:  Adjust widths correctly for oversized
    images.  Use `\setkeys{Gin}{}` to set appropriate defaults for
    `\includegraphics` (Yihui Xie, Garrick Aden-Buie).  Load
    `upquote` only after `fontenc` (Yihui Xie).
    + Beamer template: Added caption package (#1200).
    + Beamer template:  changes for better unicode handling (KarolS).
    + DocBook template:  use `authorgroup` if there are authors.
    + revealjs template: Move `include-after` to end (certainlyakey).
    + revealjs template: Fixed PDF print function (#1220, kevinkenan).
  * Bumped version bounds of dependencies.
  * Added a `--trace` command line option, for debugging backtracking
    bugs.  So far this only works with the markdown reader.
  * MathMLinHTML:  Fixed deprecation warning (#362, gwern, Albert Krewinkel).
  * Updated travis script to test with multiple GHC versions.
  * Force failure of a Travis build if GHC produces warnings (Albert
    Krewinkel).
  * Add `.editorconfig` (Albert Krewinkel).
    See <http://editorconfig.org/> for details.
  * Give more useful error message if '-t pdf' is specified (#1155).
  * Added `Cite`, `SmallCaps` to `Arbitrary` instance (#1269).
  * Allow `html4` as a synonym of `html` as a reader (it already works
    as a writer).
  * README:
    + Added an explanation of how to use YAML metadata to
    force items to appear in the bibliography without citations in
    the text (like LaTeX `\nocite`).
    + Added note to `--bibtex/--natbib`: not for use in making PDF
    (#1194, thanks to nahoj).
    + Added explanatory notes about `--natbib` and `--biblatex`.
    + Added specification of legal syntax for citation keys.
    + Fixed variable defaults documentation (Albert Krewinkel).
  * Removed copyright statements for files that have been removed
    (Albert Krewinkel).
  * Moved some doc files from `data-files` to `extra-source-files` (#1123).
    They aren't needed at runtime.  We keep README and COPYRIGHT in data
    to ensure that they'll be available on all systems on which pandoc
    is installed.
* Thu Mar 27 2014 sbahling@suse.com
- Correct package license
* Sun Mar 16 2014 sbahling@suse.com
- update to 1.12.3.3
- Remove zip-archive-upper-bound.patch (fix integrated)
  Pandoc Changes:
  1.12.3.3
  ========
  * To changes to source; recompiled tarball with latest alex and
    happy, so they will work with GHC 7.8.
  1.12.3.2
  ========
  * Bumped version bounds for blaze-html, blaze-markup.
  * ImageSize:  Avoid use of lookAhead, which is not in binary >= 0.6
    (#1124).
  * Fixed mediawiki ordered list parsing (#1122).
  * HTML reader:  Fixed bug reading inline math with `$$` (#225).
  * Added support for LaTeX style literate Haskell code blocks in rST
    (Merijn Verstraaten)
  1.12.3.1
  ========
  * Relaxed version constraint on binary, allowing the use of binary 0.5.
  1.12.3
  ======
  * The `--bibliography` option now sets the `biblio-files` variable.
    So, if you're using `--natbib` or `--biblatex`, you can just use
    `--bibliography=foo.bib` instead of `-V bibliofiles=foo`.
  * Don't run pandoc-citeproc filter if `--bibliography` is
    used together with `--natbib` or `--biblatex` (Florian Eitel).
  * Template changes:
    + Updated beamer template to include booktabs.
    + Added `abstract` variable to LaTeX template.
    + Put `header-includes` after `title` in LaTeX template (#908).
    + Allow use of `\includegraphics[size]` in beamer.
    This just required porting a macro definition from the default
    LaTeX template to the default beamer template.
  * `reference.docx`:  Include `FootnoteText` style.
    Otherwise Word ignores the style, even when specified in the `pPr`.
    (#901)
  * `reference.odt`:  Tidied `styles.xml`.
  * Relaxed version bounds for dependencies.
  * Added `withSocketsDo` around http conduit code in `openURL`,
    so it works on Windows (#1080).
  * Added `Cite` function to `sample.lua`.
  * Markdown reader:
    + Fixed regression in title blocks (#1089).
    If author field was empty, date was being ignored.
    + Allow backslash-newline hard line breaks in grid and
    multiline table cells.
    + Citation keys may now start with underscores, and may contain
    underscores adjacent to internal punctuation.
  * LaTeX reader:
    + Add support for `Verb` macro (jrnold) (#1090).
    + Support babel-style quoting: `` "`..."' ``.
  * Properly handle script blocks in strict mode.  (That is,
    `markdown-markdown_in_html_blocks`.) Previously a spurious
    `<p>` tag was being added (#1093).
  * Docbook reader: Avoid failure if `tbody` contains no `tr` or `row`
    elements.
  * LaTeX writer:
    + Factored out function for table cell creation.
    + Better treatment of footnotes in tables.
    Notes now appear in the regular sequence, rather than in the
    table cell.  (This was a regression in 1.10.)
  * HTML reader: Parse name/content pairs from meta tags as metadata.
    Closes #1106.
  * Moved `fixDisplayMath` from Docx writer to `Writer.Shared`.
  * OpenDocument writer:  Fixed `RawInline`, `RawBlock` so they don't escape.
  * ODT writer:  Use mathml for proper rendering of formulas.
    Note:  LibreOffice's support for this seems a bit buggy.  But
    it should be better than what we had before.
  * RST writer: Ensure no blank line after def in definition list (#992).
  * Markdown writer: Don't use tilde code blocks with braced attributes in
    `markdown_github` output.  A consequence of this change is that the
    backtick form will be preferred in general if both are enabled.  That
    is good, as it is much more widespread than the tilde form.  (#1084)
  * Docx writer:  Fixed problem with some modified reference docx files.
    Include `word/_rels/settings.xml.rels` if it exists, as well as other
    `rels` files besides the ones pandoc generates explicitly.
  * HTML writer:
    + With `--toc`, headers no longer link to themselves (#1081).
    + Omit footnotes from TOC entries.  Otherwise we get doubled
    footnotes when headers have notes!
  * EPUB writer:
    + Avoid duplicate notes when headings contain notes.
    This arose because the headings are copied into the metadata
    "title" field, and the note gets rendered twice.  We strip the
    note now before putting the heading in "title".
    + Strip out footnotes from toc entries.
    + Fixed bug with `--epub-stylesheet`.  Now the contents of
    `writerEpubStylesheet` (set by `--epub-stylesheet`)
    should again work, and take precedence over a stylesheet specified
    in the metadata.
  * `Text.Pandoc.Pretty`:  Added `nestle`.  API change.
  * `Text.Pandoc.MIME`: Added `wmf`, `emf`.
  * `Text.Pandoc.Shared`:  `fetchItem` now handles image URLs beginning
    with `//`.
  * `Text.Pandoc.ImageSize`:  Parse EXIF format JPEGs.  Previously
    we could only get size information for JFIF format, which led
    to squished images in Word documents. Closes #976.
  * Removed old `MarkdownTest_1.0.3` directory (#1104).
* Tue Dec 31 2013 peter.trommler@ohm-hochschule.de
- update to 1.12.2.1
- add zip-archive-upper-bound.patch
  * relax version constraint on ghc-zip-archive so we can avoid
  a dependency on ghc-utf8-string, which is not in Factory
  * see upstream commit 26052d3
  * can be dropped with next upstream release
* Sun Dec 29 2013 peter.trommler@ohm-hochschule.de
- expand macro in name tag, OBS requirement
* Sun Dec 29 2013 peter.trommler@ohm-hochschule.de
- merge d:l:haskell changes
* Mon Oct  7 2013 sbahling@suse.com
- Update to 1.12.0.2
- Use %%fdupes to make rpmlint happy
- Move documentation from /usr/share/pandoc-%%version to standard docdir
  Pandoc New Features:
  * Much more flexible metadata using YAML metadata.
  * Added opml (OPML) as input and output format.
  * Added haddock (Haddock markup) as input format
  * Added revealjs output format, for reveal.js HTML 5 slide shows.
  * Custom writers can now be written in lua.
  * New --filter/-F option to make it easier to run “filters”
  * Added --metadata/-M option.
  * Added --print-default-data-file
  * Added syntax for “pauses” in slide shows.
  * New markdown extensions:
  - ignore_line_breaks
  - yaml_metadata_block
  - ascii_identifiers
  - lists_without_preceding_blankline
* Sat May 18 2013 peter.trommler@ohm-hochschule.de
- add manual pages to files
- remove man page helper program that was added by cabal-rpm
* Sat May 18 2013 peter.trommler@ohm-hochschule.de
- update to 1.11.1 from upstream
  * hide some APIs: Parsing, Highlighting
  * new input format markdown_github
  * see http://johnmacfarlane.net/pandoc/releases.html
  for fixes
* Mon Mar 11 2013 peter.trommler@ohm-hochschule.de
- fix rpath in pandoc executable
* Fri Jan 25 2013 peter.trommler@ohm-hochschule.de
- update to 1.10.0.5 from upstream
  * new input format MediaWiki
  * new Output formats EPUB3, FictionBooks2
  * see http://johnmacfarlane.net/pandoc/releases.html
  for complete list of new features and fixes
* Sun Nov 18 2012 peter.trommler@ohm-hochschule.de
- update to 1.9.4.5 from upstream
  pandoc (1.9.4.5)
  * Raised version bounds on network, base64-bytestring, json,
    and template-haskell.
  pandoc (1.9.4.4)
  * Removed `tests` flag and made test suite into a proper cabal
    test suite, which can now be enabled using `--enable-tests`
    and run with `cabal test`.
  * Moved man page creation out of `Setup.hs` and into an
    executable built by Cabal, but never installed.  This
    allows dependencies to be specified, and solves a problem
    with 1.9.4.3, which could only be installed if `data-default`
    had already been installed.
  * Updated `lhs-latex.tex` test for latest highlighting-kate
    representation of backticks.
  pandoc (1.9.4.3)
  * Removed `-threaded` from default compile flags.
  * Modified modules to compile with GHC 7.6 and latest version of time
    package.
* Thu Jul  5 2012 peter.trommler@ohm-hochschule.de
- update to 1.9.4.2 from upstream
  * Don't encode/decode file paths if base >= 4.4.
    Prior to base 4.4, filepaths and command line arguments were treated
    as unencoded lists of bytes, not unicode strings, so we had to work
    around that by encoding and decoding them. This commit adds CPP
    checks for the base version that intelligibly enable encoding/decoding
    when needed. Fixes a bug with multilingual filenames when pandoc was
    compiled with ghc 7.4 (#540).
  * Don't generate an empty H1 after hrule slide breaks.
    We now use a slide-level header with contents `[Str "\0"]` to mark
    an hrule break.  This avoids creation of an empty H1 in these
    contexts.  Closes #484.
  * Docbook reader: Added support for "bold" emphasis.  Thanks to mb21.
  * In make_osx_package.sh, ensure citeproc-hs is built with the
    embed_data_files flag.
  * MediaWiki writer: Avoid extra blank lines after sublists (Gavin Beatty).
  * ConTeXt writer: Don't escape `&`, `^`, `<`, `>`, `_`,
    simplified escapes for `}` and `{` to `\{` and `\}` (Aditya Mahajan).
  * Fixed handling of absolute URLs in CSS imports with `--self-contained`.
    Closes #535.
  * Added webm to mime types. Closes #543.
  * Added some missing exports and tests to the cabal file
    (Alexander V Vershilov).
  * Compile with `-rtsopts` and `-threaded` by default.
* Sat Jun 16 2012 peter.trommler@ohm-hochschule.de
- update to 1.9.4.1 from upstream
  pandoc (1.9.4.1)
  * Markdown reader: Added `cf.` and `cp.` to list of likely abbreviations.
  * LaTeX template: Added `linkcolor`, `urlcolor` and `links-as-notes`
    variables.  Make TOC links black.
  * LaTeX template improvements.
    + Don't print date unless one is given explicitly in the document.
    + Simplified templates.
    + Use fontenc [T1] by default, and lmodern.
    + Use microtype if available.
  * Biblio:
    + Add comma to beginning of bare suffix, e.g. `@item1 [50]`.
    Motivation: `@item1 [50]` should be as close as possible to
    `[@item1, 50]`.
    + Added workaround for a bug in citeproc-hs 0.3.4 that causes footnotes
    beginning with a citation to be empty.  Closes #531.
  * Fixed documentation on mixed lists.  Closes #533.
  pandoc (1.9.4)
  * Simplified `Text.Pandoc.Biblio` and fixed bugs with citations inside
    footnotes and captions.  We now handle note citations by inserting
    footnotes during initial citation processing, and doing a separate
    pass later to remove notes inside notes.
  * Added 'zenburn' highlight style from highlighting-kate.
  * Added Slideous writer. Slideous is an HTML + javascript slide show
    format, similar to Slidy, but works with IE 7. (Jonas Smedegaard)
  * LaTeX writer:
    + Ensure we don't have extra blank lines at ends of cells.
    This can cause LaTeX errors, as they are interpreted as new paragraphs.
    + More consistent interblock spacing.
    + Require highlighting-kate >= 0.5.1, for proper highlighted inline
    code in LaTeX.  Closes #527.
    + Ensure that a Verbatim at the end of a footnote is followed by
    a newline. (Fixes a regression in the previous version.)
    + In default template, use black for internal links and TOC.
    Added commented-out code to use footnotes for links, as would
    be suitable in print output.
  * Beamer writer:  When `--incremental` is used, lists inside
    a block quote should appear all at once.  (This makes Beamer
    output consistent with the HTML slide show formats.)
  * ConTeXt writer:
    + Escape `%%` as `\letterpercent{}` not `\letterpercent `,
    to avoid gobbling spaces after the `%%` sign.
    + Ensure space after `\stopformula`.
  * Markdown writer:
    + Use `:` form instead of `~` in definition lists, for better
    compatibility with other markdown implementations.
    + Don't wrap the term, because it breaks definition lists.
    + Use a nonzero space to prevent false recognition
    of list marker in ordered lists.  Closes #516.
  * Org writer: Add space before language name.  Closes #523.
  * Docx writer: Simplified bullet characters so they work properly
    with Word 2007. Closes #520.
  * LaTeX reader: Support `\centerline`.
  * RST reader:  handle figures.  Closes #522.
  * Textile reader: fix for `<notextile>` and `==`.  Closes #517.
    (Paul Rivier)
* Thu Jun  7 2012 peter.trommler@ohm-hochschule.de
- update to 1.9.3 from upstream
  pandoc (1.9.3)
  * Fixed bug in `fromEntities`.  The previous version would turn
    `hi & low you know;` into `hi &`.
  * HTML reader:
    + Don't skip nonbreaking spaces.
    Previously a paragraph containing just `&nbsp;` would be rendered
    as an empty paragraph. Thanks to Paul Vorbach for pointing out the bug.
    + Support `<col>` and `<caption>` in tables. Closes #486.
  * Markdown reader:
    + Don't recognize references inside delimited code blocks.
    + Allow list items to begin with lists.
  * Added basic docbook reader (John MacFarlane and Mauro Bieg).
  * LaTeX reader:
    + Handle `\bgroup`, `\egroup`, `\begingroup`, `\endgroup`.
    + Control sequences can't be followed by a letter.
    This fixes a bug where `\begingroup` was parsed as `\begin`
    followed by `group`.
    + Parse 'dimension' arguments to unknown commands.  e.g. `\parindent0pt`
    + Make `\label` and `\ref` sensitive to `--parse-raw`.
    If `--parse-raw` is selected, these will be parsed as raw latex
    inlines, rather than bracketed text.
    + Don't crash on unknown block commands (like `\vspace{10pt}`)
    inside `\author`; just skip them.  Closes #505.
  * Textile reader:
    + Implemented literal escapes with `==` and `<notextile>`.  Closes #473.
    + Added support for LaTeX blocks and inlines (Paul Rivier).
    + Better conformance to RedCloth inline parsing (Paul Rivier).
    + Parse '+text+' as emphasized (should be underlined, but this
    is better than leaving literal plus characters in the output.
  * Docx writer: Fixed multi-paragraph list items.  Previously they each
    got a list marker.  Closes #457.
  * LaTeX writer:
    + Added `--no-tex-ligatures` option to avoid replacing
    quotation marks and dashes with TeX ligatures.
    + Use `fixltx2e` package to provide '\textsubscript'.
    + Improve spacing around LaTeX block environments:
    quote, verbatim, itemize, description, enumerate.
    Closes #502.
    + Use blue instead of pink for URL links in latex/pdf output.
  * ConTeXt writer: Fixed escaping of `%%`.
    In text, `%%` needs to be escaped as `\letterpercent`, not `\%%`
    Inside URLs, `%%` needs to be escaped as `\%%`
    Thanks to jmarca and adityam for the fix.  Closes #492.
  * Texinfo writer:  Escape special characters in node titles.
    This fixes a problem pointed out by Joost Kremers.  Pandoc used
    to escape an '@' in a chapter title, but not in the corresponding
    node title, leading to invalid texinfo.
  * Fixed document encoding in texinfo template.
    Resolves Debian Bug #667816.
  * Markdown writer:
    + Don't force delimited code blocks to be flush left.
    Fixes bug with delimited code blocks inside lists etc.
    + Escape `<` and `$`.
  * LaTeX writer: Use `\hyperref[ident]{text}` for internal links.
    Previously we used `\href{\#ident}{text}`, which didn't work on
    all systems. Thanks to Dirk Laurie.
  * RST writer: Don't wrap link references.  Closes #487.
  * Updated to use latest versions of blaze-html, mtl.
  pandoc (1.9.2)
  * LaTeX reader:
    + Made `lstlisting` work as a proper verbatim environment.
    + Fixed bug parsing LaTeX tables with one column.
  * LaTeX writer:
    + Use `{}` around `ctable` caption, so that formatting can be used.
    + Don't require eurosym package unless document has a €.
  * LaTeX template: Added variables for `geometry`, `romanfont`,
    `sansfont`, `mathfont`, `mainfont` so users can more easily
    customize fonts.
  * PDF writer:
    + Run latex engine at least two times, to ensure
    that PDFs will have hyperlinked bookmarks.
    + Added PDF metadata (title,author) in LaTeX standalone + PDF output.
  * Texinfo writer: retain directories in image paths.  (Peter Wang)
  * RST writer:  Better handling of inline formatting, in accord
    with docutils' "inline markup recognition rules" (though we don't
    implement the unicode rules fully). Now `hi*there*hi` gets
    rendered properly as `hi\ *there*\ hi`, and unnecessary
    `\ ` are avoided around `:math:`, `:sub:`, `:sup:`.
  * RST reader:
    + Parse `\ ` as null, not escaped space.
    + Allow `` :math:`...` `` even when not followed by blank
    or `\`.  This does not implement the complex rule docutils follows,
    but it should be good enough for most purposes.
    + Add support for the rST default-role directive. (Greg Maslov)
  * Text.Pandoc.Parsing: Added `stateRstDefaultRole` field to `ParserState`.
    (Greg Maslov)
  * Markdown reader: Properly handle citations nested in other inline
    elements.
  * Markdown writer:  don't replace empty alt in image with "image".
  * DZSlides:  Updated template.html and styles in default template.
    Removed bizarre CSS for `q` in dzslides template.
  * Avoid repeated `id` attribute in section and header in HTML slides.
  * README improvements:  new instructions on internal links,
    removed misleading note on reST math.
  * Build system:
    + Fixed Windows installer so that dzslides works.
    + Removed stripansi.sh.
    + Added .travis.yml for Travis continuous integration support..
    + Fixed upper bound for zlib (Sergei Trofimovich).
    + Fixed upper bound for test-framework.
    + Updated haddocks for haddock-2.10 (Sergei Trofimovich).
- update needed for Haskell Platform 2012.2.0.0
* Mon May 14 2012 peter.trommler@ohm-hochschule.de
- remove docdir to prevent double packaging (fails in Factory)
* Mon May 14 2012 peter.trommler@ohm-hochschule.de
- put docdir back
- fix dependencies for devel package (bnc #762003)
- fix packaging (bnc #713301)
* Sun Apr 29 2012 peter.trommler@ohm-hochschule.de
- exclude doc dir from library packages
* Sun Apr 29 2012 peter.trommler@ohm-hochschule.de
- simplified spec file
- add README and others to %%doc in main package (bnc #713301)
* Tue Mar 13 2012 peter.trommler@ohm-hochschule.de
- removed attr for man pages
- added filter for rpmlint (debuginfo)
* Mon Mar 12 2012 peter.trommler@ohm-hochschule.de
- upgrade to 1.9.1.2 from upstream (fixes man page issue)
* Fri Mar  9 2012 herbert@graeber-clan.de
- revert last change, because without_hscolour was already undefined
* Fri Mar  9 2012 mvancura@suse.de
- allow hscolour support as we are over the bootstrapping phase
* Fri Mar  9 2012 mvancura@suse.de
- man pages must have permissions 644
* Thu Jan 19 2012 herbert@graeber-clan.de
- initial packaging for Fedora automatically generated by cabal2spec-0.24.1
